<?php

namespace BayDOC\Entry;

use PHPUnit\Framework\MockObject\Stub\ReturnReference;

class Doc extends Base
{

    protected bool $antrag = true;
    protected array $status = [];

    protected string $table = 'baydoc';



    public function __construct(\BayCMS\Base\BayCMSContext $context, int $id = null)
    {
        parent::__construct($context, $id);
        $this->init();

    }

    private function init()
    {
        if ($this->id === null) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from ' . $this->table . ' where (id_benutzer=$1 or id_benutzer2=$1) order by antrag,id',
                [$this->context->getUserId()]
            );
            if (pg_num_rows($res)) {
                [$this->id] = pg_fetch_row($res, 0);
                $this->role = 'selbst';
            } elseif ($this->context->getPower() >= 1000) {
                $this->role = 'admin';
            } else {
                $res = pg_query_params(
                    $this->context->getDbConn(),
                    'select s.id from ' . $this->table . ' s, bayprof p where
                (s.b_id=p.id or s.m1_id=p.id or s.m2_id=p.id or s.m3_id=p.id) and
				(p.id_benutzer=$1 or p.id_benutzer2=$1)',
                    [$this->context->getUserId()]
                );
                if (pg_num_rows($res)) {
                    $this->role = 'bm';
                } else {
                    $this->role = 'selbst';
                }
            }
        }

        if ($this->id === null)
            return;

        if (
            $this->role == 'selbst' &&
            pg_num_rows(pg_query($this->context->getDbConn(), "select d.id from " . $this->table . " d, objekt_ls o where 
        d.antrag and d.id=o.id_obj and o.id_lehr!=" . $this->context->getOrgId() . " and d.id=" . $this->id))
        ) {
            pg_query_params(
                $this->context->getRwDbConn(),
                'delete from objekt_ls where id_obj=$1',
                [$this->id]
            );

        }
        if (
            $this->role == 'selbst' &&
            !pg_num_rows(pg_query(
                $this->context->getDbConn(),
                "select * from objekt_ls where id_obj=" . $this->id . " and id_lehr=" . $this->context->getOrgId()
            ))
        ) {
            pg_query_params(
                $this->context->getRwDbConn(),
                'select set_objekt_ls($1,$2,$3)',
                [$this->id, $this->context->getOrgId(), $this->context->getOrgId()]
            );

        }
        $this->load($this->id);
    }


    public function confirm()
    {
        if (!in_array($_GET['who'] ?? '', explode(' ', 'b m1 m2 m3')))
            throw new \BayCMS\Exception\missingData('$_GET[who] must be set and one of b, m1, m2 or m3');

        if (!is_numeric($_GET['id_obj'] ?? 'x'))
            throw new \BayCMS\Exception\invalidData('$_GET[id_obj] must be numeric');
        $res = pg_query_params(
            $this->context->getDbConn(),
            "select id from " . $this->table . " where id=\$1 and
			$_GET[who]_token=\$2 and $_GET[who]_bestaetigt is null and $_GET[who]_id is not null",
            [$_GET['id_obj'], $_GET['token']]
        );
        if (pg_num_rows($res)) {
            pg_query(
                $this->context->getRwDbConn(),
                "update " . $this->table . " set $_GET[who]_bestaetigt=now() where id=$_GET[id_obj]"
            );
            $res = pg_query(
                $this->context->getRwDbConn(),
                "select p.id,p.id_benutzer,p.id_benutzer2 from bayprof p, baydoc d
                    where d.id=$_GET[id_obj] and d.$_GET[who]_id=p.id"
            );
            [$id_prof, $id_benutzer1, $id_benutzer2] = pg_fetch_row($res, 0);
            if (!$id_benutzer1) {
                pg_query(
                    $this->context->getRwDbConn(),
                    "update bayprof set id_benutzer=" . $this->context->getUserId() . " where id=$id_prof"
                );
                $id_benutzer1 = $this->context->getUserId();
            } elseif ($this->context->getUserId() != $id_benutzer1) {
                pg_query(
                    $this->context->getRwDbConn(),
                    "update bayprof set id_benutzer2=" . $this->context->getUserId() . " where id=$id_prof"
                );
                $id_benutzer2 = $this->context->getUserId();
            }
            pg_prepare(
                $this->context->getRwDbConn(),
                'set_zugriff',
                'insert into zugriff(id_benutzer,id_obj)
                    select $1,$2 except select id_benutzer,id_obj from zugriff 
                    where id_benutzer=$1 and id_obj=$2'
            );
            if ($id_benutzer1)
                pg_execute(
                    $this->context->getRwDbConn(),
                    'set_zugriff',
                    [$id_benutzer1, $_GET['id_obj']]
                );
            if ($id_benutzer2)
                pg_execute(
                    $this->context->getRwDbConn(),
                    'set_zugriff',
                    [$id_benutzer2, $_GET['id_obj']]
                );
            $this->message = $this->context->t('Confirmation successful', 'Betätigung erfolgt') . '.';
        } elseif (
            pg_num_rows(pg_query_params(
                $this->context->getDbConn(),
                "select id from " . $this->table . " where id=\$1 and
                $_GET[who]_bestaetigt is null and $_GET[who]_id is not null",
                [$_GET['id_obj']]
            ))
        ) {
            $this->message = $this->context->t(
                'Error: Token is not valid any more. Please check whether there is a new e-mail with an other token link',
                'Fehler: Token ist nicht mehr gültig! Bitte prüfen Sie,
                    ob nicht eine neuere E-Mail mit einem anderen Token vorliegt'
            ) . '.';
            require '../../inc/gru/end_tags.inc';
        } elseif (
            pg_num_rows(pg_query_params(
                $this->context->getDbConn(),
                "select id from " . $this->table . " where id=\$1 and
                $_GET[who]_bestaetigt is not null and $_GET[who]_id is not null",
                array($_GET['id_obj'])
            ))
        ) {
            $this->message = $this->context->t(
                'Error: The entry has been confirmed already',
                'Fehler: Der Eintrag wurde bereits bestätigt'
            ) . '.';
        } else {
            $this->message = $this->context->t('Error: No entry found', 'Fehler: Kein Eintrag gefunden') . '.';
        }
        $_GET['tab'] = 'betr';
    }

    public function load(int $id)
    {
        //Confirmation for supervisors...
        if (($_GET['betr'] ?? '') == 'confirm' || ($_GET['aktion_disabled'] ?? '') == 'confirm') {
            $this->confirm();
        }

        $this->id = $id;

        $obj = new \BayCMS\Base\BayCMSObject($this->context);
        $obj->load($id);
        try{
            $obj->checkAccess(); //Throws exception!
        } catch(\Exception $e){
            $p = new \BayCMS\Page\ErrorPage($this->context,401,$e->getMessage());
            $p->page();
        }
        $lang = $this->context->lang;
        $lang2 = $this->context->lang2;

        $from = "lehrstuhl l, gehoert_zu g, lehrstuhl pl, " . $this->table . " d " .
            ($this->table == 'baydoc' ? "
        left outer join baydoc_stgfach f on f.id=d.hstatg_fach" : '');
        $select = 'd.*,
        baydoc_getstatus($1,$2,\'' . $lang . '\'),
        non_empty(l.' . $lang . ',l.' . $lang2 . ') as ls,
        non_empty(pl.' . $lang . ',pl.' . $lang2 . ') as ls2,
        non_empty(l.de,l.en) as group_de,non_empty(l.en,l.de) as group_en,
        non_empty(pl.de,pl.en) as parent_group_de,non_empty(pl.en,pl.de) as parent_group_en' .
            ($this->table == 'baydoc' ? ", f.name as promotions_fach" : '');
        $bm = ['b', 'm1', 'm2', 'm3'];
        for ($i = 0; $i < 4; $i++) {
            $from .= " left outer join bayprof $bm[$i] on $bm[$i].id=d.$bm[$i]_id";
            $select .= ",$bm[$i].anrede as $bm[$i]_anrede,$bm[$i].titel as $bm[$i]_titel,$bm[$i].vname as $bm[$i]_vname,
            $bm[$i].nname as $bm[$i]_nname,$bm[$i].email as $bm[$i]_email,$bm[$i].aktiv as $bm[$i]_aktiv,$bm[$i].admin_ok as $bm[$i]_admin_ok";
        }
        $res = pg_query_params(
            $this->context->getDbConn(),
            "select $select from $from where
                d.id_lehr=l.id and l.id=g.id_lehr and g.id_parent=pl.id and
                d.id=\$1",
            [$this->id, $this->context->getOrgId()]
        );
        if (!pg_num_rows($res)) {
            throw new \BayCMS\Exception\notFound('Entry with id=' . $this->id . ' does not exist');
        }
        $this->row = pg_fetch_array($res, 0);
        $this->antrag = $this->row['antrag'] == 't';
        if ($this->context->getPower() >= 1000)
            $this->role = 'admin';
        elseif ($this->row['id_benutzer'] == $this->context->getUserId() || $this->row['id_benutzer2'] == $this->context->getUserId())
            $this->role = 'selbst';
        else
            $this->role = 'bm';
        if ($this->table == 'baydoc') {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select 
        g.id_parent,z.id_lehr,k.id,k.uname from
        baydoc_zulassungskat k, baydoc_zulassung z, gehoert_zu g
        where g.id_lehr=z.id_lehr and z.id_stud=$1 and z.id_kat=k.id order 
        by k.id,z.id_lehr,z.datum',
                [$this->id]
            );
            for ($i = 0; $i < pg_num_rows($res); $i++) {
                $r2 = pg_fetch_array($res, $i);
                $this->status[(int) $r2['id_lehr']] = $r2['uname'];
                $this->status[(int) $r2['id_parent']] = $r2['uname'];
            }
        }

    }


    public function printHead()
    {
        if ($this->message)
            $GLOBALS['TE']->printMessage($this->message);

        if (!$this->id) {
            if ($this->role == 'selbst') {
                echo "<h2>" . $this->context->t('New Registration', 'Neue Registrierung') . "</h2>";

            }
            return;
        }

        if ($this->role == 'selbst' && $this->antrag)
            echo '<p style="max-width:300px; float:right;">
    <h4 style="color:#ff0000;">' .
                $this->context->t(
                    'Attention: You are still in the registration process. Your data will be saved even on logout. But your entry is only visible to you.',
                    'Hinweis: Sie befinden sich noch im Registrierungsprozess. Ihr Angaben werden gespeichert und sind auch nach einem Logout/Login vorhanden. Aktiv wird ihr Eintrag jedoch erst nach Abschluss der Registrierung.'
                ) .
                '</h4></p>';


        if ($this->context->getPower() >= 1000) {
            echo '<p style="float:right">' . $GLOBALS['TE']->getActionLink('/' . $this->context->getOrgLinkLang() . '/admin/baydoc/baydoc.php', 'zurück zur Übersicht', '', 'arrow-left') .
                '</p>';
        }

        echo "<h2>" . $this->row['vorname'] . " " . $this->row['name'] . "</h2>
	<h4>" . $this->row['ls2'] . ": " . $this->row['ls'] . "</h4>";
        //Status:
        if ($this->row['baydoc_getstatus']) {
            echo "<h4>Status: " . $this->row['baydoc_getstatus'];
            if ($this->row['locked'] == 't')
                echo "-- <span style=\"color:#ff0000;\">Bearbeitung gesperrt!!</span>";
            echo "</h4>";
        }



    }


    public function getTable(){
        return $this->table;
    }
    public function getVTable(){
        return $this->table=='baydoc'?'baydoc_verfahren':'habil_verfahren';
    }

    public function getAntrag()
    {
        return $this->antrag;
    }

    public function getStatus(int $key = null)
    {
        if ($key !== null)
            return $this->status[$key] ?? null;
        return $this->status;
    }

    public function hstatgOk(): bool
    {
        return $this->row['hstatg_ok'] == 't';
    }



    public function getOrgId()
    {
        if (isset($this->row))
            return (int) $this->row['id_lehr'];
        else
            return $this->context->getOrgId();
    }
}