<?php

namespace BayDOC\Field;

class AdminOK extends \BayCMS\Field\Select
{
    protected static array $check_colors = [
        'eingegangen' => '#000000',
        'nachgefordert' => '#dd0000',
        'nicht ok' => '#dd0000',
        'ok' => '#00aa00'
    ];

    protected static array $en = [
        'eingegangen' => 'Documents received',
        'nachgefordert' => 'Further Documents requested',
        'nicht ok' => 'not OK',
        'ok' => 'OK'
    ];

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        string $name,
        string|null $description = null,
        string $id = '',
        string $sql = '',
        string $help = '',
        string $label_css = '',
        string $input_options = '',
        string $post_input = '',
        string $placeholder = '',
        bool $no_add_to_query = false,
        bool $not_in_table = false,
        bool $non_empty = false,
        array|null $footnote = null,
        mixed $default_value = null,
        string $div_id = ''
    ) {
        parent::__construct(
            $context,
            $name,
            $description,
            $id,
            $sql,
            $help,
            $label_css,
            $input_options,
            $post_input,
            $placeholder,
            $no_add_to_query,
            $not_in_table,
            $non_empty,
            $footnote,
            $default_value,
            $div_id,
            values: ['eingegangen', 'nachgefordert', 'nicht ok', 'ok'],
            null: true
        );
    }

    public function getDisplayValue(): string{
        $v=$this->value;
        if(! $v) return '';
        if(! $this->de()) $v=AdminOK::$en[$v];    
        return '<span style="color:'.(AdminOK::$check_colors[$this->value]??'#000000').';">'.$v.'</span>';
    }

    public function getFormRow(\BayCMS\Fieldset\Form $form): string
    {
        if($this->no_add_to_query)
            return '<div class="' . $GLOBALS['TE']->getCSSClass('form_div') . '">'. 
                $this->getDescription() .$this->getDisplayValue(). "</div>\n";
        return parent::getFormRow($form);
    }


    public function getTableRow(): string
    {
        if( $this->not_in_table) return '';
        if($this->no_add_to_query)
            return "<tr><td colspan=2>" .$this->getDescription(). $this->getDisplayValue() . "</td></tr>\n";
        return parent::getTableRow();
    }




}