<?php

namespace BayDOC\Page\Admin;

class Events extends \BayCMS\Fieldset\Domain
{
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            $context,
            'baydoc_events',
            'Veranstaltungen',
            'baydoc_event',
            headline:false
        );
        if (!isset($_GET['d1order_by']))
            $_GET['d1order_by'] = '2-d';
        $squery = '';
        $sql = 'non_empty(' . $context->getLangLang2('t.') . ')';
        if ($_GET['json_query'] ?? false)
            $_GET['such'] = $_GET['json_query'];
        if ($_GET['such'] ?? '') {
            $such = "'%" . pg_escape_string($context->getDbConn(), $_GET['such']) . "%'";
            $squery .= " and ($sql ilike $such)";
        }
        if (($_GET['anzeigen_vor_anmeldung'] ?? 'f') != 'f')
            $squery .= ' and t.anzeigen_vor_anmeldung';
        if (($_GET['baydoc'] ?? 'f') != 'f')
            $squery .= ' and t.baydoc';
        if (($_GET['postdoc'] ?? 'f') != 'f')
            $squery .= ' and t.postdoc';
        $this->setListProperties(order_by: [1, 2, 't.datum'], squery: $squery);


        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'such',
            'Name',
            sql: $sql
        ), search_field: 1, list_field: 1, edit_field: 0);
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'anmeldungen',
            'Anmeldungen',
            sql: "' <a href=\"event_anmeldungen.php?id_obj='||t.id||'\">Anmeldungen</a>'"
        ), list_field: 1, edit_field: 0);
        $this->addField(new \BayCMS\Field\BilangInput(
            $context,
            '',
            'Titel',
            non_empty: 1
        ));
        $help = 'Falls gesetzt, wird ein Link zur Darstellung automatisch erzeugt und das Link (URL) Feld ignoriert';
        $this->addField(new \BayCMS\Field\BilangTextarea(
            $context,
            'text_',
            'Beschreibung',
            help: ['de' => $help, 'en' => ''],
            htmleditor: 1

        ));
        $this->addField(new \BayCMS\Field\URL(
            $context,
            'url',
            'Link (mit http://)'
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            'Datum',
            help: 'Dieses Datum regelt die Sichtbarkeit. Nur zukünftige Veranstaltungen erscheinen beim Doktoranden. ' .
            'Administratoren sehen abweichend auch Veranstaltungen die bereits bis zu zwei Monate vergangen sind. ' .
            'Falls zusätzlich &quot;Anmeldung möglich ab&quot; gesetzt ist, wird ggf. eine zukünftige Veranstaltung unterdrückt.'
        ), list_field: 1);
        $this->addField(new \BayCMS\Field\Date(
            $context,
            'datum_bis',
            'bis Datum'
        ));
        $this->addField(new \BayCMS\Field\Time(
            $context,
            'von',
            'Uhrzeit von'
        ));
        $this->addField(new \BayCMS\Field\Time(
            $context,
            'bis',
            'Uhrzeit bis'
        ));
        $this->addField(new \BayCMS\Field\Datetime(
            $context,
            'anmeldung_von',
            'Anmeldung möglich ab',
            help: 'Falls gesetzt sehen Doktoranden/Postdocs diese Veranstaltung erst nach diesem Zeitpunkt. Administratoren sehen die Veranstaltung unabhängig von einem Eintrag in diesem Feld.'
        ));
        $this->addField(new \BayCMS\Field\Datetime(
            $context,
            'anmeldung_bis',
            'Anmeldung möglich bis'
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'anzeigen_vor_anmeldung',
            'Veranstatlung schon auflisten bevor der Anmeldezeitraum aktiv ist.'
        ), search_field: 1);
        $this->addField(new \BayCMS\Field\Number(
            $context,
            'max_anzahl',
            'Maximale Anzahl',
            help: 'Achtung! Das Hochsetzen der Maximalzahl bei Teilnehmern auf der Warteliste, führt zu freien Plätzen. Überbuchen Sie besser die Veranstaltung (Wartelistenplatz löschen - richtigen Platz buchen)'
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'waitlist',
            'Mit Warteliste'
        ));
        $this->addField(new \BayCMS\Field\Number(
            $context,
            'min_geld',
            'Notwendiges Guthaben'
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'id_gkat',
            'in Kategorie',
            db_query: "select id,non_empty(de,en) as description from baydoc_gkat order by 2"
        ));

        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'baydoc',
            'Für Promovierende'
        ), search_field: 1);

        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'postdoc',
            'Für Postdocs'
        ), search_field: 1);
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'zert_d',
            'Zertifikatvorlage für Doktoranden',
            accept: 'application/pdf'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'zert_p',
            'Zertifikatvorlage für Postdocs',
            accept: 'application/pdf'
        ));




    }
}