<?php

namespace BayDOC\Page\Admin;


class Super extends \BayCMS\Fieldset\Form
{
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        if ($context->getPower() <= 1000) {
            $p = new \BayCMS\Page\ErrorPage($context, 401, 'Access denied. Only super users are allowed to use this class.');
            $p->page();
        }
        parent::__construct($context, qs: 'tab=' . ($_GET['tab'] ?? 'ef15'), submit: 'ausführen');
    }

    private function checkForm()
    {
        if (($_GET['aktion'] ?? false) == 'save') {
            if ($this->setValues($_POST)) {
                unset($_GET['aktion']);
                $GLOBALS['TE']->printMessage("Bitte füllen Sie das Formular vollständig aus", 'danger');
            }
        }
        if (!isset($_GET['aktion'])) {
            echo $this->getForm('Aktion');
            return 1;
        }
        return 0;
    }


    private function ef15()
    {
        echo '<h3>Setzen von Immatrikulation (EF15) über Liste von Matrikel-Nummern</h3>';
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'mnr',
            'Liste von Matrikelnummern',
            non_empty: 1,
            help: 'Bitte nur eine Matrikelnummer pro Zeile'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_query($this->context->getRwDbConn(), "update baydoc set hstatg_immatrikuliert=false");
        pg_prepare($this->context->getRwDbConn(), "set_ef15", 'update baydoc set hstatg_immatrikuliert=true where mnr=$1');
        echo "<h3>Alle Doktoranden auf nicht immatrikuliert gesetzt</h3>";
        $mnr = preg_split("/\n|\r\n/", $_POST['mnr']);
        $found = [];
        $not_found = [];
        for ($i = 0; $i < count($mnr); $i++) {
            if (is_numeric($mnr[$i])) {
                $res = pg_execute($this->context->getRwDbConn(), 'set_ef15', [$mnr[$i]]);
                if (pg_affected_rows($res))
                    $found[] = $mnr[$i];
                else
                    $not_found[] = $mnr[$i];
            } else
                $not_found[] = $mnr[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>" . count($found) . " Doktoranden auf immatrikuliert gesetzt</h3><h3>" . count($not_found) . " Matrikelnummern nicht gefunden:</h3>
 <p>";
        echo implode("<br/>", $not_found);
        echo "</p>";

    }

    private function ef16()
    {
        echo '<h3>Setzen von Teilnahme an strukturiertem Promotionsprogramm (EF16)</h3>';

        $this->addField(new \BayCMS\Field\SelectMulti(
            $this->context,
            'pp',
            'Promotionsprogramm',
            non_empty: 1,
            db_query: "select l2.id, l1.de||': '||non_empty(l2.de,l2.en) as description from
            Lehrstuhl l1, lehrstuhl l2, gehoert_zu g where
            l1.de in ('BIGSAS', 'BayKULT', 'BayNAT', 'BayREW') and g.id_parent=l1.id and g.id_lehr=l2.id
            order by 2"
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $this->context,
            'reset',
            'Alle Doktoranden zurücksetzen'
        ));
        if ($this->checkForm())
            return;

        //Save
        pg_query($this->context->getRwDbConn(), 'begin');
        if ($_POST['reset'] == 't') {
            $res = pg_query($this->context->getRwDbConn(), "update baydoc set hstatg_promprog=false");
            $GLOBALS['TE']->printMessage("Alle Doktoranden auf keine strukturierte Promotion gesetzt");
        }
        $num = 0;
        if (is_array($_POST['pp'])) {
            pg_prepare($this->context->getRwDbConn(), 'set_pp', 'update baydoc set hstatg_promprog=true where id_lehr=$1');
            for ($i = 0; $i < count($_POST['pp']); $i++) {
                $res = pg_execute($this->context->getRwDbConn(), 'set_pp', [$_POST['pp'][$i]]);
                $num += pg_affected_rows($res);
            }
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        $GLOBALS['TE']->printMessage("$num Doktoranden auf Teilnahme an strukturiertem Promotionsprogramm gesetzt");

    }

    private function ef17()
    {
        echo '<h3>Setzen von Beschäftigungsverhältnis an der Hochschule der Promotion (EF17)
        über Liste von VIVA-Nummern</h3>';
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'nr',
            'Liste mit Viva-Nummern',
            non_empty: 1,
            help: 'Bitte nur eine Matrikelnummer pro Zeile'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_query($this->context->getRwDbConn(), "update baydoc set hstatg_beschaeftigt=false");
        pg_prepare($this->context->getRwDbConn(), "set_ef17", 'update baydoc set hstatg_beschaeftigt=true where viva_nr=$1');
        echo "<h3>Alle Doktoranden auf nicht beschäftigt gesetzt</h3>";
        $mnr = preg_split("/\n|\r\n/", $_POST['nr']);
        $found = [];
        $not_found = [];
        for ($i = 0; $i < count($mnr); $i++) {
            if (is_numeric($mnr[$i])) {
                $res = pg_execute($this->context->getRwDbConn(), 'set_ef17', [$mnr[$i]]);
                if (pg_affected_rows($res))
                    $found[] = $mnr[$i];
                else
                    $not_found[] = $mnr[$i];
            } else
                $not_found[] = $mnr[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>" . count($found) . " Doktoranden auf beschäftigt gesetzt</h3><h3>" . count($not_found) . " Viva-Nummern nicht gefunden:</h3>
<p>";
        echo implode("<br/>", $not_found);
        echo "</p>";
    }


    private function mnr2()
    {
        echo '<h3>Setzen von Matrikel-Nummern über Liste ID + MATRIKELNUMMER</h3>';
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'mnr',
            'Liste mit ID + Matrikelnummer',
            non_empty: 1,
            help: 'Bitte nur eine ID+Matrikelnummer pro Zeile und unbedingt Reihenfolge beachten: ID zuerst!'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_prepare($this->context->getRwDbConn(), "find_id", 'select id from baydoc where id=$1');
        pg_prepare($this->context->getRwDbConn(), "set_mnr", 'update baydoc set mnr=$1 where id=$2');
        $mnr = preg_split("/\n|\r\n/", $_POST['mnr']);
        $found = [];
        $not_found = [];
        $no_change = [];
        $m = [];
        for ($i = 0; $i < count($mnr); $i++) {
            if (preg_match("/([0-9]+)[\t; ]+([0-9]+)/", $mnr[$i], $m)) {
                if (pg_num_rows(pg_execute($this->context->getRwDbConn(), "find_id", [$m[1]]))) {
                    $res = pg_execute($this->context->getRwDbConn(), 'set_mnr', [$m[2], $m[1]]);
                    if (pg_affected_rows($res))
                        $found[] = $mnr[$i];
                    else
                        $no_change[] = $mnr[$i];
                } else
                    $not_found[] = $mnr[$i];
            } else
                $not_found[] = $mnr[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>Für " . count($found) . " Doktoranden wurde die Matrikelnummer gesetzt</h3>
<h3>Für " . count($no_change) . " Doktoranden ergab sich keine Änderung</h3>
<h3>" . count($not_found) . " Doktoranden wurden nicht gefunden oder das Format war ungültig:</h3>
<p>";
        echo implode("<br/>", $not_found);
        echo "</p>";
    }

    private function viva2()
    {
        echo '<h3>Setzen von VIVA-Nummern über Liste ID + VIVA-NUMMER</h3>';
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'viva',
            'Liste mit ID + VIVA-Nummer',
            non_empty: 1,
            help: 'Bitte nur eine ID+VIVA-Nummer pro Zeile und unbedingt Reihenfolge beachten: ID zuerst!'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_prepare($this->context->getRwDbConn(), "find_id", 'select id from baydoc where id=$1');
        pg_prepare($this->context->getRwDbConn(), "set_vnr", 'update baydoc set viva_nr=$1 where id=$2');
        $vnr = preg_split("/\n|\r\n/", $_POST['viva']);
        $found = [];
        $not_found = [];
        $no_change = [];
        $m = [];
        for ($i = 0; $i < count($vnr); $i++) {
            if (preg_match("/([0-9]+)[\t; ]+([0-9]+)/", $vnr[$i], $m)) {
                if (pg_num_rows(pg_execute($this->context->getRwDbConn(), "find_id", [$m[1]]))) {
                    $res = pg_execute($this->context->getRwDbConn(), 'set_vnr', [$m[2], $m[1]]);
                    if (pg_affected_rows($res))
                        $found[] = $vnr[$i];
                    else
                        $no_change[] = $vnr[$i];
                } else
                    $not_found[] = $vnr[$i];
            } else
                $not_found[] = $vnr[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>Für " . count($found) . " Doktoranden wurde die VIVA-Nummer gesetzt</h3>
    <h3>Für " . count($no_change) . " Doktoranden ergab sich keine Änderung</h3>
    <h3>" . count($not_found) . " Doktoranden wurden nicht gefunden oder das Format war ungültig:</h3>
    <p>";
        echo implode("<br/>", $not_found);
        echo "</p>";

    }

    private function hstatg()
    {
        echo '<h3>Setzen der Felder für die Promovierenden Statistik</h3>';
        $this->addField(new \BayCMS\Field\NumSelect(
            $this->context,
            'jahr',
            'Meldejahr',
            non_empty: 1,
            null: 1,
            min: 2020,
            max: min(date('Y') - 1, 2027)
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'csv',
            'Melde CSV-Datei mit IDs',
            non_empty: 1,
            help: 'Bitte den CSV-Export der Meldung mit der ID-Spalte'
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $this->context,
            'ef13',
            'Überschreibe EF13'
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $this->context,
            'ef14',
            'Überschreibe EF14'
        ));
        if ($this->checkForm())
            return;
        if (
            !strstr($_POST['csv'], '"ID";"Berichtsland (EF01) - fix 09";"Berichtsjahr (EF02)";"Hochschule der Promotion (EF03) - fix 0510";"Paginiernummer (EF04)";"Geschlecht (EF05)";"Geburtsdatum (EF06U1)";"Geburtsdatum (EF06U2)";"Geburtsdatum (EF06U3)";"Vorname - 4 Zeichen (EF07)";"Staatsangehörigkeit (EF08)";"Weitere Staatsangehörigkeit (EF09)";"Art der Promotion - default 01 (EF10)";"Promotionsfach (EF11)";"Art der Registrierung als Promovierender (EF12)";"Promotionsbeginn (EF13U1)";"Promotionsbeginn (EF13U2)";"Ende der Promotion (EF14U1)";"Ende der Promotion (EF14U2)";"Immatrikulation (EF15)";"Teilnahme an einem strukturierten Promotionsprogramm (EF16)";"Beschäftigungsverhältnis an der Hochschule der Promotion (EF17)";"Art der Dissertation - default 1 (EF18)";"Hochschule (EF19)";"Staat der HS (EF20)";"Semester (EF21)";"Jahr der Ersteinschreibung (EF22)";"Zur Promotion berechtigende Abschlussprüfung wurde/wurde noch nicht abgelegt (EF23) - fix 1";"Hochschule (EF24)";"Staat der HS (EF25)";"Art der Prüfung (EF26)";"1. Studienfach (EF27)";"Monat des Abschlusses (EF28)";"Jahr des Abschlusses (EF29)";"Gesamtnote des Abschlusses (EF30)";"Jahr des ersten Erwerbs einer HZB (EF31)";"Art der ersten HZB (EF32)";"Bundesland (EF33U1)";"Kreis/Land (EF33U2)"')
            && !strstr($_POST['csv'], '"ID";"Berichtsland (EF01) - fix 09";"Berichtsjahr (EF02)";"Hochschule der Promotion (EF03) - 0510/0511";"Paginiernummer (EF04)";"Geschlecht (EF05)";"Geburtsdatum (EF06U1)";"Geburtsdatum (EF06U2)";"Geburtsdatum (EF06U3)";"Vorname - 4 Zeichen (EF07)";"Staatsangehörigkeit (EF08)";"Weitere Staatsangehörigkeit (EF09)";"Art der Promotion - default 01 (EF10)";"Promotionsfach (EF11)";"Art der Registrierung als Promovierender (EF12)";"Promotionsbeginn (EF13U1)";"Promotionsbeginn (EF13U2)";"Ende der Promotion (EF14U1)";"Ende der Promotion (EF14U2)";"Immatrikulation (EF15)";"Teilnahme an einem strukturierten Promotionsprogramm (EF16)";"Beschäftigungsverhältnis an der Hochschule der Promotion (EF17)";"Art der Dissertation - default 1 (EF18)";"Hochschule (EF19)";"Staat der HS (EF20)";"Semester (EF21)";"Jahr der Ersteinschreibung (EF22)";"Zur Promotion berechtigende Abschlussprüfung wurde/wurde noch nicht abgelegt (EF23) - fix 1";"Hochschule (EF24)";"Staat der HS (EF25)";"Art der Prüfung (EF26)";"1. Studienfach (EF27)";"Monat des Abschlusses (EF28)";"Jahr des Abschlusses (EF29)";"Gesamtnote des Abschlusses (EF30)";"Jahr des ersten Erwerbs einer HZB (EF31)";"Art der ersten HZB (EF32)";"Bundesland (EF33U1)";"Kreis/Land (EF33U2)"')
            && !strstr($_POST['csv'], 'ID;Berichtsland (EF01) - fix 09;Berichtsjahr (EF02);Hochschule der Promotion (EF03) - fix 0510;Paginiernummer (EF04);Geschlecht (EF05);Geburtsdatum (EF06U1);Geburtsdatum (EF06U2);Geburtsdatum (EF06U3);Vorname - 4 Zeichen (EF07);Staatsangehörigkeit (EF08);Weitere Staatsangehörigkeit (EF09);Art der Promotion - default 01 (EF10);Promotionsfach (EF11);Art der Registrierung als Promovierender (EF12);Promotionsbeginn (EF13U1);Promotionsbeginn (EF13U2);Ende der Promotion (EF14U1);Ende der Promotion (EF14U2);Immatrikulation (EF15);Teilnahme an einem strukturierten Promotionsprogramm (EF16);Beschäftigungsverhältnis an der Hochschule der Promotion (EF17);Art der Dissertation - default 1 (EF18);Hochschule (EF19);Staat der HS (EF20);Semester (EF21);Jahr der Ersteinschreibung (EF22);Zur Promotion berechtigende Abschlussprüfung wurde/wurde noch nicht abgelegt (EF23) - fix 1;Hochschule (EF24);Staat der HS (EF25);Art der Prüfung (EF26);1. Studienfach (EF27);Monat des Abschlusses (EF28);Jahr des Abschlusses (EF29);Gesamtnote des Abschlusses (EF30);Jahr des ersten Erwerbs einer HZB (EF31);Art der ersten HZB (EF32);Bundesland (EF33U1);Kreis/Land (EF33U2);;;;;')
            && !strstr($_POST['csv'], 'ID;Berichtsland (EF01) - fix 09;Berichtsjahr (EF02);Hochschule der Promotion (EF03) - 0510/0511;Paginiernummer (EF04);Geschlecht (EF05);Geburtsdatum (EF06U1);Geburtsdatum (EF06U2);Geburtsdatum (EF06U3);Vorname - 4 Zeichen (EF07);Staatsangehörigkeit (EF08);Weitere Staatsangehörigkeit (EF09);Art der Promotion - default 01 (EF10);Promotionsfach (EF11);Art der Registrierung als Promovierender (EF12);Promotionsbeginn (EF13U1);Promotionsbeginn (EF13U2);Ende der Promotion (EF14U1);Ende der Promotion (EF14U2);Immatrikulation (EF15);Teilnahme an einem strukturierten Promotionsprogramm (EF16);Beschäftigungsverhältnis an der Hochschule der Promotion (EF17);Art der Dissertation - default 1 (EF18);Hochschule (EF19);Staat der HS (EF20);Semester (EF21);Jahr der Ersteinschreibung (EF22);Zur Promotion berechtigende Abschlussprüfung wurde/wurde noch nicht abgelegt (EF23) - fix 1;Hochschule (EF24);Staat der HS (EF25);Art der Prüfung (EF26);1. Studienfach (EF27);Monat des Abschlusses (EF28);Jahr des Abschlusses (EF29);Gesamtnote des Abschlusses (EF30);Jahr des ersten Erwerbs einer HZB (EF31);Art der ersten HZB (EF32);Bundesland (EF33U1);Kreis/Land (EF33U2);;;;;')
        ) {
            $GLOBALS['TE']->printMessage("Keine gültige CSV-Datei", 'danger');
            echo $this->getForm('Aktion');
            return;
        }

        pg_query($this->context->getRwDbConn(), 'begin');
        pg_prepare($this->context->getRwDbConn(), "set_paginiernr", 'update baydoc set hstatg' . $_POST['jahr'] . '=$1 where id=$2');
        pg_prepare($this->context->getRwDbConn(), "set_ef13", 'update baydoc set hstatg_ef13=$1 where id=$2 and (hstatg_ef13 is null or hstatg_ef13=\'\' or 
        \'' . $_POST['ef13'] . '\'=\'t\')');
        pg_prepare($this->context->getRwDbConn(), "set_ef14", 'update baydoc set hstatg_ef14=$1 where id=$2 and (hstatg_ef14 is null or hstatg_ef14=\'\' or 
        \'' . $_POST['ef14'] . '\'=\'t\')');
        $count_pag = 0;
        $count_ef13 = 0;
        $count_ef14 = 0;
        $lines = explode("\n", $_POST['csv']);
        for ($i = 1; $i < count($lines); $i++) {
            $l = str_getcsv($lines[$i], ";");
            $id = $l[0];
            $p = trim($l[4]);
            $ef13 = "$l[15]$l[16]";
            $ef14 = "$l[17]$l[18]";
            if (!$ef14 && $_POST['ef14'] == "t")
                $ef14 = null;
            $count_pag += pg_affected_rows(pg_execute($this->context->getRwDbConn(), 'set_paginiernr', [$p, $id]));
            $count_ef13 += pg_affected_rows(pg_execute($this->context->getRwDbConn(), 'set_ef13', [$ef13, $id]));
            if ($ef14 || $_POST['ef14'] == 't')
                $count_ef14 += pg_affected_rows(pg_execute($this->context->getRwDbConn(), 'set_ef14', [$ef14, $id]));
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>Paginiernummer für $count_pag Doktoranden gesetzt</h3>
<h3>EF13 für $count_ef13 Doktoranden gesetzt</h3>
<h3>EF14 für $count_ef14 Doktoranden gesetzt</h3>

";
    }

    private function pruef()
    {
        echo '<h3>Setzen der Felder für die Prüfungsstatistik Statistik</h3>';
        $y = 2020;
        $s_values = [];
        while ($y <= date('Y')) {
            $s_values[] = 'SS ' . $y;
            $s_values[] = 'WS ' . $y . '/' . ($y - 1999);
            $y++;
        }
        $this->addField(new \BayCMS\Field\Select(
            $this->context,
            'jahr',
            'Meldejahr',
            non_empty: 1,
            null: 1,
            values: $s_values
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'csv',
            'Liste von ID + Paginiernummer',
            non_empty: 1,
            help: 'Bitte nur eine ID+Paginierummer pro Zeile und unbedingt Reihenfolge beachten: ID zuerst!'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_prepare($this->context->getRwDbConn(), "set_paginiernr", 'update baydoc set hstatg_mp_nummer=$2,hstatg_mp_date=$1 where id=$3');
        $csv = preg_split("/\n|\r\n/", $_POST['csv']);
        $found = [];
        $not_found = [];
        $m = [];
        for ($i = 0; $i < count($csv); $i++) {
            if (preg_match("/([0-9]+)[\t; ]+([0-9]+)/", $csv[$i], $m)) {
                $res = pg_execute($this->context->getRwDbConn(), 'set_paginiernr', [$_POST['jahr'], $m[2], $m[1]]);
                if (pg_affected_rows($res))
                    $found[] = $csv[$i];
                else
                    $not_found[] = $csv[$i];
            } else
                $not_found[] = $csv[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>Für " . count($found) . " Doktoranden wurde die Paginier-Nummer gesetzt</h3><h3>" . count($not_found) . " Doktoranden wurden nicht gefunden
     oder das Format war ungültig:</h3>
    <p>";
        echo implode("<br/>", $not_found);
        echo "</p>";

    }

    public function co_ausbildung()
    {
        echo '<h3>Setzen von Ausbildungsdaten aus CampusOnline</h3>';
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'data',
            'Liste von Matrikelnummer + EF117 + EF118 + EF119(U1) + EF119(U2)',
            non_empty: 1,
            help: 'Bitte nur ein Datensatz pro Zeile und unbedingt Reihenfolge beachten!'
        ));
        if ($this->checkForm())
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_prepare($this->context->getRwDbConn(), "find_id", 'select id from baydoc where mnr=$1');
        pg_prepare($this->context->getRwDbConn(), "set_ausbildung_de", 'update baydoc set hstatg_hzb_jahr=$2,hstatg_hzb_art=stat_hr.id,
hstatg_hzb_kreis=stat_kreise.id,hstatg_hzb_land=stat_laender.id
from stat_hr, stat_kreise, stat_laender where baydoc.mnr=$1 and stat_hr.schluessel=to_char($3::int,\'00FM\') 
and stat_laender.schluessel=\'000\' and stat_kreise.schluessel=to_char($4::int,\'00FM\')||to_char($5::int,\' 0 00FM\')');
        pg_prepare($this->context->getRwDbConn(), "set_ausbildung_notde", 'update baydoc set hstatg_hzb_jahr=$2,hstatg_hzb_art=stat_hr.id,
hstatg_hzb_land=stat_laender.id, hstatg_hzb_kreis=null
from stat_hr, stat_laender where baydoc.mnr=$1 and stat_hr.schluessel=to_char($3::int,\'00FM\')
and stat_laender.schluessel=to_char($4::int,\'000FM\')');
        $data = preg_split("/\n|\r\n/", $_POST['data']);
        $found = [];
        $not_found = [];
        $no_change = [];
        $m = [];
        for ($i = 0; $i < count($data); $i++) {
            if (preg_match("/([0-9]+)[\t; ]+([0-9]+)[\t; ]+([0-9]+)[\t; ]+([0-9]+)[\t; ]+([0-9]+)/", $data[$i], $m)) {
                if (pg_num_rows(pg_execute($this->context->getRwDbConn(), "find_id", [$m[1]]))) {
                    if ($m[4] == '99')
                        $res = pg_execute($this->context->getRwDbConn(), 'set_ausbildung_notde', [$m[1], $m[2], $m[3], $m[5]]);
                    else
                        $res = pg_execute($this->context->getRwDbConn(), 'set_ausbildung_de', [$m[1], $m[2], $m[3], $m[4], $m[5]]);
                    if (pg_affected_rows($res))
                        $found[] = $data[$i];
                    else
                        $no_change[] = $data[$i];
                } else
                    $not_found[] = $data[$i];
            } else
                $not_found[] = $data[$i];
        }
        pg_query($this->context->getRwDbConn(), 'commit');
        echo "<h3>Für " . count($found) . " Doktoranden wurde die Daten geändert.</h3>
<h3>Für " . count($no_change) . " Doktoranden ergab sich keine Änderung.</h3>
<h3>" . count($not_found) . " Doktoranden wurden nicht gefunden oder das Format war ungültig:</h3>
<p>";
        echo implode("<br/>", $not_found);
        echo "</p>";
    }

    private function dublettenNameById($id, $table)
    {
        $query = $table == 'bayprof' ? "trim(nname),trim(vname)" : "trim(name),trim(vorname)";
        $res = pg_query_params(
            $this->context->getDbConn(),
            "select $query from $table where id=\$1",
            [$id]
        );
        return pg_fetch_row($res, 0);
    }
    private function dubletten($table = 'baydoc')
    {
        if ($_GET['id_standard']??false) {
            [$name, $vorname] = $this->dublettenNameById($_GET['id_standard'], $table);
            echo "<h3>$name, $vorname</h3><a href=\"../gru/objekt_detail.php?id_obj=$_GET[id_standard]\">Objekt Details</a><br>";

            pg_query($this->context->getRwDbConn(), "begin");

            if ($table == 'bayprof')
                $query = "trim(t.nname)='$name' and trim(t.vname)='$vorname'";
            else
                $query = "trim(t.name)='$name' and trim(t.vorname)='$vorname' and not t.antrag";
            $res = pg_query_params(
                $this->context->getRwDbConn(),
                "select t.id from $table t, objekt o 
        where t.id=o.id and $query and o.geloscht is null and t.id!=\$1",
                [$_GET['id_standard']]
            );



            for ($i = 0; $i < pg_num_rows($res); $i++) {
                $r = pg_fetch_array($res, $i);
                echo "<h3>Bearbeite $r[id]</h3>\n";
                if ($table == 'bayprof') {
                    $bm = array('b', 'm1', 'm2', 'm3');
                    $bm_names = array('1. Betreuer(in)', 'Mentor/Betreuer(in)', 'Mentor/Betreuer(in)', 'Mentor/Betreuer(in)');
                    for ($j = 0; $j < count($bm); $j++) {
                        echo "Übertrage $bm_names[$j] ";
                        $res2 = pg_query($this->context->getRwDbConn(), "select count(*) from baydoc where $bm[$j]_id=$r[id]");
                        $r2 = pg_fetch_row($res2, 0);
                        echo "$r2[0]<br>\n";
                        if ($r2[0]) {
                            pg_query_params(
                                $this->context->getRwDbConn(),
                                "update baydoc set $bm[$j]_id=\$1 where $bm[$j]_id=$r[id]",
                                [$_GET['id_standard']]
                            );
                        }
                    }
                }
                echo "Verschiebe E-Mails: ";
                $res2 = pg_query($this->context->getRwDbConn(), "select count(*) from qb_mails where id_obj=$r[id]");
                $r2 = pg_fetch_row($res2, 0);
                echo "$r2[0]<br>\n";
                if ($r2[0]) {
                    pg_query_params(
                        $this->context->getRwDbConn(),
                        "update qb_mails set id_obj=\$1 where id_obj=$r[id]",
                        [$_GET['id_standard']]
                    );
                }

                echo "Kopiere Verweise von: ";
                $res2 = pg_query($this->context->getRwDbConn(), "select count(*) from verweis where id_von=$r[id]");
                $r2 = pg_fetch_row($res2, 0);
                echo "$r2[0]<br>\n";
                if ($r2[0]) {
                    pg_query_params(
                        $this->context->getRwDbConn(),
                        "insert into verweis(id_von,id_auf,ordnung) select \$1,id_auf,ordnung from verweis 
                     where id_von=$r[id] except select \$1,id_auf,ordnung from verweis where id_von=\$1",
                        [$_GET['id_standard']]
                    );
                }

                echo "Kopiere Zuordnung: ";
                $res2 = pg_query($this->context->getRwDbConn(), "select count(*) from objekt_ls where id_obj=$r[id]");
                $r2 = pg_fetch_row($res2, 0);
                echo "$r2[0]<br>\n";
                if ($r2[0]) {
                    pg_query_params(
                        $this->context->getRwDbConn(),
                        "insert into objekt_ls(id_obj,id_lehr,sichtbar,nur_lesen)  
                    select \$1,id_lehr,true,true from objekt_ls where id_obj=$r[id] 
                    except select \$1,id_lehr,true,true from objekt_ls where id_obj=\$1",
                        [$_GET['id_standard']]
                    );
                }

                echo "lösche Eintrag: <br>\n";
                pg_query(
                    $this->context->getRwDbConn(),
                    "update objekt set geloescht=now() where id=$r[id]"
                );

            }
            pg_query($this->context->getRwDbConn(), "commit");
            return;
        }


        if ($_GET['id'] ?? false) {
            [$name, $vorname] = $this->dublettenNameById($_GET['id'], $table);
            echo "<h4>$name, $vorname</h4>\n";
            $list = new \BayCMS\Fieldset\BayCMSList(
                $this->context,
                "$table t, objekt o",
                "t.id=o.id and o.geloescht is null and " . ($table == 'bayprof' ?
                    "trim(t.nname)='$name' and trim(t.vname)='$vorname'" :
                    "not t.antrag and trim(t.name)='$name' and trim(t.vorname)='$vorname'"),
                qs: "tab=$_GET[tab]&id=$_GET[id]"
            );
            $link = './';
            $link_name = "t.vorname||' '||t.name";
            if ($table == 'bayprof') {
                $link = './bayprof.php';
                $link_name = "t.vname||' '||t.nname";
            }
            if ($table == 'postdoc')
                $link = '../postdoc/';
            $list->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'Name',
                sql: "'<a href=\"$link?id='||t.id||'\">'||$link_name||'</a>'"
            ));
            if ($table == 'bayprof') {
                $list->addField(new \BayCMS\Field\TextInput(
                    $this->context,
                    'Doktoranden',
                    sql: "baydoc_get_docs(t.id,'b',false)"
                ));
                $list->addField(new \BayCMS\Field\TextInput(
                    $this->context,
                    'Mentorate',
                    sql: "baydoc_get_docs(t.id,'m',false)"
                ));
            }
            $list->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'Aktion',
                sql: "'<a href=\"?tab=$_GET[tab]&id_standard='||t.id||'\">Als Standard setzen und andere löschen</a>'"
            ));
            echo $list->getTable();
            return;

        }

        $list = new \BayCMS\Fieldset\BayCMSList(
            $this->context,
            from: $table == 'bayprof' ?
            "(select count(*), first_id(m.id) as id, trim(m.nname) as nname, trim(m.vname) as vname 
		from bayprof m, objekt o where o.id=m.id and o.geloescht is null group by trim(nname),trim(vname)) a" :
            "(select count(*), first_id(m.id) as id, trim(m.name) as name, trim(m.vorname) as vorname
			from " . $table . " m, objekt o where o.id=m.id and o.geloescht is null and not m.antrag 
			group by trim(name),trim(vorname),gdatum) a",
            where: 'count>1',
            id_query: 'id',
            order_by: $table == 'bayprof' ? ['count', 'nname', 'vname'] : ['count', 'name', 'vorname'],
            prefix: '',
            qs: 'tab=' . ($_GET['tab'] ?? ''),
            jquery_row_click: 1
        );
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'Count'
        ));
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            $table == 'bayprof' ? 'nname' : 'name',
            'Nachname'
        ));
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            $table == 'bayprof' ? 'vname' : 'vorname',
            'Vorname'
        ));
        echo $list->getTable();

    }

    private function dub_d()
    {
        $this->dubletten();
    }

    private function dub_p()
    {
        $this->dubletten('bayprof');
    }

    private function dub_pd()
    {
        $this->dubletten('postdoc');
    }



    public function page()
    {
        $this->context->printHeader();
        $nav = new \BayCMS\Util\TabNavigation(
            $this->context,
            ['ef15', 'ef16', 'ef17', 'mnr2', 'viva2', 'pruef', 'hstatg', 'co_ausbildung', 'dub_d', 'dub_pd', 'dub_p'],
            [
                'EF15',
                'EF16',
                'EF17',
                'Matrikelnummer',
                'VIVA-Nummern',
                'Prüfungsstatistik',
                'Promovierendenstatistik',
                'CampusOnline Ausbildung',
                'Dubletten Promovierende',
                'Dubletten Postdocs',
                'Dubletten Professoren'
            ]
        );

        echo $nav->getNavigation();
        $tab = $_GET['tab'] ?? 'ef15';
        $this->$tab();
        $this->context->printFooter();
    }
}