<?php

namespace BayDOC\QB;

class Base extends \BayCMS\Fieldset\QueryBuilder
{
    protected array $left_hash;
    protected array $from_hash;

    protected function getLeftJoinName($l)
    {
        if (!isset($this->left_hash[$l]))
            $this->left_hash[$l] = 0;
        $this->left_hash[$l]++;
        return $l . $this->left_hash[$l];
    }

    protected function addTab(\BayCMS\Fieldset\Fieldset $t, $tab, $class, $id = false)
    {
        if ($id)
            $this->addField(new \BayCMS\Field\Number(
                $this->context,
                'id',
                'ID',
                div_id: $tab
            ));
        foreach ($t->getFields() as $f) {
            $l = $f->get('left_join');
            $left = $f->get('left_join_name');
            if (!$left)
                $left = $this->getLeftJoinName($l);

            switch ($l) {
                case 'l12':
                    $this->list_from .= " left outer join lehrstuhl prom_prog on prom_prog.id=t.id_lehr 
                    left join gehoert_zu gz on prom_prog.id=gz.id_lehr
                    left outer join lehrstuhl fak on fak.id=gz.id_parent";
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        'einheit_de',
                        'Einheit (deutsch)',
                        sql: 'prom_prog.de',
                        div_id: $tab
                    ));
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        'fakultaet_de',
                        'Fakultät (deutsch)',
                        sql: 'fak.de',
                        div_id: $tab
                    ));

                    break;
                case 'user':
                    $this->list_from .= " left outer join benutzer $left on t." . $f->name . "=$left.id";
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        $f->name,
                        $f->description,
                        sql: "$left.login",
                        div_id: $tab
                    ));
                    break;
                case 'bayprof':
                    $this->list_from .= " left outer join bayprof $left on t." . $f->name . "=$left.id";
                    $nr = '';
                    if (strstr($f->name, 'm')) {
                        switch ($f->name) {
                            case 'm1_id':
                                $nr = 'I. ';
                                break;
                            case 'm2_id':
                                $nr = 'II. ';
                                break;
                            case 'm3_id':
                                $nr = 'III. ';
                                break;
                        }
                    }
                    foreach (['anrede', 'titel', 'vname', 'nname', 'email', 'fakultaet', 'lehrstuhl', 'id'] as $what) {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $f->name . "_" . $what,
                            $nr.$f->description . ' (' . ucfirst($what) . ')',
                            sql: $left . "." . $what,
                            div_id: $tab
                        ));
                    }
                    break;
                case 'stat_art':
                case 'stat_hr':
                case 'stat_kreise':
                case 'stat_laender':
                case 'stat_hs':
                case 'baydoc_stgfach':
                case 'laender':
                    if (!isset($this->from_hash[$left])) {
                        $this->from_hash[$left] = 1;
                        if ($l == 'laender') {
                            $l = 'stat_laender';
                            $this->list_from .= " left outer join $l $left on t." . $f->name . "=$left.name";
                        } else
                            $this->list_from .= " left outer join $l $left on t." . $f->name . "=$left.id";
                    }
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        $tab . '_' . $f->name . "_schluessel",
                        $f->description . ' (Schlüssel)',
                        sql: $left . "." . ($l == 'baydoc_stgfach' ? 'signatur' : 'schluessel'),
                        div_id: $tab
                    ));
                    if ($l == 'stat_art') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_gruppe",
                            $f->description . ' (Gruppe)',
                            sql: "$left.gruppe",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_pruef",
                            $f->description . ' (Prüfung)',
                            sql: "$left.pruef",
                            div_id: $tab
                        ));
                    } else if ($l == 'stat_kreise') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_bundesland",
                            $f->description . ' (Bundesland)',
                            sql: "$left.bundesland",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_kreis",
                            $f->description . ' (Kreis)',
                            sql: "$left.kreis",
                            div_id: $tab
                        ));
                    } else if ($l == 'stat_hs') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_bundesland",
                            $f->description . ' (Bundesland)',
                            sql: "$left.bundesland",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_stadt",
                            $f->description . ' (Stadt)',
                            sql: "$left.stadt",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_name",
                            $f->description . ' (Name)',
                            sql: "$left.name",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_typ",
                            $f->description . ' (Typ)',
                            sql: "$left.typ",
                            div_id: $tab
                        ));
                    } else if ($l == 'stat_laender') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_kennung",
                            $f->description . ' (Kennung)',
                            sql: "$left.kennung",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_name",
                            $f->description . ' (Name)',
                            sql: "$left.name",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_eu",
                            $f->description . ' (EU)',
                            sql: "$left.eu",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_eu_gleich",
                            $f->description . ' (EU gleichgestellt)',
                            sql: "$left.eu_gleich",
                            div_id: $tab
                        ));
                    } else if ($l == 'baydoc_stgfach') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_gr",
                            $f->description . ' (Signatur Gruppe)',
                            sql: "$left.signatur_gr",
                            div_id: $tab
                        ));
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_name",
                            $f->description . ' (Name)',
                            sql: "$left.name",
                            div_id: $tab
                        ));
                    } else if ($l == 'stat_hr') {
                        $this->addField(new \BayCMS\Field\TextInput(
                            $this->context,
                            $tab . '_' . $f->name . "_schule",
                            $f->description . ' (Schule)',
                            sql: "$left.schule",
                            div_id: $tab
                        ));
                    }
                    break;
                case 'file':
                    $this->list_from .= " left outer join (select f.*,o.id_obj as id_parent from file f, objekt o
                    where f.id=o.id and f.de='" . addslashes($f->uname) . "') $left on $left.id_parent=t.id";
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        $tab . '_' . $f->name . "_name",
                        $f->description . ' (Download Link)',
                        sql: "'<a href=\"../../top/gru/get.php?id='||$left.id||'\">'||non_empty($left.de,$left.en)||'</a>'",
                        div_id: $tab
                    ));
                    $this->addField(new \BayCMS\Field\TextInput(
                        $this->context,
                        $tab . '_' . $f->name . "_mtime",
                        $f->description . ' (Änderungszeitpunkt)',
                        sql: "$left.mtime",
                        div_id: $tab
                    ));
                    break;
                case 'add_to_query':
                    $f->setDivID($tab);
                    $this->addField($f);
                    break;

                default:
                    if ($f->no_add_to_query)
                        continue 2;
                    $f = clone ($f);
                    $f->setDivID($tab);
                    $this->addField($f);
                    break;
            }



        }
    }

}