<?php

namespace BayDOC\QB;

/**
 * QB
 * Basetable: Buchungen (geld-table)
 */
class Buchung extends Base {
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            context: $context,
            table: 'baydoc',
            object: true,
            postfilter: array_merge(
                \BayDOC\Util\Filter::getPostfilterStatus($context),
                \BayDOC\Util\Filter::getPostfilterHStatG()
            ),
            row_click_query: 't.id',
            where: "geld.id_stud=t.id and s.id_stud=t.id and s.id_status=k.id and t.id=o.id and not t.antrag",
            email_fields: ['email', 'b_id_email', 'm1_id_email', 'm2_id_email', 'm3_id_email']
        );
        $this->mapper_class='\\BayDOC\\QB\\Mapper\\Buchung';

        $doc = new \BayDOC\Entry\Doc($context);

        $this->list_from = "baydoc_geld geld left outer join baydoc_gkat gk on geld.id_gkat=gk.id, baydoc_getstudstatus(" . $context->getOrgId() . ") s, baydoc_zulassungskat k, objekt_verwaltung" . $context->getOrgId() . " o, baydoc t";
        $tabs = [
            'Stamm' => 'Stammdaten',
            'Uni' => 'Ausbildung',
            'Betr' => 'Betreuer',
            'Prom' => 'Promotion',
            'Verfahren' => 'Verfahren',
            'Hstatg' => 'HStatG'
        ];
        $admin = \BayDOC\Util\AdminFields::getAdminFields($context->getOrgId());
        if ($admin !== null)
            $tabs['Admin'] = 'Admin';

        $this->left_hash = [];
        $this->from_hash = [];

        foreach ($tabs as $class => $tab) {
            $full_class = '\BayDOC\Tabs\Doc' . $class;
            $t = new $full_class($context, $doc);
            $this->addTab($t, $tab, $class, $class=='Stamm');
        } 
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Buchungstext',
            div_id:'Buchung',
            sql: 'geld.was'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Buchungsdatum',
            div_id:'Buchung',
            sql: 'geld.datum'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Buchungs_ID',
            div_id:'Buchung',
            sql: 'geld.id'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Kategorie',
            div_id:'Buchung',
            sql: "case when geld.kat=-1 then 'Gutschrift' when geld.kat=0 then 'Festlegung' when geld.kat=1 then 'Ausgabe' else 'unbekannt' end"
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Buchungsbetrag',
            div_id:'Buchung',
            sql: 'geld.betrag'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'Geldkategorie',
            div_id:'Buchung',
            sql: 'non_empty(gk.de,gk.en)'
        ));
         
       


    }


    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void{
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from baydoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /'.$this->context->getOrgLinkLang().'/admin/baydoc/?tab=geld&id=' . $_GET['id']);
                exit();
            }
        }
        parent::page($pre_content, $post_content);

    }
}