<?php

namespace BayDOC\QB;

/**
 * QB
 * Basetable: Dokoranden (baydoc)
 */
class Doc extends Base
{
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            context: $context,
            table: 'baydoc',
            object: true,
            postfilter: array_merge(
                \BayDOC\Util\Filter::getPostfilterStatus($context),
                \BayDOC\Util\Filter::getPostfilterHStatG()
            ),
            row_click_query: 't.id',
            where: "s.id_stud=t.id and s.id_status=k.id and t.id=o.id and not t.antrag",
            email_fields: ['email', 'b_id_email', 'm1_id_email', 'm2_id_email', 'm3_id_email']
        );
        $this->mapper_class = '\\BayDOC\\QB\\Mapper\\Doc';

        $doc = new \BayDOC\Entry\Doc($context);

        $this->list_from = "baydoc_getstudstatus(" . $context->getOrgId() . ") s, baydoc_zulassungskat k, objekt_verwaltung" . $context->getOrgId() . " o, baydoc t";
        $tabs = [
            'Stamm' => 'Stammdaten',
            'Uni' => 'Ausbildung',
            'Betr' => 'Betreuer',
            'Prom' => 'Promotion',
            'Verfahren' => 'Verfahren',
            'Hstatg' => 'HStatG'
        ];
        $admin = \BayDOC\Util\AdminFields::getAdminFields($context->getOrgId());
        if ($admin !== null)
            $tabs['Admin'] = 'Admin';

        $this->left_hash = [];
        $this->from_hash = [];

        foreach ($tabs as $class => $tab) {
            $full_class = '\BayDOC\Tabs\Doc' . $class;
            $t = new $full_class($context, $doc);
            $this->addTab($t, $tab, $class, $class == 'Stamm');

        } //End Tabs...
        $this->addEFHstatgTab();
        $this->addStatusTab();
        $this->addEventGeldTab();
        $this->addPubTab();
        $this->addUniOldTab();

        $this->addNavigationTab($this->t('PhDs', 'Promovierende'), $_SERVER['SCRIPT_NAME']);
        $this->addNavigationTab('Stapelverarbeitung', $_SERVER['SCRIPT_NAME'] . '/Run');
    }


    protected function addUniOldTab()
    {
        $felder = explode(" ", "uni_land uni_ort uni_name uni_typ uni_abschluss uni_abschluss_name uni_abschluss_datum");
        $f_namen = explode(",", "Land,Ort,Name der Einrichtung,Einrichtungstyp,Abschluss,Name des Abschlusses,Datum des Abschlusses");
        for ($i = 0; $i < count($felder); $i++) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                $felder[$i],
                $f_namen[$i],
                div_id: 'Uni (veraltet)'
            ));
        }
    }


    protected function addStatusTab()
    {
        //Status
        $res = pg_query(
            $this->context->getDbConn(),
            'select non_empty(de,en),id from baydoc_zulassungskat order by id'
        );
        $org_id = $this->context->getOrgId();
        for ($i = 0; $i < pg_num_rows($res); $i++) {
            $r = pg_fetch_array($res, $i);
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'status_datum' . $i,
                "Datum &quot;$r[0]&quot;",
                sql: "baydoc_getstatus_date(t.id,$org_id,$r[1])",
                div_id: 'Status'
            ));
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'status_tage_seit' . $i,
                "Tage seit &quot;$r[0]&quot;",
                sql: "now()::date-baydoc_getstatus_date(t.id,$org_id,$r[1])",
                div_id: 'Status'
            ));
        }
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'status_gs',
            "Graduate School (Antrag, Mitglied ...)",
            sql: "baydoc_gs_getstatus(t.id)",
            div_id: 'Status'
        ));

    }

    protected function addEventGeldTab()
    {
        $f = [];

        $f["e_events_de"] = ["baydoc_get_event(t.id,'de')", "Veranstaltungen (als Text, deutsch)"];
        $f["e_events_en"] = ["baydoc_get_event(t.id,'en')", "Veranstaltungen (als Text, englisch)"];
        $f["e_link"] = ["'<a href=\"/" . $this->context->getOrgLinkLang() . "/admin/baydoc/?id='||t.id||'&tab=event\">Details</a>'", "Link zu Veranstaltungsdetails"];



        if ($this->context->getOrgId() == 5001) {
            $f["g_guthaben"] = ["baydoc_get_geld(t.id,null)", "Guthaben"];
            $f["g_ausgaben"] = ["baydoc_get_geld(t.id,1)", "Ausgegeben"];
            $f["g_gutschrift"] = ["baydoc_get_geld(t.id,-1)", "Gutschrift"];
            $f["g_festlegung"] = ["baydoc_get_geld(t.id,0)", "Festlegung"];
            $f["g_link"] = ["'<a href=\"/" . $this->context->getOrgLinkLang() . "/admin/baydoc/?id='||t.id||'&tab=geld\">Details</a>'", "Link zu Finanzdetails"];
        }

        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'eg_' . $name,
                $v[1],
                sql: $v[0],
                div_id: preg_match('/^e/', $name) ? 'Events' : 'Geld'
            ));
        }

    }

    protected function addPubTab()
    {
        $f = [];

        $f["p_anz"] = ["baydoc_getpub_anz(t.id,true)", "Anzahl Publikationen bestätigt durch Betreuer"];
        $f["p_pubs"] = ["baydoc_getpubs(t.id,true)", "Link zu Publikationen bestätigt durch Betreuer"];
        $f["p_anz_total"] = ["baydoc_getpub_anz(t.id,false)", "Anzahl Publikationen"];
        $f["p_link"] = ["'<a href=\"/" . $this->context->getOrgLinkLang() . "/admin/baydoc/?id='||t.id||'&tab=pub\">Details</a>'", "Link zu Publikationsdetails"];

        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'eg_' . $name,
                $v[1],
                sql: $v[0],
                div_id: 'Publikationen'
            ));
        }

    }

    protected function addEFHstatgTab()
    {
        $f = [];
        $hstatg_start = (\BayDOC\Util\Filter::$hstatg_year - 1) . '-12-02';
        $hstatg_end = \BayDOC\Util\Filter::$hstatg_year . '-12-01';
        $sql_ef13_date = \BayDOC\Util\Filter::$sql_ef13_date;
        $sql_ef14_date = \BayDOC\Util\Filter::$sql_ef14_date;

        $f["id"] = ["t.id", 'BayDOC-ID'];
        $f["ef00"] = ["'05100000'", "Berichtseinheitid - fix 05100000"];
        $f["ef01"] = ["'09'", "Berichtsland (EF01) - fix 09"];
        $f["ef02"] = [\BayDOC\Util\Filter::$hstatg_year, "Berichtsjahr (EF02)"];
        $f["ef03"] = ["case when non_empty(fak.de,fak.en) ilike '%VII' then '0511' else '0510' end", "Hochschule der Promotion (EF03) - 0510/0511"];
        $f["ef04"] = [" to_char(row_number() OVER (order by t.id),'000000')", "Paginiernummer (EF04)"];


        $f["ef05"] = ["t.hstatg_geschlecht", "Geschlecht (EF05)"];
        $f["ef06"] = ["to_char(t.gdatum,'DDMMYYYY')", "Geburtsdatum (EF06)"];
        $f["ef06u1"] = ["to_char(t.gdatum,'DD')", "Geburtsdatum (EF06U1)"];
        $f["ef06u2"] = ["to_char(t.gdatum,'MM')", "Geburtsdatum (EF06U2)"];
        $f["ef06u3"] = ["to_char(t.gdatum,'YYYY')", "Geburtsdatum (EF06U3)"];
        $f["ef07"] = ["rpad(baydoc_sonderzeichen2txt(t.vorname),4)", "Vorname - 4 Zeichen (EF07)"];
        $f["ef08"] = ["nat1.schluessel", "Staatsangehörigkeit (EF08)"];
        $f["ef09"] = ["case when nat2.schluessel!=nat1.schluessel then nat2.schluessel end", "Weitere Staatsangehörigkeit (EF09)"];


        $f["ef10"] = ["t.hstatg_prom_art", "Art der Promotion (EF10)"];
        $f["ef10_01"] = ["case when t.hstatg_prom_art is null then '01' else t.hstatg_prom_art end", "Art der Promotion - default 01 (EF10)"];
        $f["ef11"] = ["prom_fach.signatur", "Promotionsfach (EF11)"];
        $f["ef12"] = [
            "case when t.abbruch_best<='$hstatg_end' or t.abbruch<='$hstatg_end' then 6
      when t.prue_urkunde is not null and t.prue_urkunde<='$hstatg_end' then 5
      when t.prue_nichtbestanden is not null and t.prue_nichtbestanden<='$hstatg_end' then 5
      when t.pstart2<'$hstatg_start' and t.pstart2>('$hstatg_start'::date-interval '1 year') then 2
      when $sql_ef13_date<'$hstatg_start' then 3
      else 1 end",
            "Art der Registrierung als Promovierender (EF12)"
        ];
        $f["ef13"] = ["to_char($sql_ef13_date,'MMYYYY')", "Promotionsbeginn (EF13) (Minimum aus ...)"];
        $f["ef13u1"] = ["to_char($sql_ef13_date,'MM')", "Promotionsbeginn (EF13U1)"];
        $f["ef13u2"] = ["to_char($sql_ef13_date,'YYYY')", "Promotionsbeginn (EF13U2)"];
        $f["ef13_gemeldet"] = ["t.hstatg_ef13", "Promotionsbeginn (EF13) gemeldet"];
        $f["ef14"] = [
            "to_char(case when $sql_ef14_date<='$hstatg_end'
      then $sql_ef14_date end,'MMYYYY')",
            "Ende der Promotion (EF14) == Verfahren Datum der mündlichen Prüfung oder Datum „Bestätigung Rücktritt von der Promotion“"
        ];
        $f["ef14u1"] = [
            "to_char(case when $sql_ef14_date<='$hstatg_end'
      then $sql_ef14_date end,'MM')",
            "Ende der Promotion (EF14U1)"
        ];
        $f["ef14u2"] = [
            "to_char(case when $sql_ef14_date<='$hstatg_end'
      then $sql_ef14_date end,'YYYY')",
            "Ende der Promotion (EF14U2)"
        ];
        $f["ef14_gemeldet"] = ["t.hstatg_ef14", "Promotionsende (EF14) gemeldet"];
        $f["ef15"] = ["case when t.hstatg_immatrikuliert then 1 else 0 end", "Immatrikulation (EF15)"];
        $f["ef16"] = ["case when t.hstatg_promprog then '1' else '0' end", "Teilnahme an einem strukturierten Promotionsprogramm (EF16)"];
        $f["ef17"] = ["case when t.hstatg_beschaeftigt then 1 else 0 end", "Beschäftigungsverhältnis an der Hochschule der Promotion (EF17)"];
        $f["ef18"] = ["t.hstatg_diss_art::int", "Art der Dissertation (EF18)"];
        $f["ef18_01"] = ["case when t.hstatg_diss_art is null then 1 else t.hstatg_diss_art::int end", "Art der Dissertation - default 1 (EF18)"];
        $f["ef19"] = ["bachelor_hs.schluessel", "Hochschule (EF19)"];
        $f["ef20"] = ["case when bachelor_land.schluessel!='000' then bachelor_land.schluessel end", "Staat der HS (EF20)"];
        $f["ef21"] = ["t.hstatg_erst_semester", "Semester (EF21)"];
        $f["ef22u1"] = ["t.hstatg_erst_jahr", "Jahr der Ersteinschreibung (EF22)"];
        $f["ef22u2"] = ["t.hstatg_erst_monat", "Monat der Ersteinschreibung (EF22)"];

        $f["ef23"] = ["1", "Zur Promotion berechtigende Abschlussprüfung wurde/wurde noch nicht abgelegt (EF23) - fix 1"];
        $f["ef24"] = ["master_hs.schluessel", "Hochschule (EF24)"];
        $f["ef25"] = ["case when master_land.schluessel!='000' then master_land.schluessel end", "Staat der HS (EF25)"];
        $f["ef26"] = ["replace(master_art.schluessel,' ','')", "Art der Prüfung (EF26)"];
        $f["ef27"] = ["master_fach.signatur", "1. Studienfach (EF27)"];
        $f["ef28"] = ["to_char(t.hstatg_ab_datum,'MM')", "Monat des Abschlusses (EF28)"];
        $f["ef29"] = ["to_char(t.hstatg_ab_datum,'YYYY')", "Jahr des Abschlusses (EF29)"];
        $f["ef30"] = ["substr(t.hstatg_ab_note,2,1)", "Gesamtnote des Abschlusses (EF30)"];

        $f["ef31"] = ["t.hstatg_hzb_jahr", "Jahr des ersten Erwerbs einer HZB (EF31)"];
        $f["ef32"] = ["hzb_art.schluessel", "Art der ersten HZB (EF32)"];
        $f["ef33kreis"] = ["hzb_kreis.schluessel", "Ort (EF33)"];
        $f["ef33land"] = ["hzb_land.schluessel", "Wenn HZB im Ausland erworben: Land (EF33)"];
        $f["ef33U1"] = ["case when hzb_kreis.schluessel is null then case when hzb_land.schluessel!='000' then '99' end else substring(hzb_kreis.schluessel from 1 for 2) end", "Bundesland (EF33U1)"];
        $f["ef33U2"] = ["case when hzb_kreis.schluessel is null then hzb_land.schluessel else replace(substring(hzb_kreis.schluessel from 3 for 7),' ','') end", "Kreis/Land (EF33U2)"];
        $f['stat_land'] = ["case when t.land!='Deutschland' and (t.land2!='Deutschland' or t.land2 is null) then t.land end", "Nationalität falls nicht Deutschland"];
        $f['stat_land_nr'] = ["case when t.land!='Deutschland' and (t.land2!='Deutschland' or t.land2 is null) then (select schluessel from stat_laender where name=t.land) end", "Nationalität Nummer falls nicht Deutschland"];
        $f['hstatg_hzb_ok'] = ["non_empty((((hzb_land.schluessel='000' and hzb_kreis.schluessel>'') 
or (hzb_land.schluessel is not null and hzb_land.schluessel!='000')) 
and t.hstatg_hzb_jahr>1920 and t.hstatg_hzb_jahr<extract(year from now())
and hzb_art.schluessel>'')::text,'f')::boolean ",
            "HZB vollständig"
        ];
        $f['hstatg_bachelor_ok'] = ["non_empty((
bachelor_hs.schluessel>'' and bachelor_land.schluessel>'' and t.hstatg_erst_semester>'' and t.hstatg_erst_jahr>1920 and t.hstatg_erst_jahr<extract(year from now())
)::text,'f')::boolean",
            "Ersteinschreibung vollständig"
        ];
        $f['hstatg_master_ok'] = ["non_empty((
master_hs.schluessel>'' and master_land.schluessel>'' and master_art.schluessel>'' and master_fach.signatur>'' and t.hstatg_ab_datum is not null and t.hstatg_ab_note>''
)::text,'f')::boolean",
            "Abschlussprüfung vollständig"
        ];
        $f['stat_mnr'] = ["to_char(t.mnr,' 99999999999')", "Matrikel Nummer (mit führenden Lehrzeichen)"];
        $f['stat_xmann'] = ["case when t.anrede='Herr' then 'X' end", "X falls Mann"];
        $f['stat_xfrau'] = ["case when t.anrede!='Herr' then 'X' end", "X falls Frau"];
        $f['stat_gmonat'] = ["to_char(t.gdatum,'MM')", "Geburtsmonat"];
        $f['stat_gjahr'] = ["to_char(d.gdatum,'YYYY')", "Geburtsjahr"];
        $f['stat_xdeutsch'] = ["case when t.land='Deutschland' or t.land2='Deutschland' then 'X' end", "X falls Deutschland"];
        $f['stat_semester'] = ["to_char(ceil((t.prue_urkunde-(" . \BayDOC\Util\Filter::$sql_ef13_date . "))::float/365*2),'09')", "Anzahl Fachsemester"];
        $f['stat_prom_art'] = ["case when t.zulassung_prom_art>'' then t.zulassung_prom_art else '506' end", "Art der Promotion"];
        $f['stat_monat'] = ["to_char(t.prue_urkunde,'MM')", "Abschlussmonat"];
        $f['stat_jahr'] = ["to_char(t.prue_urkunde,'YYYY')", "Abschlussjahr"];
        for ($i = 0; $i <= 4; $i++)
            $f['stat_x' . $i] = ["case when t.prue_note=$i then 'X' end", "X falls Note $i"];

        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'EF_hstatg_' . $name,
                $v[1],
                sql: $v[0],
                div_id: 'HStatG EF'
            ));
        }



    }

    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void {
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from baydoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /' . $this->context->getOrgLinkLang() . '/admin/baydoc/?id=' . $_GET['id']);
                exit();
            }

        }
        $this->pageExport();
        $this->pageHelp();
        $path = explode('/', $_SERVER['PATH_INFO'] ?? '/');
        if (in_array($path[1], ['Query', 'Document', 'Email']))
            $this->pageQB($pre_content, $post_content);

        $head = $pre_content . $this->getTabNavigation();

        if ($path[1] == 'Run') {
            $run = new \BayDOC\Page\Admin\Run($this->context);
            $run->page($head);
        }


        $doc = new \BayDOC\Page\Admin\DocList($this->context);
        $doc->page($head);
    }




}