<?php

namespace BayDOC\QB;

/**
 * QB
 * Basetable: Eventanmeldungen (Dokoranden/Postdocs)
 */
class Event extends Base
{
    private $domain;
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            context: $context,
            table: 'baydoc_events',
            object: true,
            row_click_query: 'd.id',
            where: "t.id=o.id",
            email_fields: ['email_doc']
        );
        $this->mapper_class = '\\BayDOC\\QB\\Mapper\\Event';


        $this->domain = new \BayDOC\Page\Admin\Events($context);
        $this->addTab($this->domain, 'Veranstaltungen', 'event', true);

        $felder = 'id,titel,anrede,name,vorname,gname,gdatum,gort,str,ort,land_wohnort,land,land2,tel,email,homepage,antrag';
        $fnamen = 'ID (Post)Doc,Titel,Anrede,Name,Vorname,Geburtsname,Geburtsdatum,Geburtsort,Straße,Ort,Land Wohnort,Nationalität,2. Nationalität,Telefon,E-Mail,Homepage,Antrag';

        $this->list_from = "objekt_verwaltung" . $context->getOrgId() . " o, baydoc_events t
join verweis v on v.id_auf=t.id join (
  select id_lehr," . str_replace(',titel,', ",'' as titel,", $felder) . ",'Promovierende' as gruppe from baydoc
  union
  select id_lehr,$felder,'Postdocs' as gruppe from postdoc
) d on d.id=v.id_von
";
        $felder = explode(',', $felder);
        $fnamen = explode(',', $fnamen);
        for ($i = 0; $i < count($felder); $i++) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'doc_' . $felder[$i],
                $fnamen[$i],
                div_id: '(Post)Doc',
                sql: 'd.' . $felder[$i]
            ));
        }

        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'gruppe_doc',
            'Gruppe',
            div_id: '(Post)Doc',
            sql: 'd.gruppe'
        ));
        $this->list_from .= " left outer join lehrstuhl prom_prog on prom_prog.id=d.id_lehr 
                    left join gehoert_zu gz on prom_prog.id=gz.id_lehr
                    left outer join lehrstuhl fak on fak.id=gz.id_parent";
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'einheit_de',
            'Einheit (deutsch)',
            sql: 'prom_prog.de',
            div_id: '(Post)Doc'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'fakultaet_de',
            'Fakultät (deutsch)',
            sql: 'fak.de',
            div_id: '(Post)Doc'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'Warteliste_doc',
            'Warteliste',
            div_id: '(Post)Doc',
            sql: "case when v.ordnung>100 then 'Ja' else 'Nein' end"
        ));
        $this->addField(new \BayCMS\Field\Number(
            $this->context,
            'warteliste_nr',
            'Warteliste Position',
            div_id: '(Post)Doc',
            sql: "v.ordnung-100 "
        ));
        $this->addNavigationTab($this->t('Overview','Überblick'),'/'.$context->getOrgLinkLang().'/admin/baydoc/event_qb.php');
    }

    

    public function page(string $pre_content = '', string $post_content = '')
    {
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from baydoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /' . $this->context->getOrgLinkLang() . '/admin/baydoc/?tab=event&id=' . $_GET['id']);
                exit();
            }
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from postdoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /' . $this->context->getOrgLinkLang() . '/admin/postdoc/?tab=event&id=' . $_GET['id']);
                exit();
            }
        }

        $this->pageExport();
        $this->pageHelp();
        $path = explode('/', $_SERVER['PATH_INFO'] ?? '/');
        if (in_array($path[1], ['Query', 'Document', 'Email']))
            $this->pageQB($pre_content, $post_content);

        $this->domain->pagePreHeader();
        $this->context->printHeader();
        $head = $pre_content . $this->getTabNavigation();
        echo $head;
        $post_content .= ' '.$this->context->TE->getActionLink(
            '/' . $this->context->getOrgLinkLang() . '/admin/baydoc/event_qb.php',
            $this->t('Event overview queries', 'Überblicks-Abfragen'),
            '',
            'arrow-right'
        );
        $this->domain->pagePostHeader($post_content);
    }
}