<?php

namespace BayDOC\QB;

/**
 * QB 
 * Basetable - Events mit Count-Felder für Anmeldung und Warteliste
 */
class Events extends \BayCMS\Fieldset\QueryBuilder
{
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            $context,
            row_click_query: 't.id'
        );
        $this->mapper_class = '\\BayDOC\\QB\\Mapper\\Events';
        $this->list_from = "objekt_verwaltung" . $context->getOrgId() . " o, baydoc_events t 
	  left outer join 
	  (select t.id,count(*) from baydoc_events t, verweis v where v.id_auf=t.id and v.ordnung=100 group by t.id) a 
	  on t.id=a.id 
	  left outer join 
	  (select t.id,count(*) from baydoc_events t, verweis v where v.id_auf=t.id and v.ordnung>100 group by t.id) w 
	  on t.id=w.id ";
        $this->list_where = " o.id=t.id";

        $this->addField(new \BayCMS\Field\Number(
            $context,
            'Id',
            div_id: 'Event'
        ));

        $d = new \BayDOC\Page\Admin\Events($context);
        $left_nr = 0;
        foreach ($d->getFields() as $f) {
            if (!$f->get('edit_field'))
                continue;
            $f->setDivID('Event');
            $f->set(['list_field' => 1]);
            if (get_class($f) == 'BayCMS\\Field\\UploadFile') {
                $left = "file" . $left_nr;
                $left_nr++;
                $this->list_from .= " left outer join (select f.*,o.id_obj as id_parent from file f, objekt o
                    where f.id=o.id and f.de='" . addslashes($f->uname) . "') $left on $left.id_parent=t.id";
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    $f->name . "_name",
                    $f->description . ' (Download Link)',
                    sql: "'<a href=\"../../top/gru/get.php?id='||$left.id||'\">'||non_empty($left.de,$left.en)||'</a>'",
                    div_id: 'Zertifikate'
                ))->set(['list_field' => 1]);
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    $f->name . "_mtime",
                    $f->description . ' (Änderungszeitpunkt)',
                    sql: "$left.mtime",
                    div_id: 'Zertifikate'
                ))->set(['list_field' => 1]);
            } elseif (strstr(get_class($f), 'BayCMS\\Field\\Bilang')) {
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    $f->name . 'de',
                    $f->description . ' (deutsch)',
                    div_id: 'Event'
                ));
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    $f->name . 'en',
                    $f->description . ' (englisch)',
                    div_id: 'Event'
                ));

            } else
                $this->addField($f);
        }
        $this->addField(new \BayCMS\Field\Number(
            $context,
            'current',
            $this->t('Current registrations', 'Anzahl Anmeldungen'),
            sql: 'a.count',
            div_id: 'Anmeldungen'
        ));
        $this->addField(new \BayCMS\Field\Number(
            $context,
            'on_waitlist',
            $this->t('Registrations on waitlist', 'Anzahl Warteliste'),
            sql: 'w.count',
            div_id: 'Anmeldungen'
        ));
    }


    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void {
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from baydoc_events where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /' . $this->context->getOrgLinkLang() . '/admin/baydoc/events.php/?id=' . $_GET['id']);
                exit();
            }
        }
        $this->context->initTemplate();
        $post_content .= $this->context->TE->getActionLink(
            '/' . $this->context->getOrgLinkLang() . '/admin/baydoc/events.php',
            $this->t('back to events', 'Zurück zu den Veranstaltungen'),
            '',
            'arrow-left'
        );
        parent::page($pre_content, $post_content);

    }
}