<?php

namespace BayDOC\QB\Mapper;

use function PHPUnit\Framework\containsOnly;

class Base extends \BayCMS\Base\BayCMSBase {
    protected array $old=[];
    protected array $prefilter_map=[];
    protected array $field_map=[];
    protected string $sql_ef13_date="case when d.pstart2 is not null then d.pstart2
            when d.zulassung_zulassung is not null then d.zulassung_zulassung
            else d.zulassung end";
    protected string $sql_ef14_date="greatest(d.prue_urkunde,case when d.prue_nichtbestanden is not null then d.prue_nichtbestanden 
    when d.abbruch_best is not null then d.abbruch_best else d.abbruch end)";

    protected string $hstatg_2024_start='2023-12-02';
    protected string $hstatg_2024_ende='2024-12-01';
    public function __construct(\BayCMS\Base\BayCMSContext $context, $nr=1){
        $this->context=$context;

        $ret2=array();
        $ret2['f_query'][]="";
        $ret2['f_query_name'][]="";
        
        $res=pg_query($context->getDbConn(),"select id,non_empty(de,en) from baydoc_zulassungskat order by 2");
        for($i=0;$i<pg_num_rows($res);$i++){
            $r=pg_fetch_array($res,$i);
            $this->prefilter_map[count($ret2['f_query'])]="status_eq_".$r['id'];
            $ret2['f_query'][]=($nr?" and s.id_status=$r[id]":" and d.ubt_status=$r[id]");
            $ret2['f_query_name'][]="Status $r[non_empty]";

        }
        $res=pg_query($context->getDbConn(),"select id,non_empty(de,en) from baydoc_zulassungskat order by 1");
        for($i=0;$i<pg_num_rows($res);$i++){
            $r=pg_fetch_array($res,$i);
            $this->prefilter_map[count($ret2['f_query'])]="status_lt_".$r['id'];
            $ret2['f_query'][]=($nr?" and s.id_status<=$r[id]":" and d.ubt_status<=$r[id]");
            $ret2['f_query_name'][]="Status <=$r[non_empty]";
        }
        
        
        $y=2017;
        while($y<2024){
            $this->prefilter_map[count($ret2['f_query'])]="hstatg$y";
            $ret2['f_query'][]=" and hstatg$y>''";
            $ret2['f_query_name'][]='HStatG '.$y.' - abgeschlossen';
            $y++;
        }
        $this->prefilter_map[count($ret2['f_query'])]="hstatg$y";
        $ret2['f_query'][]=" and not d.no_hstatg
        and (greatest(d.prue_urkunde,d.abbruch_best,d.abbruch) is null or
        greatest(d.prue_urkunde,d.abbruch_best,d.abbruch)>='".$this->hstatg_2024_start."')
        and s.id_status>0
        and (d.hstatg_ef14 is null or d.hstatg_ef14='')
        and ".$this->sql_ef13_date."<='".$this->hstatg_2024_ende."'";
        $ret2['f_query_name'][]='HStatG 2024';

        $this->old['f_filter']=$ret2;
    }


    private function error_text(string $field){
        $out=$field;
        if(isset($this->old['felder'][$field])) $out.=" (".htmlentities($this->old['felder'][$field]).')';
        return $out;
    } 

    public function map(int $id){
        $ret=['error'=>'','json'=>[]];

        $res=pg_query($this->context->getDbConn(),
        "select * from qb_querys where id=$id");

        if(! pg_num_rows($res)) throw new \BayCMS\Exception\notFound("No query with id=$id");

        $r=pg_fetch_array($res,0);
        $ret['json']['qb_qname']=$r['name'];
        $ret['json']['qb_qvis']=$r['power'];

        $res=pg_query($this->context->getDbConn(),'select * from qb_expert where id_query='.$id);
        for($i=0;$i<pg_num_rows($res);$i++){
            $r2=pg_fetch_array($res,$i);
            $ret['json']['qb_expert'.$r2['nr'].'_name']=$r2['name'];
            $ret['json']['qb_expert'.$r2['nr'].'_sql']=$this->old2new($r2['sql']);
            $this->field_map['expert'.$r2['nr']]="_expert".$r2['nr'];
        }

        if($r['f_query'] && $r['f_query']!='null'){
            if(isset($this->prefilter_map[$r['f_query']])){
                $ret['json']['qb_prefilter0_name']=$this->prefilter_map[$r['f_query']];
                $ret['json']['qb_prefilter0_con']='';
                $ret['json']['qb_prefilter0_bo']='';
                $ret['json']['qb_prefilter0_bc']='';
                
                $ret['json']['qb_postfilter0_name']=$this->prefilter_map[$r['f_query']];
                $ret['json']['qb_postfilter0_con']='';
                $ret['json']['qb_postfilter0_bo']='';
                $ret['json']['qb_postfilter0_bc']='';
            }
            else 
                $ret['error'].="Prefilter $r[f_query] is unknown.<br/>";
 
        }
        foreach(explode(',',$r['felder']) as $f){
            if(isset($this->field_map[$f])){
                $ret['json'][$this->field_map[$f]]='t';
            } else {
                $ret['error'].="Field &quot;".$this->error_text($f)."&quot; not found.<br/>";
            }
        }
        $nr=0;
        foreach(explode('||XX||',$r['filter']) as $f){
            if(! $f) continue;
            [$con,$bo,$field,$op,$val,$bc,$sql]=explode("|X|",$f);
            if(isset($this->field_map[$field])){
                $ret['json']["qb_filter".$nr."_con"]=$con;
                $ret['json']["qb_filter".$nr."_bo"]=$bo;
                $ret['json']["qb_filter".$nr."_bc"]=$bc;
                $ret['json']["qb_filter".$nr."_name"]=$this->field_map[$field];
                $ret['json']["qb_filter".$nr."_op"]=$op;
                $ret['json']["qb_filter".$nr."_val"]=$val;
                if($sql)
                    $ret['error'].="SQL in Filter line ".($nr+1)." not supported! Please use SQL-Fields instead!<br/>";

            } else {
                $ret['error'].="Filter field &quot;".$this->error_text($field)."&quot; not found.<br/>";

            }
            $nr++;

        }
        $nr=0;
        foreach(explode(",",$r['order_felder']) as $f){            
            if(! $f) continue;
            $f=explode(" ",$f);
            if(isset($this->field_map[$f[0]])){
                $ret['json']['qb_order'.$nr.'_name']=$this->field_map[$f[0]];                
                $ret['json']['qb_order'.$nr.'_desc']=(isset($f[1])?'t':'f');
            } else {
                $ret['error'].="Order by field &quot;".$this->error_text($f[0])."&quot; not found.<br/>";
            }
        }

        
        return $ret;

    }

    protected $table_hash = [
    ];

    protected function new2old($sql)
    {
        $sql = ' ' . $sql;
        foreach ($this->table_hash as $new => $old) {
            $search = '/([^a-z_])' . $new . '\\./';
            $replace = '\\1' . $old . '.';
            $sql = preg_replace($search, $replace, $sql);
        }
        return trim($sql);
    }

    protected function old2new($sql)
    {
        $sql = ' ' . $sql;
        foreach ($this->table_hash as $new => $old) {
            $search = '/([^a-z_])' . $old . '\\./';
            $replace = '\\1' . $new . '.';
            $sql = preg_replace($search, $replace, $sql);
        }
        return trim($sql);
    }
    
}