<?php

namespace BayDOC\QB;
/**
 * QB
 * Basetable: Postdocs
 */
class Postdoc extends Base {
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            context: $context,
            table: 'postdoc',
            object: true,
            row_click_query: 't.id',
            where: "t.id=o.id and not t.antrag",
            email_fields: ['email', 'b_id_email', 'm1_id_email', 'm2_id_email', 'm3_id_email']
        );
        $this->mapper_class='\\BayDOC\\QB\\Mapper\\Postdoc';

        $doc = new \BayDOC\Entry\Postdoc($context);
        $this->left_hash = [];
        $this->from_hash = [];
        $this->list_from = "objekt_verwaltung" . $context->getOrgId() . " o, postdoc t";
        $this->addTab(new \BayDOC\Tabs\DocStamm($this->context, $doc),'Stammdaten','stamm',true);
        $this->addTab(new \BayDOC\Tabs\PostdocUni($this->context, $doc),'Ausbildung','uni');
        $this->addTab(new \BayDOC\Tabs\DocBetr($this->context, $doc),'Betreuer','betr');
        $this->addTab(new \BayDOC\Tabs\PostdocProm($this->context, $doc),'Promotion','prom');
        $this->addTab(new \BayDOC\Tabs\PostdocJp($this->context, $doc),'Junior Professur','jp');
        $this->addTab(new \BayDOC\Tabs\PostdocHabil($this->context, $doc),'Habilitation','habil');
        $this->addEventGeldTab();

        $this->addNavigationTab('Postdocs',$_SERVER['SCRIPT_NAME']);

    }

    

    protected function addEventGeldTab()
    {
        $f = [];

        $f["e_events_de"] = ["baydoc_get_event(t.id,'de')", "Veranstaltungen (als Text, deutsch)"];
        $f["e_events_en"] = ["baydoc_get_event(t.id,'en')", "Veranstaltungen (als Text, englisch)"];
        $f["e_link"] = ["'<a href=\"/".$this->context->getOrgLinkLang()."/admin/postdoc/?id='||t.id||'&tab=event\">Details</a>'", "Link zu Veranstaltungsdetails"];



        if ($this->context->getOrgId() == 5001) {
            $f["g_guthaben"] = ["baydoc_get_geld(t.id,null)", "Guthaben"];
            $f["g_ausgaben"] = ["baydoc_get_geld(t.id,1)", "Ausgegeben"];
            $f["g_gutschrift"] = ["baydoc_get_geld(t.id,-1)", "Gutschrift"];
            $f["g_festlegung"] = ["baydoc_get_geld(t.id,0)", "Festlegung"];
            $f["g_link"] = ["'<a href=\"/".$this->context->getOrgLinkLang()."/admin/postdoc/?id='||t.id||'&tab=geld\">Details</a>'", "Link zu Finanzdetails"];
        }

        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'eg_' . $name,
                $v[1],
                sql: $v[0],
                div_id: preg_match('/^e/', $name) ? 'Events' : 'Geld'
            ));
        }

    }



    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void{
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from postdoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /'.$this->context->getOrgLinkLang().'/admin/postdoc/?id=' . $_GET['id']);
                exit();
            }

        }
        $this->pageExport();
        $this->pageHelp();
        $path = explode('/', $_SERVER['PATH_INFO']??'/');
        if(in_array($path[1],['Query','Document','Email']))
            $this->pageQB($pre_content,$post_content);
        
        $head = $pre_content . $this->getTabNavigation();

        $doc=new \BayDOC\Page\Admin\PostdocList($this->context);
        $doc->page($head);
    }

   


}