<?php

namespace BayDOC\QB;

/**
 * QB
 * Basetable: Postdocs joined with Research-Grant (postdoc_tg)
 */
class PostdocRSG extends Postdoc
{
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct($context);
        $this->list_from .= ", postdoc_tg_deadline tg, postdoc_tg an, objekt an_o";
        $this->list_where .= " and tg.id=an.id_tg_deadline and an.id=an_o.id and an_o.id_obj=t.id 
        and an_o.geloescht is null";

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tg_id',
            'Ausschreibung ID',
            div_id: 'Ausschreibung',
            sql: 'tg.id'
        ));
       $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tg_name',
            'Ausschreibung Name',
            div_id: 'Ausschreibung',
            sql: 'non_empty(tg.de,tg.en)'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tg_bis',
            'Ausschreibung bis',
            div_id: 'Ausschreibung',
            sql: 'tg.bis'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tg_von',
            'Ausschreibung von',
            div_id: 'Ausschreibung',
            sql: 'tg.von'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tg_max',
            'Ausschreibung max',
            div_id: 'Ausschreibung',
            sql: 'tg.max'
        ));


        $felder = [
            'kurztitel' => 'Kurztitel',
            'ziel' => 'Reiseziel',
            'betrag' => 'Betrag',
            'von' => 'Start des Aufenthalts',
            'bis' => 'Ende des Aufenthalts',
            'geldgeber' => 'Geldgeber',
            'abgesprochen_name' => 'Vorgesetzter',
            'abgesprochen_einheit' => 'Lehrstuhl',
            'beschreibung' => 'Beschreibung',
            'qualiziel' => 'Qualifizierungsziel',
            'motivation' => 'Erwartungen hins. Vernetzung',
            'annahmebestaetigung' => 'Erwareteter Nutzen für eigene Forschung',
            'status' => 'Status',
            'annahme' => 'Annahme'
        ];

        foreach($felder as $key=>$value){
            $this->addField(new \BayCMS\Field\TextInput(
                $context,
                'an_'.$key,
                $value,
                div_id: 'Antrag',
                sql: 'an.'.$key
            ));
        }
        
    }

    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void{
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from postdoc where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                header('Location: /'.$this->context->getOrgLinkLang().'/admin/postdoc/?tab=tg&id=' . $_GET['id']);
                exit();
            }

        }
        $this->pageExport();
        $this->pageHelp();
        $path = explode('/', $_SERVER['PATH_INFO']??'/');
        if(in_array($path[1],['Query','Document','Email']))
            $this->pageQB($pre_content,$post_content);
        
        $this->context->printHeader();
        echo $pre_content . $this->getTabNavigation();

        $d=new \BayDOC\Page\Admin\RSG($this->context);
        $d->pagePostHeader();
    }


    public function getTabNavigation()
    {
        $names = $this->context->lang == 'en' ?
            ['Research Stay Grants','Query', 'Documents', 'Emails'] :
            ['Research Stay Grants','Abfragen', 'Dokumente', 'E-Mails'];
        $urls = [
            $_SERVER['SCRIPT_NAME'],
            $_SERVER['SCRIPT_NAME'] . '/Query',
            $_SERVER['SCRIPT_NAME'] . '/Document',
            $_SERVER['SCRIPT_NAME'] . '/Email'
        ];

        $nav = new \BayCMS\Util\TabNavigation(
            context: $this->context,
            names: $names,
            urls: $urls
        );
        return $nav->getNavigation();
    }


}