<?php

namespace BayDOC\QB;

/**
 * QB
 * Basetable: Professoren (bayprof)
 */
class Prof extends Base
{
    protected array $left_hash;
    protected array $from_hash;
    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        parent::__construct(
            context: $context,
            table: 'bayprof',
            object: true,
            prefilter: array_merge(
                \BayDOC\Util\Filter::getPostfilterStatus($context, true),
                \BayDOC\Util\Filter::getPostfilterHStatG()
            ),
            row_click_query: 't.id',
            where: "t.id=o.id",
            email_fields: ['email']
        );
        $this->mapper_class='\\BayDOC\\QB\\Mapper\\Prof';

        $prof = new \BayDOC\Entry\Prof($context);
        $t = new \BayDOC\Tabs\ProfStamm($context, $prof);
        $this->list_from = "objekt_verwaltung" . $context->getOrgId() . " o, bayprof t
left outer join datahub2bayd_person idmp on idmp.pernr=t.idm_pernr
left outer join exp_organisation idmo on idmo.objid_orgeh=t.idm_objid_orgeh
  left outer join 
   		(select d1.id,count(*) as sum,comma(d1.vorname||' '||d1.name),comma(d1.name) as nnamen
        from 
 (select p.id,t.vorname,t.name
  		from objekt_verwaltung" . $context->getOrgId() . " o, bayprof p, baydoc t
  		where o.id=p.id and p.id=t.b_id and not t.antrag \${prefilter} order by p.id,t.name,t.vorname) d1
  		group by d1.id ) s1 on s1.id=t.id
  		left outer join
  		(select d2.id,count(*) as sum,comma(d2.vorname||' '||d2.name),comma(d2.name) as nnamen
        from 
(select p.id,t.vorname,t.name
  		from objekt_verwaltung" . $context->getOrgId() . " o, bayprof p, baydoc t 
  		where 
  		(t.m1_id=p.id or t.m2_id=p.id or t.m3_id=p.id) and 
 		 o.id=p.id and not t.antrag \${prefilter} order by p.id,t.name,t.vorname) d2
        group by d2.id ) s2 on 
 		 s2.id=t.id";
        $this->addTab($t, 'Stammdaten', 'stamm',true);
        $this->addDocTab();
        $this->addIDMTab();

        $this->addNavigationTab('Profs',$_SERVER['SCRIPT_NAME']);

    }

    public function page(
        string $pre_content = '',
        string $post_content = ''
    ): void {
        if (isset($_GET['id'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select id from bayprof where id=$1',
                [$_GET['id']]
            );
            if (pg_num_rows($res)) {
                $prof = new \BayDOC\Page\Admin\Prof($this->context);
                $prof->page();
            }

        }
        $this->pageExport();
        $this->pageHelp();
        $path = explode('/', $_SERVER['PATH_INFO'] ?? '/');
        if (in_array($path[1], ['Query', 'Document', 'Email']))
            $this->pageQB($pre_content, $post_content);

        $head = $pre_content . $this->getTabNavigation();

        $list = new \BayDOC\Page\Admin\ProfList($this->context);
        $list->page($head);
    }



    protected function addDocTab(){
        $f = [];
        $f['sum1']=['case when s1.sum is null then 0 else s1.sum end','Anzahl Promovierende'];
        $f['d_namen']=['s1.comma','Promovierende (Vorname Name)'];
        $f['d_nnamen']=['s1.nnamen','Promovierende (Name)'];
        $f['sum2']=['case when s2.sum is null then 0 else s2.sum end','Anzahl Mentorate'];
        $f['m_namen']=['s2.comma','Mentorate (Vorname Name)'];
        $f['m_nnamen']=['s2.nnamen','Mentorate (Name)'];
        $f['b_akt']=["baydoc_get_docs(t.id,'b',false)",'aktive Promovierende (Namen)'];
        $f['m_akt']=["baydoc_get_docs(t.id,'m',false)",'aktive Mentorate (Namen)'];
        $f['b_ab']=["baydoc_get_docs(t.id,'b',true)",'abgeschlossene Promovierende (Namen)'];
        $f['m_ab']=["baydoc_get_docs(t.id,'m',true)",'abgeschlossene Mentorate (Namen)'];
        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'stat_' . $name,
                $v[1],
                sql: $v[0],
                div_id: 'Doktorarbeiten/Mentorate'
            ));
        }

    }

    protected function addIDMTab()
    {
        $f = [];

        $f['pernr'] = ['t.idm_pernr', 'IDM Personalnummer'];
        $f['orgid'] = ['t.idm_objid_orgeh', 'IDM Orgeinheit ID'];
        $f['org_cob'] = ['idmo.cob', 'IDM Orgeinheit COB'];
        $f['org_stext'] = ['idmo.org_stext', 'IDM Orgeinheit STEXT'];
        $f['org_tline'] = ['idmo.org_tline', 'IDM Orgeinheit TLINE'];   


        foreach ($f as $name => $v) {
            $this->addField(new \BayCMS\Field\TextInput(
                $this->context,
                'idm_' . $name,
                $v[1],
                sql: $v[0],
                div_id: 'IDM'
            ));
        }

    }
}