<?php

namespace BayDOC\Tabs;

class DocBetr extends DocForm
{
    static public array $bm = array('b', 'm1', 'm2', 'm3');
    static public array $bm_names_bilang = array(
        "de" => array('1. Betreuer(in)', 'Mentor/Betreuer(in)', 'Mentor/Betreuer(in)', 'Mentor/Betreuer(in)'),
        'en' => array('1st Supervisor', 'Mentor/Supervisor', 'Mentor/Supervisor', 'Mentor/Supervisor')
    );

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $admin = $doc->getRole() == 'admin';
        $bm = DocBetr::$bm;
        $bm_names = DocBetr::$bm_names_bilang[$context->lang];
        $bm_max = 1;
        for ($i = 0; $i < 4; $i++) {
            $this->addField(
                new \BayCMS\Field\SelectJS(
                    $context,
                    $bm[$i] . '_id',
                    description: $bm_names[$i],
                    non_empty: ($i < $bm_max),
                    target: '../../intern/baydoc/prof.php',
                    db_query: "select id, titel||' '||vname||' '||nname as description from bayprof where id=\$1"
                )
            )->set(['left_join' => 'bayprof','left_join_name'=>'prof_'.$bm[$i]]);
            if ($admin) {
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    $bm[$i] . '_token',
                    $bm_names[$i] . ' Token'
                ));
                $this->addField(new \BayCMS\Field\Checkbox(
                    $context,
                    $bm[$i] . '_genToken',
                    'Token neu generieren',
                    no_add_to_query: 1
                ));
                $this->addField(new \BayCMS\Field\Datetime(
                    $context,
                    $bm[$i] . '_bestaetigt',
                    $bm_names[$i] . ' - Bestätigt',
                    help: 'Achtung! Dieses Feld wird normalerweise automatisch gefüllt!'
                ));
            }
        }

    }

    public function print()
    {
        $this->load($this->doc->getId());
        if (($_GET['aktion'] ?? false) && !$this->editAllowed())
            unset($_GET['aktion']);
        if ($_GET['aktion'] ?? '') {
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }
            if ($_GET['aktion'] == 'save') {
                $this->save();
                $GLOBALS['TE']->printMessage($this->t('Saved entry', "Eintrag gespeichert"));
                unset($_GET['aktion']);
                if ($this->doc->getAntrag() && ($tab=$this->getNextTab()))
                    echo $this->getJSRedirect("?tab=$tab&id=" . $this->doc->getId() . "&aktion=edit");
                $this->doc->load($this->doc->getId());
            } else {
                if ($this->doc->getAntrag())
                    $GLOBALS['TE']->printMessage($this->getComment());
                echo $this->getForm($this->t('Edit Entry', 'Eintrag bearbeiten'));
            }
        }
        if (!isset($_GET['aktion'])) {
            if($this->doc->getAntrag())
                $GLOBALS['TE']->printMessage($this->getComment());
            if ($this->editAllowed())
                echo $GLOBALS['TE']->getActionLink(
                    "?tab=betr&aktion=edit&id=" . $this->doc->getId(),
                    $this->t('edit', 'bearbeiten'),'',
                    'edit'
                );
            $r = $this->doc->getRow();
            echo "<table" . $GLOBALS['TE']->getCSSClass('table') . ">";

            $bm = DocBetr::$bm;
            $bm_names = DocBetr::$bm_names_bilang[$this->context->lang];
            $translations=[];
            $translations['en']['Herr']='Mr';
            $translations['en']['Frau']='Ms';
            $mail=new \BayDOC\Util\Mail($this->context);
            for ($i = 0; $i < 4; $i++) {
                if ($r[$bm[$i] . '_id']) {
                    if ($this->doc->getRole() == 'admin')
                        $r["$bm[$i]_url"] = "bayprof.php?tab=stamm&id=" . $r["$bm[$i]_id"];
                    echo "<tr><th style=\"font-weight:bold;\">$bm_names[$i]" .
                        (! $this->doc->getAntrag() ? ' - ' . (!$r["$bm[$i]_bestaetigt"] ? 
                        '<span style="color: #ff0000;">' . $this->t('not yet','noch nicht') : 
                        '<span style="color: #008800;">') . ' ' . $this->t('confirmed','bestätigt') . "</span>" : '') . "</th></tr>
                                <tr><td>".($r["$bm[$i]_url"]??false?"<a href=\"" . $r["$bm[$i]_url"] . "\">":'') . $r["$bm[$i]_vname"] . ' ' . $r["$bm[$i]_nname"] . 
                                ($this->doc->getRole() == 'admin' && $r["$bm[$i]_admin_ok"] == 'f' ? 
                                ' <b><i>(Ungeprüft!)</i></b>' : '') .($r["bm[$i]_url"]??false?"</a>":''). "</td></tr>
                                <tr><td>" . $r["$bm[$i]_email"] . "</td></tr>
                                ";
                    if ($this->doc->getRole() == 'admin' && !$r["$bm[$i]_bestaetigt"]) {
                        $id=$this->doc->getId();
                        echo "<tr><td><form method=\"post\" action=\"../../admin/baydoc/bayprof.php?aktion=email&id=" . $r["$bm[$i]_id"] . "\">
                            ";
                        $r['herr_frau_de'] = $r['anrede'];
                        $r['herr_frau_en'] = $translations['en'][$r['anrede']]??'';
                        $r['email'] = $r[$bm[$i] . '_email'];
                        $r['vname'] = $r[$bm[$i] . '_vname'];
                        $r['nname'] = $r[$bm[$i] . '_nname'];
                        $r['pw'] = substr($r[$bm[$i] . '_token'], 1, 8);
                        $r['mentor_anrede_de'] = $r[$bm[$i] . '_anrede'] ? 'Sehr geehrte' . ($r[$bm[$i] . '_anrede'] == 'Herr' ? 'r' : '') . ' ' . $r[$bm[$i] . '_anrede'] . ($r[$bm[$i] . '_titel'] ? ' ' . $r[$bm[$i] . '_titel'] : '') : 'Guten Tag';
                        $r['mentor_anrede_en'] = $r[$bm[$i] . '_anrede'] ? 'Dear ' . $translations['en'][$r[$bm[$i] . '_anrede']] . ($r[$bm[$i] . '_titel'] ? ' ' . $r[$bm[$i] . '_titel'] : '') : 'Hallo';
                        $r['was_de'] = DocBetr::$bm_names_bilang['de'][$i];
                        $r['was_en'] = DocBetr::$bm_names_bilang['en'][$i];
                        $r['blink_de'] = "https://$_SERVER[HTTP_HOST]/ubt/de/intern/baydoc/?betr=confirm&id=$id&who=$bm[$i]&token=" . $r[$bm[$i] . '_token'];
                        $r['blink_en'] = "https://$_SERVER[HTTP_HOST]/ubt/en/intern/baydoc/?betr=confirm&id=$id&who=$bm[$i]&token=" . $r[$bm[$i] . '_token'];
                        echo '<input type="hidden" name="betreff" value="' . 
                        htmlspecialchars($mail->replaceTokens($mail->getMailText('mentor_neuer_antrag_betreff'), $r)) . 
                        '">
                            <input type="hidden" name="nachricht" value="' . 
                            htmlspecialchars($mail->replaceTokens($mail->getMailText('mentor_neuer_antrag'), $r)) . 
                             '">
                            <input type="submit" value="Token-Mail"></form></td></tr>';
                        // $r=baydoc_getDocRow($id);
                    }
                }
            }
            echo '</table>';



        }
    }


    public function editAllowed(): bool
    {
        return ($this->doc->getRole() == 'admin' || ($this->doc->getRole() == 'selbst' && $this->doc->getAntrag())) && !$this->doc->locked();
    }

    public function getComment(): string
    {
        if($this->doc->getTable()=='baydoc')
        return $this->t(
            'You have to select a supervisor. Supervisors will get a mail when you finish the registration process.',
            'Sie müssen Betreuer angeben. Die Betreuer werden beim Beenden des Registrierungsprozesses per Mail informiert.'
        );
        return '';
    }

}