<?php

namespace BayDOC\Tabs;

class DocGs extends Doc
{

    public function save()
    {
        $id=$this->doc->getId();
        if (($_GET['aktion'] ?? false) != 'finish')
            return;
        if (!isset($_POST['gs_antrag'])) {
            $GLOBALS['TE']->printMessage($this->t('You have to check the checkbox', 'Sie müssen die Checkbox anhaken'), 'danger');
            return;
        }

        $res = pg_query_params(
            $this->context->getDbConn(),
            'select zulassung_zulassung from baydoc
        where id=$1 and zulassung_zulassung is not null',
            [$id]
        );
        if (!pg_num_rows($res)) {
            $GLOBALS['TE']->printMessage($this->t('Confirmation of the faculty is missing', 'Sie haben noch keine Zulassung von der Fakultät'), 'danger');
            return;
        }
        $res = pg_query_params(
            $this->context->getDbConn(),
            'select non_empty(' . $this->context->getLangLang2('k.') . '),k.id,k.uname
from baydoc_zulassung z, baydoc_zulassungskat k where k.id=z.id_kat and z.id_stud=$1 and z.id_lehr=5001
order by z.datum desc limit 1',
            [$id]
        );
        if (pg_num_rows($res)) {
            $GLOBALS['TE']->printMessage($this->t('Application already submitted', 'Antrag bereits eingetragen.'), 'danger');
            return;
        }

        ignore_user_abort(true);
        $r = $this->doc->getRow();
        pg_prepare(
            $this->context->getRwDbConn(),
            'zulassung',
            'insert into baydoc_zulassung(id_stud,datum,id_kat,id_benutzer,id_lehr)
                    select $1,now()::date,$4,$2,$3 except select id_stud,now()::date,id_kat,id_benutzer,id_lehr
                    from baydoc_zulassung where id_stud=$1'
        );
        pg_query_params(
            $this->context->getRwDbConn(),
            'select set_objekt_ls(d.id,5001,$2,o.id_art,0)
                        from objekt o, baydoc d where o.id=d.id and o.id=$1',
            [$id, $this->context->getOrgId()]
        );
        pg_execute(
            $this->context->getRwDbConn(),
            'zulassung',
            [$id, $this->context->getUserId(), 5001, 1]
        );

        // Send Mails...
        $translations = [];
        $translations['en']['Herr'] = 'Mr';
        $translations['en']['Frau'] = 'Ms';
        $r['student_anrede_de'] = $r['anrede'] ? 'Liebe' . ($r['anrede'] == 'Herr' ? 'r' : '') . ' ' . $r['anrede'] : 'Guten Tag';
        $r['student_anrede_en'] = $r['anrede'] ? 'Dear ' . $translations['en'][$r['anrede']] : 'Hello';
        $r['herr_frau_de'] = $r['anrede'];
        $r['herr_frau_en'] = $translations['en'][$r['anrede']];
        $r['pdf_link'] = "https://$_SERVER[HTTP_HOST]/$ls_link/de/intern/baydoc/antrag_pdf.php?id_obj=$id&gs=1";
        $r['admin_link'] = "https://$_SERVER[HTTP_HOST]/gs/de/admin/baydoc/?id_obj=$id";
        $r['intern_link'] = "https://$_SERVER[HTTP_HOST]/$ls_link/de/intern/baydoc/?id_obj=$id";
        $mail = new \BayDOC\Util\Mail($this->context);
        $mail->sendMail(
            $r['email'],
            $mail->getMailText('student_neuer_antrag_betreff', 5001),
            $mail->getMailText('student_neuer_antrag', 5001),
            $r,
            ids: [$id]
        );
        $mail->sendMail(
            $mail->getAdmins(5001),
            "Neuer Antrag von $r[name], $r[vorname]",
            $mail->getMailText('admin_neuer_antrag',5001),
            $r
        );

        $GLOBALS['TE']->printMessage($this->t(
            'Thank you for application. Please do not forget to print out, sign and send the application form to the given address.',
            'Danke für Ihren Antrag. Bitte denken Sie daran, den Antrag auszudrucken, zu unterschreiben und an die angegebene Adresse zu schicken.'
        ));

        $this->context->printFooter();

    }


    public function print()
    {
        $this->save();
        $res = pg_query_params(
            $this->context->getDbConn(),
            'select non_empty(' . $this->context->getLangLang2('k.') . '),k.id,k.uname,to_char(z.datum,\'DD.MM.YYYY\')
from baydoc_zulassung z, baydoc_zulassungskat k where k.id=z.id_kat and z.id_stud=$1 and z.id_lehr=5001
order by k.id desc, z.datum desc limit 1',
            [$this->doc->getId()]
        );

        if (pg_num_rows($res)) {
            $r = pg_fetch_array($res, 0);
            echo "<h3>Status Graduate School: $r[non_empty]</h3>";

            if ($r['id'] == 1) {
                if (!isset($_GET['aktion']))
                    echo "<p>" . ($this->context->lang == 'de' ? 'Die Aufnahme in die Graduate School der Universität Bayreuth wurde am ' . $r['to_char'] . ' 
elektronisch beantragt. Stellen Sie bitte sicher, dass Sie auch den schriftlichen Antrag unterschrieben und abgeschickt haben.'
                        : 'You applied for membership in Universtity of Bayreuth on ' . $r['to_char'] . '. 
Please make sure, that you signed and sent the application letter.') . "</p>";
                echo '<form action="../../intern/baydoc/antrag_pdf.php" target="_blank">
<input type="hidden" name="gs" value="1">
<input type="hidden" name="id_obj" value="' . $this->doc->getId() . '">
<input type="submit" value="' . ($this->context->lang == "de" ? "PDF-Antrag" : 'PDF Application') . '"></form>';
            } elseif ($r['id'] == 2) {
                echo "<p>" . ($this->context->lang == 'de' ? 'Ihr Antrag auf Mitgliedschaft in der UBT Graduate School 
wird derzeit auf Vollständigkeit geprüft. Dieser Vorgang ist nicht automatisiert und kann in der Regel bis zu 2 Wochen dauern.' :
                    'Your application for membership in the UBT Graduate School is currently being 
checked for completeness. This process is not automated and can take up to 2 weeks.') . "</p>";
            } elseif ($r['id'] == 4) {
                echo "<p>" . ($this->context->lang == 'de' ? 'Sie sind Mitglied in der UBT Graduate School. Sie können von <a href="/gs/de/intern/baydoc/">hier</a> in das Mitgliederportal wechseln, 
um dort Leistungen wie die Teilnahme an Veranstaltungen zu buchen.' :
                    'As a member of the UBT Graduate School you can switch from <a href="/gs/en/intern/baydoc/">here</a> to the member portal to book services such as events.') . "</p>";
            } elseif ($r['id'] == 5) {
                echo "<p>" . ($this->context->lang == 'de' ? 'Ihre Mitgliedschaft/Ihr Antrag in der UBT Graduate School wurde am  ' . $r['to_char'] . ' beendet. ' :
                    'Your membership in the UBT Graduate School expired on ' . $r['to_char']) . "</p>";

            }

            return;
        }



        $res = pg_query_params($this->context->getDbConn(), 'select zulassung_zulassung>(now()-interval \'380 days\') or gs_anmeldung as ok from baydoc 
where id=$1 and zulassung_zulassung is not null', [$this->doc->getId()]);
        if (pg_num_rows($res)) {
            //Antrag möglich
            $r = pg_fetch_array($res, 0);
            if ($r['ok'] == 't') {
                echo ($this->context->lang == 'de' ? '<b>Hinweis:</b> Sie können die Mitgliedschaft in der Graduate School der Universität Bayreuth beantragen. 
Der Antrag auf Mitgliedschaft muss innerhalb des <b>ersten Jahres der Promotion</b> gestellt werden. Zur Aufnahme in die University of Bayreuth Graduate School laden Sie bitte folgende Dokumente hoch:
<br/>(1) Lebenslauf im Reiter "Ausbildung"
<br/>(2) Betreuungsvereinbarung im Reiter "Promotion". 
<br/>
Auf der Bestätigungsseite erhalten Sie einen Link zu einer PDF-Datei.
Diese müssen Sie ausdrucken, unterschreiben und an die angegebene Adresse schicken.' :
                    '<b>Remarks:</b> You may apply for the membership in the Graduate School of the University of Bayreuth. 
Applications for membership must be carried out in the <b>first year of PhD</b>.
For your application as a member to the University of Bayreuth Graduate School, please upload your: 
<br/>(1) CV in section "Education" 
<br/>(2) Supervision agreement (in BIGSAS IRTP) in section "PhD". 
<br/>You will get a link to a PDF-file on the confirmation page.
			Please print out the file, sign and send to the given address.');

                echo '<form action="../../intern/baydoc/antrag_pdf.php" target="_blank">
<input type="hidden" name="gs" value="1">
<input type="hidden" name="id_obj" value="' . $this->doc->getId() . '">
<input type="submit" value="' . ($this->context->lang == "de" ? "PDF-Antrag - Vorschau" : 'PDF Application Preview') . '"></form>';
                echo '<br/>
	<br/>
	<form action="?tab=gs&aktion=finish&id=' . $this->doc->getId() . '" method="post">
	<input type="checkbox" name="gs_antrag"> ' . ($this->context->lang == 'de' ? 'Hiermit beantrage ich die Mitgliedschaft in der Graduate School der Universtiät Bayreuth' :
                        'Hereby I apply for membership in the Graduate School of the University of Bayreuth') . '
	<br/>
	<input type="submit" value="' . ($this->context->lang == 'de' ? 'Antrag abschicken' : 'submit application') . '"></form>';
            } else {
                echo "<h3>University of Bayreuth Graduate School - " . ($this->context->lang == 'de' ? 'Mitgliedschaft' : 'Membership') . '</h3>';
                echo "<p>" . ($this->context->lang == 'de' ?
                    'Antrag ist nicht mehr möglich. Ihr Annahmedatum liegt mehr als ein Jahr zurück' :
                    'Application is no longer possible. Starting date ouf your PhD is more than one year ago') . "</p>";

            }

        } else {
            echo "<h3>University of Bayreuth Graduate School - " . ($this->context->lang == 'de' ? 'Mitgliedschaft' : 'Membership') . '</h3>';
            echo "<p>" . ($this->context->lang == 'de' ?
                'An dieser Stelle werden Sie den Antrag zur Mitgliedschaft in der University of Bayreuth Graduate School sehen,
 wenn Sie von der promovierenden Einrichtung laut Promotionsordnung zur Promotion angenommen wurden (Angenommen zur Promotion).<br/> 
Für den Antrag auf Mitgliedschaft in der UBT Graduate School halten Sie bitte noch pdf-Dateien eines CV und der Betreuungsvereinbarung bereit.

 ' :
                'At this point, you will see the application for membership of the University of Bayreuth Graduate School, 
if you have been accepted by the faculty/BayNAT or BIGSAS according to the doctoral degree regulations 
(acceptance for doctoral studies).  <br/>
For the application for membership in the UBT Graduate School, please provide pdf files of a CV and the supervision agreement.

 

 ') . "</p>";



        }

    }
}