<?php

namespace BayDOC\Tabs;

class DocHstatg extends DocAdministration
{
    public static array $prom_art_stat = [
        ['01', 'Promotion (einschl. Kooperation mit anderer Universität in Deutschland)'],
        ['02', 'Promotion in Kooperation mit Universität im Ausland'],
        ['03', 'Promotion in Kooperation mit Fachhochschule'],
        ['04', 'Promotion in Kooperation mit Forschungseinrichtung'],
        ['05', 'Promotion in Kooperation mit Wirtschaft oder sonstiger Einrichtung']
    ];

    public static array $semester_schluessel = [
        ['1', 'Sommersemester'],
        ['2', 'Wintersemester']
    ];

    public static array $noten_schluessel = [
        ['n0', 'Mit Auszeichnung'],
        ['n1', 'Sehr gut'],
        ['n2', 'Gut'],
        ['n7', 'Vollbefriedigend (Nur Staatsprüf./Magister)'],
        ['n3', 'Befriedigend'],
        ['n4', 'Ausreichend'],
        ['n8', 'Bestanden, Note nicht bekannt']
    ];
    public static array $prom_art = [
        ['506', 'Promotion'],
        ['592', 'Promotion nach FH-Abschluss'],
        ['591', 'Strukturiertes Promotionsstudium']
    ];
    public static array $diss_art = [
        ['01', 'Monographie'],
        ['02', 'kumulativ']
    ];


    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $this->skip_empty=true;
        $this->admin_actions=['HStatG'];

        $this->addField(new \BayCMS\Field\Select(
            $context,
            'action',
            'Bearbeiter-Aktion',
            values: $this->admin_actions,
            null: true,
            non_empty: true,
            no_add_to_query: true,
            not_in_table: true
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $context,
            'action_comment',
            'Bearbeiter Kommenentar',
            no_add_to_query: true,
            not_in_table: true
        ));

        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'no_hstatg',
            'Datensatz von HStatG-Meldung ausschließen'
        ));

        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'meldungen',
            '<h3>Meldungen</h3>',
            div_id: 'Meldungen'
        ));

        for ($y = 2017; $y <= min(date('Y') - 1, 2027); $y++) {
            $this->addField(new \BayCMS\Field\TextInput(
                $context,
                "hstatg$y",
                "Paginiernummer Meldung $y",
                input_options: ' readonly disabled',
                no_add_to_query: 1
            ))->set(['left_join'=>'add_to_query']);
        }
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            "hstatg_ef13",
            "Gemeldeter Promotionsbeginn (EF13)",
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            "hstatg_ef14",
            "Gemeldetes Promotionsende/Abbruch (EF14)",
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);

        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'puefungs_stat',
            '<h3>Meldungen Prüfungsstatistik</h3>'
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            "hstatg_mp_date",
            "Meldung",
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            "hstatg_mp_nummer",
            "Paginiernummer Meldung",
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);

        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'prom_berichtsjahr',
            '<h3>Promotion im Berichtsjahr</h3>',
            div_id: 'Promotion'
        ));

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'hstatg_meldenummer',
            'Erstmeldenummer',
            help: 'Diese Nummer wird beim ersten Export gesetzt',
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);

        $this->addField(new \BayCMS\Field\Select(
            $context,
            'hstatg_prom_art',
            'Art der Promotion (EF10)',
            values: DocHstatg::$prom_art_stat,
            null: 1
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            $context,
            'hstatg_fach',
            description: 'Promotionsfach (EF11)',
            target: 'stgfaecher.php',
            db_query: 'select id,name||\' (\'||signatur||\')\' as description 
        from baydoc_stgfach where id=$1'
        ))->set(['left_join'=>'baydoc_stgfach','left_join_name'=>'prom_fach']);
        $this->addField(new \BayCMS\Field\YesNo(
            $context,
            'hstatg_immatrikuliert',
            'Immatrikulation (EF15)'
        ));
        $this->addField(new \BayCMS\Field\YesNo(
            $context,
            'hstatg_promprog',
            'Teilnahme an einem strukturierten Promotionsprogramm (EF16)'
        ));
        $this->addField(new \BayCMS\Field\YesNo(
            $context,
            'hstatg_beschaeftigt',
            'Beschäftigungsverhältnis an der Hochschule der Promotion (EF17)'
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'hstatg_diss_art',
            'Art der Dissertation (EF18)',
            values: DocHstatg::$diss_art,
            null: 1
        ));

        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'Ersteinschreigung',
            '<h3>Ersteinschreibung (als Studierender)</h3>',
            div_id: 'Ersteinschreibung'
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_erst_hs',
            target: 'stat_hs.php',
            db_query: 'select id,name as description from stat_hs where id=$1',
            help: $this->t(
                'Look for your university. If the university is not in Germany add &quot;Hochschule im Ausland&quot; here',
                'Suchen Sie hier Ihre Universität. Wenn die Universität nicht in Deutschland ist, wählen Sie &quot;Hochschule im Ausland&quot;'
            ),
            description: 'Hochschule (EF19)'
        ))->set(['left_join'=>'stat_hs','left_join_name'=>'bachelor_hs']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_erst_hs_land',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            target: 'stat_laender.php',
            description: 'Bei Ersteinschreibung an einer Hochschule außerhalb Deutschlands: Staat der HS (EF20)'
        ))->set(['left_join'=>'stat_laender','left_join_name'=>'bachelor_land']);
        $this->addField(new \BayCMS\Field\Select(
            context: $context,
            name: 'hstatg_erst_semester',
            values: DocHstatg::$semester_schluessel,
            description: 'Semester (EF21)',
            null: true
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'hstatg_erst_jahr',
            description: 'Jahr der Ersteinschreibung (EF22)',
            min: 1930,
            max: date('Y'),
            placeholder: $this->t('YYYY', 'JJJJ')
        ));

        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'abschluss',
            '<h3>Zur Promotion berechtigende, vorangegangene bestandene Abschlussprüfung</h3>',
            div_id: 'Hochschulabschluss'
        ));

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_hs',
            target: 'stat_hs.php',
            db_query: 'select id,name as description from stat_hs where id=$1',
            description: 'Hochschule (EF24)'
        ))->set(['left_join'=>'stat_hs','left_join_name'=>'master_hs']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_hs_land',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            target: 'stat_laender.php',
            description: 'Wenn Hochschule der zur Promotion berechtigenden Prüfung außerhalb Deutschlands: Staat der HS (EF25)'
        ))->set(['left_join'=>'stat_laender','left_join_name'=>'master_land']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_art',
            db_query: "select id,pruef||' - '||zusatz as description from stat_art where id=\$1",
            target: 'stat_art.php',
            description: 'Art der Prüfung (EF26)'
        ))->set(['left_join'=>'stat_art','left_join_name'=>'master_art']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_fach',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from baydoc_stgfach where id=\$1",
            target: 'stgfaecher.php',
            description: '1. Studienfach (EF27)'
        ))->set(['left_join'=>'baydoc_stgfach','left_join_name'=>'master_fach']);
        $this->addField(new \BayCMS\Field\Date(
            $context,
            name: 'hstatg_ab_datum',
            description: 'Datum des Prüfungsabschlusses (EF28+EF29)'
        ));
        $this->addField(new \BayCMS\Field\Select(
            context: $context,
            name: 'hstatg_ab_note',
            values: DocHstatg::$noten_schluessel,
            description: 'Gesamtnote (EF30)',
            null: true
        ));
        
        $this->addField(new \BayCMS\Field\Comment($context,'Hochschulzugangsberechtigung',
         '<h3>Hochschulzugangsberechtigung</h3>',div_id: 'Hochschulzugangsberechtigung'));
         $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'hstatg_hzb_jahr',
            description: 'Jahr des ersten Erwerbs einer HZB (EF31)',
            min: 1930,
            max: date('Y') - 10,
            placeholder: $this->t('YYYY', 'JJJJ')
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_art',
            target: 'stat_hr.php',
            db_query: "select id, gruppe||' '||pruef as description from stat_art where id=\$1",
            description: 'Art der ersten HZB (EF32)'
        ))->set(['left_join'=>'stat_art','left_join_name'=>'hzb_art']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_kreis',
            target: 'stat_kreise.php',
            db_query: 'select id,bundesland||\'/\'||kreis as description from stat_kreise where id=$1',
            description: 'Ort (EF33)'
        ))->set(['left_join'=>'stat_kreise','left_join_name'=>'hzb_kreis']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_land',
            target: 'stat_laender.php',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            description: 'Wenn HZB im Ausland erworben: Land (EF33)'
        ))->set(['left_join'=>'stat_laender','left_join_name'=>'hzb_land']);
        
    }



}