<?php

namespace BayDOC\Tabs;

class DocProm extends DocAdministration
{
    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $admin = $doc->getRole() == 'admin';
        $footnote = ['*', $this->t('mandatory', 'Pflichtfeld')];
        $this->admin_actions = ['Betreuungsvereinbarung', 'HStatG-Felder'];
        if ($context->org_folder == 'bigsas')
            $this->admin_actions = array_merge(
                $this->admin_actions,
                ['Motivationsschreiben', 'IRTP', 'Finanzierung', 'Publikationsliste', 'Masterarbeit', 'Recommendation', 'Proposal', 'Self- Declaration']
            );

        $faecher = false;
        if ($doc->getId()) {
            $res = pg_query_params(
                $context->getDbConn(),
                'select faecher_ids from bayprof where id=$1',
                array($doc->getRow()['b_id'])
            );

            if (pg_num_rows($res))
                [$faecher] = pg_fetch_row($res, 0);
            if (!$faecher)
                $config = $context->getModConfig('baydoc', 'faecher');
            if (!$faecher && $doc->getRow()['b_id']) {
                //Suche der Fächer über Prof-Fakultät
                $res = pg_query_params(
                    $context->getDbConn(),
                    "select l.id from lehrstuhl l, bayprof p 
        where 'Fakultät '||substring(p.fakultaet from '^[^/]*')=l.de and p.id=\$1",
                    [$doc->getRow()['b_id']]
                );
                if (pg_num_rows($res))
                    [$prof_ls_id] = pg_fetch_row($res, 0);
                else
                    $prof_ls_id = 0;
                $res = pg_query_params(
                    $context->getDbConn(),
                    "select c.value from modul_ls_config c, modul_default_config d
    where d.mod='baydoc' and d.uname='faecher' and d.id=c.id_modconfig and c.id_lehr=\$1",
                    [$prof_ls_id]
                );
                if (pg_num_rows($res))
                    [$faecher] = pg_fetch_row($res, 0);
            }
            if ($faecher && $doc->getRow()['hstatg_fach'])
                $faecher .= ',' . $doc->getRow()['hstatg_fach'];
        }

        $fach_namen_sql = ($this->de() ? 'non_empty(co,name)' :
            "non_empty(en,co)|| case when en>'' then ' ('||non_empty(co,name)||')' else '' end");
        $fach_name = ($this->de() ? 'Fach' : 'Subject');
        if ($faecher)
            $this->addField(new \BayCMS\Field\Select(
                $context,
                'hstatg_fach',
                $fach_name,
                null: 1,
                db_query: 'select id,' . $fach_namen_sql . ' as description from baydoc_stgfach 
    where id in(' . $faecher . ') order by 2',
                non_empty: !$admin
            ));
        else
            $this->addField(new \BayCMS\Field\SelectJS(
                $context,
                'hstatg_fach',
                description: $fach_name,
                target: 'stgfaecher.php',
                db_query: 'select id,' . $fach_namen_sql . ' as description from baydoc_stgfach where id=$1',
                non_empty: !$admin
            ))->set(['left_join' => 'baydoc_stgfach', 'left_join_name' => 'prom_fach']);

        $this->addField(new \BayCMS\Field\Textarea(
            $context,
            'arbeitstitel',
            $this->t(
                'Topic of the thesis (working title)',
                'Thema der Promotion (Arbeitstitel)'
            ),
            non_empty: !$admin
        ));

        $this->addField(new \BayCMS\Field\Select(
            $context,
            'hstatg_diss_art',
            $this->t('Type of Thesis (planned)', 'Art der Dissertation (aktueller Plan)'),
            values: DocHstatg::$diss_art,
            help: 'Please select the type or your thesis: Monographie==One single Book - kumulativ==several papers',
            null: 1,
            non_empty: !$admin
        ));

        $this->addField(new \BayCMS\Field\Date(
            $context,
            'pstart2',
            $this->t(
                'Acceptance for doctorate of previous doctoral studies at another German HEI',
                'Annahme zur Promotion an vorheriger Hochschule in Deutschland'
            ),
            help: $this->t(
                'mandatory if a doctorate was started at another German higher education institution',
                'Pflichtangabe falls eine Promotion an einer anderen deutschen Hochschule begonnen wurde'
            )
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'funding',
            $this->t('Funding', 'Finanzierung'),
            null: 1,
            values: [
                ['Landesstelle', $this->t('employed at UBT as assistant professor', 'Landesstelle')],
                ['Drittmittel', $this->t('project employment', 'Drittmittel')],
                ['Stipendium', $this->t('scholarship', 'Stipendium')],
                ['Außerhalb UBT berufstätig („externe Promotion“)', $this->t('external employment (“external PhD”)', 'Außerhalb UBT berufstätig („externe Promotion“)')],
                ['Sonstige Finanzierung', $this->t('other funding', 'Sonstige Finanzierung')]
            ],
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'funding_text'
            ,
            $this->t(
                'Funding (if other funding as been choosen above)',
                'Finanzierung (wenn oben Sonstige Finanzierung gewählt wurde)'
            )
        ));


        $prom_art = [
            ['01', $this->t('no joint degree or joint degree contracted with German university', 'keine Kooperation oder Kooperation mit deutscher Universität')],
            ['02', $this->t('with univertity abroad', 'Promotion in Kooperation mit Universität im Ausland')],
            ['03', $this->t('with FH ( German University of Applied Science)', 'Promotion in Kooperation mit Fachhochschule')],
            ['04', $this->t('with research institution', 'Promotion in Kooperation mit Forschungseinrichtung')],
            ['05', $this->t('with company or other institution', 'Promotion in Kooperation mit Wirtschaft oder sonstiger Einrichtung')]
        ];
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'hstatg_prom_art',
            $this->t('Joint degree contracted', 'Vertraglich fixierte gemeinsame Promotion'),
            values: $prom_art,
            null: 1,
            non_empty: !$admin,
            help: $this->t(
                'Only choose other than &quot;no joint degree ... &quot; when there is a contract for the cooperation.',
                'Es muss sich um eine institutionelle Kooperation handen. Der Kooperation muss ein Vertrag oder eine Vereinbarung zugrunde liegen. Bei mehreren Kooperationen ist immer nur die erste zutreffende Ausprägung zu melden.'
            )
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'coop_text',
            $this->t(
                'Name of the joint degree institution',
                'Name der Kooperationseinrichtung'
            )
        ));

        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'betreuungsvereinbarung',
            uname: 'agreement',
            description: $this->t('supervision agreement', 'Betreuungsvereinbarung'),
            help: $this->t(
                'Please upload here your supervision agreement',
                'Bitte laden Sie hier Ihre Betreuungsvereinbarung hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ))->set(['left_join' => 'file', 'left_join_name' => 'agreement_file']);
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'zertifikat_gwp',
            uname: 'good_academic_practice',
            description: $this->t('certificate Good Scientific Practice', 'Zertifikat Gute Wissenschaftliche Praxis'),
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            help: $this->t(
                'Only for UBTGS members: Please upload your certificate after completing the e-learning course on Good Scientific Practice',
                'Nur für Mitglieder der UBTGS: Bitte laden Sie das Zertifikat zum E-Learning-Kurs „Gute Wissenschaftliche Praxis“ hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i'
        ))->set(['left_join' => 'file', 'left_join_name' => 'gwp_file']);
        $this->addField(new \BayCMS\Field\Comment(
            $context,
            'bigsas_uploads',
            '<h3>' . $this->t(
                'Only for applicants for a doctorate from BIGSAS (Bayreuth International Graduate School of African Studies)',
                'Nur für Bewerber*innen bei BIGSAS (Bayreuth International Graduate School of African Studies)'
            ) . '</h3>'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_motivation',
            uname: 'motivation',
            description: $this->t('letter of motivation', 'Motivationsschreiben'),
            help: $this->t(
                'Please upload a one-page letter of motivation in which you explain why you apply to BIGSAS ',
                'Bitte laden Sie Ihr Motivationsschreiben hoch, in dem Sie erklären wieso Sie sich bei BIGSAS bewerben (1 Seite).'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_irtp',
            uname: 'bigsas_irtp',
            description: $this->t('Individual Research Training Plan', 'Individual Research Training Plan'),
            help: $this->t(
                'Please upload your Individual Research Training Plan',
                'Bitte laden Sie den Individual Research Training Plan hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_finanz',
            uname: 'bigsas_finanz',
            description: $this->t('certificate of funding', 'Bescheinigung über Finanzierung'),
            help: $this->t(
                'Please upload a certificate of funding for your doctoral studies',
                'Bitte laden Sie eine Bescheinigung über die Finanzierung Ihrer Promotion hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_publist',
            uname: 'bigsas_publist',
            description: $this->t('publication list', 'Publikationsliste'),
            help: $this->t(
                'Please upload your publication list here',
                'Bitte laden Sie hier Ihre Publikationsliste hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_master',
            uname: 'bigsas_master',
            description: $this->t('master thesis', 'Masterarbeit'),
            help: $this->t(
                'Please upload your master thesis here',
                'Bitte laden Sie hier Ihre Masterarbeit hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_recommendation',
            uname: 'bigsas_recommendation',
            description: $this->t('Recommendation', 'Empfehlungsschreiben'),
            help: $this->t(
                'Please upload in one PDF two recommendations here',
                'Bitte laden Sie hier in einer PDF zwei Gutachten hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_proposal',
            uname: 'bigsas_proposal',
            description: $this->t('Proposal', 'Proposal'),
            help: $this->t(
                'Please upload your proposal including a summary of your proposal',
                'Bitte laden Sie hier Ihr Proposal inkl. Zusammenfassung hoch'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $context,
            'bigsas_self_declaration',
            uname: 'bigsas_self_declaration',
            description: $this->t('Self-Declaration', 'Eigenerklärung'),
            help: $this->t(
                'Please upload in one PDF your self-declaration that you have not been accepted for a doctorate at another university or are enrolled at another university or university of applied sciences.',
                'Bitte laden Sie hier in einer PDF Ihre Eigen-Erklärung hoch, dass Sie keine Annahme zur Promotion oder Einschreibung an einer anderen Universität oder HAW/FH haben.'
            ) . ' (max. 2 MB)',
            accept: 'application/pdf',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024,
            preg_match: '/\\.pdf$/i'
        ));

        if ($admin) {
            $this->addField(new \BayCMS\Field\Comment(
                $context,
                'admin_fields',
                '<h3>Administratorenfelder</h3>'
            ));
            $this->addField(new \BayDOC\Field\AdminOK(
                context: $context,
                name: 'admin_bigsas',
                description: 'Prüfung BIGSAS'
            ));

            $this->addField(new \BayCMS\Field\Select(
                $context,
                'action',
                'Bearbeiter-Aktion',
                values: $this->admin_actions,
                null: true,
                non_empty: true,
                no_add_to_query: true,
                not_in_table: true
            ));
            $this->addField(new \BayCMS\Field\Textarea(
                $context,
                'action_comment',
                'Bearbeiter Kommenentar',
                no_add_to_query: true,
                not_in_table: true
            ));
        }


    }

    public function print()
    {
        $this->load($this->doc->getId());
        if (($_GET['aktion'] ?? false) && !$this->editAllowed())
            unset($_GET['aktion']);
        if ($_GET['aktion'] ?? '') {
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }
            if (
                $_GET['aktion'] == 'save' &&
                ($_POST['funding'] == 'Sonstige Finanzierung' && !$_POST['funding_text'])
            ) {
                $this->getField('funding_text')->setError(true);
                $GLOBALS['TE']->printMessage($this->t('Please give a funding', 'Bitte geben Sie eine Finanzierung an'), 'danger');
                $_GET['aktion'] = 'edit';
            }
            if (
                $_GET['aktion'] == 'save' &&
                (in_array($_POST['hstatg_prom_art'], ['02', '03', '04', '05']) && !$_POST['coop_text'])
            ) {
                $this->getField('coop_text')->setError(true);
                $GLOBALS['TE']->printMessage($this->t('Please give the name of the joint degree institution', 'Bitte geben Sie eine Kooperationseinrichtung an'), 'danger');
                $_GET['aktion'] = 'edit';
            }



            if ($_GET['aktion'] == 'save') {
                $this->save();
                $GLOBALS['TE']->printMessage($this->t('Saved entry', "Eintrag gespeichert"));
                unset($_GET['aktion']);
                if ($this->doc->getAntrag())
                    echo $this->getJSRedirect("?tab=register&id=" . $this->doc->getId() . "&aktion=edit");

            } else {
                if ($this->doc->getAntrag())
                    $GLOBALS['TE']->printMessage($this->getComment());
                echo $this->getForm($this->t('Edit Entry', 'Eintrag bearbeiten'));
            }
        }
        if (!isset($_GET['aktion'])) {
            $GLOBALS['TE']->printMessage($this->getComment());
            echo $this->getTable(delete_link: false, edit_link: $this->editAllowed(), object_link: false, pos: 'top');
            if ($this->doc->getRole() == 'admin')
                echo $this->getAdminHistory();
        }

    }



    public function editAllowed(): bool
    {
        return ($this->doc->getRole() == 'admin' || $this->doc->getRole() == 'selbst')
            && !$this->doc->locked();
    }


    public function getComment(): string
    {
        return $this->t(
            'In this section, we need information on your doctorate. Mandatory fields according to the Higher Education Statistics Act (HStatG) are marked with an *.
	Further required data for the Higher Education Statistics Act is also listed in section “Examination & Statistics”',
            'In diesem Abschnitt benötigen wir Informationen zu Ihrer Promotion. Alle verpflichtenden Felder nach dem Hochschulstatistikgesetz (HStatG) sind mit einem * markiert.
Weitere benötige Angaben für die Statistik sehen Sie im Reiter „Prüfung & Statistik“.'
        );

    }
}