<?php

namespace BayDOC\Tabs;

class DocPs extends Doc
{

    public function print()
    {
        $f = [
            'email' => ['Email', 'Email'],
            'prue_abgabe' => ['Abgabe Dissertation und vollständige Unterlagen im Dekanat', 'Submission of thesis and required document'],
            'prue_prom_komm' => ['Datum der Promotionskommission', 'Date of doctoral committee or executive board meeting'],
            'prue_zulassung' => ['Zulassung zum Promotionsprüfungsverfahren', 'Admission to the doctoral examination process'],
            'prue_gut1' => ['Gutachter*in 1', 'Thesis reviewer 1'],
            'prue_best_gut1' => ['Bestellung Gutachter*innen 1 und Versand der Druckexemplare', 'Appointment of thesis reviewer 1 and forwarding of copies'],
            'prue_ein_gut1' => ['Eingang Gutachten 1', 'Receipt of review 1'],
            'prue_gut2' => ['Gutachter*in 2', 'Thesis reviewer 2'],
            'prue_best_gut2' => ['Bestellung Gutachter*innen 2 und Versand der Druckexemplare', 'Appointment of thesis reviewer 2 and forwarding of copies'],
            'prue_ein_gut2' => ['Eingang Gutachten 2', 'Receipt of review 2'],
            'prue_gutw' => ['weitere Gutachter*in', 'Further thesis reviewers'],
            'prue_best_gutw' => ['Bestellung weiterer Gutachter*innen', 'Appointment of further theisis reviewer'],
            'prue_ein_gutw' => ['Eingang weitere Gutachten', 'Receipt of further reviews'],
            'prue_aus_start' => ['Beginn der Auslagefrist', 'Start of inspection period'],
            'prue_aus_end' => ['Ende der Auslagefrist', 'End of inspection period'],
            'prue_mit_koll' => ['Mitteilung des Kolloquium-Termins', 'Notification of thesis defence date'],
            'ef13' => ['Gemeldeter Promotionsbeginn (i.d.R. Annahme zur Promotion)', 'Start of doctoral studies (usually acceptance as doctoral candidate)'],
            'hstatg_prom_art' => ['Art der Promotion', 'Type of Doctorate'],
            'hstatg_fach' => ['Promotionsfach', 'Doctoral subject'], //
            'hstatg_immatrikuliert' => ['Immatrikulation', 'Enrolment'],
            'hstatg_promprog' => ['Teilnahme an einem strukturierten Promotionsprogramm', 'Participation in a structured doctoral programme'],
            'ef17_prog' => ['Strukturiertes Programm:', 'Structured programme:'],
            'hstatg_beschaeftigt' => ['Beschäftigungsverhältnis an UBT zum Stichtag 1.12.', 'Employment at the University of Bayreuth at Dec 1'],
            'hstatg_diss_art' => ['Art der Dissertation', 'Type of Thesis'],
        ];

        $hl = [
            'prue_abgabe' => ["Daten im Promotionsprüfungsverfahren", "Timetable within the Doctoral Examination Process"],
            'ef13' => ["Angaben für die amtliche Statistik (HStatG)", "Required Data for the Higher Education Statistics Act"],
        ];

        $ft = [
            'prue_abgabe' => 'date',
            'prue_prom_komm' => 'date',
            'prue_zulassung' => 'date',
            'prue_best_gut1' => 'date',
            'prue_best_gut2' => 'date',
            'prue_best_gutw' => 'date',
            'prue_ein_gut1' => 'date',
            'prue_ein_gut2' => 'date',
            'prue_ein_gutw' => 'date',
            'prue_gut1' => 'fk',
            'prue_gut2' => 'fk',
            'prue_gutw' => 'fk',
            'prue_aus_start' => 'date',
            'prue_aus_end' => 'date',
            'prue_mit_koll' => 'date',
            'ef13' => 'sql',
            'hstatg_prom_art' => 'select',
            'hstatg_fach' => 'sql',
            'hstatg_immatrikuliert' => 'bool',
            'hstatg_promprog' => 'bool',
            'ef17_prog' => 'sql',
            'hstatg_beschaeftigt' => 'bool',
            'hstatg_diss_art' => 'select'
        ];

        $lang=$this->context->lang;
        $lang2=$this->context->lang2;
        $sql = [
            'ef13' => "to_char(case when d.pstart2 is not null then d.pstart2
            when least(d.zulassung_zulassung,d.zulassung) is null
            then d.pstart else
            least(d.zulassung_zulassung,d.zulassung) end,'DD.MM.YYYY')",
            'hstatg_fach' => 'f.' . ($lang == 'de' ? 'name' : 'en'),
            'ef17_prog' => "case when d.hstatg_promprog then non_empty(l.$lang,l.$lang2) else '-' end"
        ];


        $query = '';
        if ($lang == 'de') {
            $true = "Ja";
            $false = "Nein";
        } else {
            $true = "Yes";
            $false = "No";

        }

        $hstatg_prom_art = [
            '01' => 'Promotion (einschl. Kooperation mit anderer Universität in Deutschland)',
            '02' => 'Promotion in Kooperation mit Universität im Ausland',
            '03' => 'Promotion in Kooperation mit Fachhochschule',
            '04' => 'Promotion in Kooperation mit Forschungseinrichtung',
            '05' => 'Promotion in Kooperation mit Wirtschaft oder sonstiger Einrichtung'
        ];

        $hstatg_diss_art = [
            '01' => 'Monographie',
            '02' => 'kumulativ'
        ];


        foreach ($f as $key => $value) {
            switch ($ft[$key]??'') {
                case 'fk':
                    $query .= "$key.titel||' '||$key.vname||' '||$key.nname as $key,";
                    break;
                case 'date':
                    $query .= "to_char(d.$key,'DD.MM.YYYY') as $key,";
                    break;
                case 'sql':
                    $query .= "$sql[$key] as $key,";
                    break;
                case 'bool':
                    $query .= "case when d.$key then '$true' else '$false' end as $key,";
                    break;
                default:
                    $query .= "d.$key,";
            }
        }


        $res = pg_query_params($this->context->getDbConn(), "select $query d.id from baydoc d 
        left outer join baydoc_stgfach f on f.id=d.hstatg_fach
        left outer join lehrstuhl l on l.id=d.id_lehr
        left outer join bayprof prue_gut1 on prue_gut1.id=d.prue_gut1_id
        left outer join bayprof prue_gut2 on prue_gut2.id=d.prue_gut2_id
        left outer join bayprof prue_gutw on prue_gutw.id=d.prue_gutw_id
        
         where d.id=" . '$1 and check_objekt($1,$2)', [$this->doc->getId(), $this->context->getUserId()]);

        echo $GLOBALS['TE']->printMessage($this->getComment());
        echo "<table " . $GLOBALS['TE']->getCSSClass("table") . ">";
        $r = pg_fetch_array($res);
        reset($f);
        $i = 0;
        if ($lang == 'en')
            $i = 1;
        foreach ($f as $key => $value) {
            if (isset($hl[$key]))
                echo "<tr><th colspan=2 style=\"font-weight:bold;\">" . $hl[$key][$i] . "</th></tr>";
            echo "<tr><td>$value[$i]</td><td>";
            if (($ft[$key]??'') == "select")
                echo ${$key}[$r[$key]]??'';
            else
                echo $r[$key];
            echo "</td></tr>";
        }
        echo "</table>";

        echo "<p>" . ($lang == "de" ? "Bitte prüfen Sie außerdem die Angaben im <a href=\"?tab=uni&id=".$this->doc->getId()."\">Reiter Ausbildung</a>" :
            "Please also check your <a href=\"?tab=uni&id=".$this->doc->getId()."\">education tab</a>") . "</p>";

    }

    public function getComment(): string
    {
        return $this->t(
            'On this page you can see dates within the doctoral examination process and required data for 
        the Higher Education Statistics Act (Hochschulstatistikgesetz - HStatG § 5 (2)). 
        Please check this data and contact graduateschool@uni-bayreuth.de for updates.',
            'Auf dieser Seite finden Sie Daten zum Promotionsprüfungsverfahren und Merkmale, 
        die nach Hochschulstatistikgesetz (HStatG § 5(2)) erhoben und gemeldet werden. 
        Bitte überprüfen Sie die Angaben. Bei Aktualisierungen wenden Sie sich bitte an graduateschool@uni-bayreuth.de.'
        );
    }
}