<?php

namespace BayDOC\Tabs;

class DocPub extends Doc
{
    private \BayCMS\Fieldset\Domain $domain;

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $this->domain = new \BayCMS\Fieldset\Domain(
            $context,
            'baydoc_pub',
            uname: 'baydoc_pub',
            from: 'objekt o, baydoc_pub t left outer join benutzer b on b.id=t.ok_id_benutzer',
            where: 't.id=o.id and o.id_obj=' . $doc->getId(),
            qs: 'tab=pub&id=' . $doc->getId(),
            id_name: 'id_pub',
            write_access_query: $doc->locked() ? 'false' : 'ok_datum is null',
            copy: false,
            object_button: false,
            delete_button: $doc->getRole() != 'bm',
            erase_object: true
        );
        $this->domain->setListProperties(
            export_buttons: false,
            new_button: !$doc->locked() && $doc->getRole() != 'bm',
            actions: ['edit']
        );

        $this->domain->addField(new \BayCMS\Field\Hidden(
            $context,
            'id_parent',
            default_value: $doc->getId(),
            non_empty:1,
            no_add_to_query: 1,
            type: 'int'
        ));
        $this->domain->addField(new \BayCMS\Field\Date(
            $context,
            'datum',
            $context->t('Date of publication', 'Publikationsdatum'),
            non_empty: 1,
        ))->set(['list_field' => 1, 'edit_field' => $doc->getRole() != 'bm']);
        $this->domain->addField(new \BayCMS\Field\Textarea(
            $context,
            'zitat',
            $context->t('Scientific citation', 'Wissenschaftliches Zitat'),
            non_empty: 1,
            input_options: $doc->getRole() == 'bm' ? ' readonly disabled' : ''
        ))->set(['list_field' => 1, 'edit_field' => $doc->getRole() != 'bm']);
        if ($doc->getRole() != 'bm') {

            $this->domain->addField(new \BayCMS\Field\URL(
                $context,
                'url',
                'URL (alternativ' . ($context->lang == 'en' ? 'e' : '') . ' PDF)'
            ));
            $this->domain->addField(new \BayCMS\Field\UploadFile(
                $context,
                'pdf',
                'PDF (alternativ' . ($context->lang == 'en' ? 'e for' : ' zu') . ' URL)'
            ));
        }
        if ($doc->getRole() == 'bm' || $doc->getRole() == 'admin' && isset($_GET['debug_bm'])) {
            $res = pg_query_params(
                $context->getDbConn(),
                "select p.*,of.id as id_file,b.kommentar,b.login,to_char(p.ok_datum,'DD.MM.YYYY')
				from objekt o,baydoc_pub p left outer join objekt of on of.id_obj=p.id left outer join benutzer b on b.id=p.ok_id_benutzer
				where p.id=o.id and o.id_obj=" . $doc->getId() . " and o.id=\$1",
                [$_GET['id_pub']]
            );
            $r = pg_fetch_array($res, 0);
            if ($r['id_file'])
                $r['url'] = "../../intern/baydoc/get_file.php?id=$r[id_file]";
            $this->domain->addField(new \BayCMS\Field\Comment(
                $context,
                'zitat',
                "$r[zitat]<br/><a href=\"$r[url]\" target=\"_blank\">[Details]</a>"
            ));
            $mailer = new \BayDOC\Util\Mail($context);
            $this->domain->addField(new \BayCMS\Field\Checkbox(
                $context,
                'ok',
                $mailer->getMailText('pub_pruef_' . $context->lang),
                non_empty:1
            ));
            $this->domain->addField(new \BayCMS\Field\Hidden(
                $context,
                'ok_id_benutzer',
                default_value: $context->getUserId(),
                non_empty:1,
                type: 'int'
            ));

        }
        $this->domain->addField(new \BayCMS\Field\Hidden(
            $context,
            'ok_datum',
            $context->t('checked on', 'geprüft am'),
            non_empty: 1,
            default_value: date('Y-m-d'),
            sql: "to_char(t.ok_datum,'DD.MM.YYYY')||'<br/>'||b.kommentar"
        ))->set(['list_field' => 1, 'edit_field' => $doc->getRole() == 'bm']);

    }
    public function print()
    {
        $edit = $this->domain->getEdit();
        if ($edit['error'])
            $GLOBALS['TE']->printMessage($edit['error'], 'danger');
        if ($edit['message'])
            $GLOBALS['TE']->printMessage($edit['message']);
        echo $edit['html'];
        echo $this->domain->getList()['html'];
    }

    public function editAllowed(): bool
    {

        return !$this->doc->locked();
    }


}