<?php

namespace BayDOC\Tabs;

class DocRegister extends DocForm
{
    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $this->addField(new \BayCMS\Field\Checkbox(
            $context,
            'hinweise_gelesen',
            $this->t(
                'I agree that the University of Bayreuth may use this information for internal and HStatG (German statistic act) purposes',
                'Ich stimme zu, dass die Universität Bayreuth diese Angaben für interne und Hochschulstatistikgesetz Zwecke verwendet'
            ),
            no_add_to_query: 1,
            non_empty: 1
        ));

    }

    private function finish()
    {
        ignore_user_abort(true);
        $id = $this->doc->getId();
        $r = $this->doc->getRow();
        $r['b_token'] = md5(random_bytes(20));
        $r['m1_token'] = md5(random_bytes(20));
        $r['m2_token'] = md5(random_bytes(20));
        $r['m3_token'] = md5(random_bytes(20));
        pg_query_params(
            $this->context->getRwDbConn(),
            'update baydoc set
		b_token=$2,
		m1_token=$3,
		m2_token=$4,
		m3_token=$5,antrag=false,reg_time=now() where id=$1',
            [$id, $r['b_token'], $r['m1_token'], $r['m2_token'], $r['m3_token']]
        );

        pg_prepare(
            $this->context->getRwDbConn(),
            'zulassung',
            'insert into baydoc_zulassung(id_stud,datum,id_kat,id_benutzer,id_lehr)
        select $1,now()::date,$4,$2,$3 except select id_stud,now()::date,id_kat,id_benutzer,id_lehr
        from baydoc_zulassung where id_stud=$1'
        );

        //z.B. Anmeldung zu Peer aber bereits Individual-Promotion?
        if (
            $this->context->get('row1', 'baydoc_profile') > 0 &&
            $r['id_lehr'] != $this->context->getOrgId()
        ) {
            pg_query_params(
                $this->context->getRwDbConn(),
                'delete from objekt_ls where id_obj=$1 and id_lehr=$2',
                [$id, $r['id_lehr']]
            );
            pg_query_params(
                $this->context->getRwDbConn(),
                'delete from baydoc_zulassung where id_stud=$1 and id_lehr=$2 and id_kat=1',
                [$id, $r['id_lehr']]
            );
            pg_query_params(
                $this->context->getRwDbConn(),
                'update baydoc set id_lehr=$2 where id=$1',
                [$id, $this->context->getOrgId()]
            );
            $r['id_lehr'] = $this->context->getOrgId();
        }

        //Zuordnung zu Einheit
        pg_query_params(
            $this->context->getRwDbConn(),
            'select set_objekt_ls(d.id,d.id_lehr,$2,o.id_art,0)
        from objekt o, baydoc d where o.id=d.id and o.id=$1',
            [$id, $this->context->getOrgId()]
        );
        //Zuordnung zu Ober-Einheit
        pg_query_params(
            $this->context->getRwDbConn(),
            'select set_objekt_ls(d.id,g.id_parent,$2,o.id_art,0)
        from objekt o, baydoc d, gehoert_zu g
 where g.id_lehr=d.id_lehr and o.id=d.id and o.id=$1',
            [$id, $this->context->getOrgId()]
        );
        pg_execute(
            $this->context->getRwDbConn(),
            'zulassung',
            [$id, $this->context->getUserId(), $r['id_lehr'], 1]
        );

        // Send Mails...
        $bm = \BayDOC\Tabs\DocBetr::$bm;
        $bm_names_bilang = \BayDOC\Tabs\DocBetr::$bm_names_bilang;
        $translations = [];
        $translations['en']['Herr'] = 'Mr';
        $translations['en']['Frau'] = 'Ms';
        $ls_link = $this->context->org_folder;
        $r['student_anrede_de'] = $r['anrede'] ? 'Liebe' . ($r['anrede'] == 'Herr' ? 'r' : '') . ' ' . $r['anrede'] : 'Guten Tag';
        $r['student_anrede_en'] = $r['anrede'] ? 'Dear ' . $translations['en'][$r['anrede']] : 'Hello';
        $r['herr_frau_de'] = $r['anrede'];
        $r['herr_frau_en'] = $translations['en'][$r['anrede']];
        $r['pdf_link'] = "https://$_SERVER[HTTP_HOST]/$ls_link/de/intern/baydoc/antrag_pdf.php?id_obj=$id";
        $r['admin_link'] = "https://$_SERVER[HTTP_HOST]/$ls_link/de/admin/baydoc/?id_obj=$id";
        $r['intern_link'] = "https://$_SERVER[HTTP_HOST]/$ls_link/de/intern/baydoc/?id_obj=$id";

        $mail = new \BayDOC\Util\Mail($this->context);
        $mail->sendMail(
            $r['email'],
            $mail->getMailText('student_neuer_antrag_betreff'),
            $mail->getMailText('student_neuer_antrag'),
            $r,
            ids: [$id]
        );

        $max_mentor_email = ($this->context->get('row1', 'baydoc_profile') == -1 ? 1 : 4);
        for ($i = 0; $i < $max_mentor_email; $i++) {
            $r['email'] = $r[$bm[$i] . '_email'];
            if ($r['email'] && !$r[$bm[$i] . '_bestaetigt'] && $r[$bm[$i] . '_aktiv'] == 't') {
                $r['vname'] = $r[$bm[$i] . '_vname'];
                $r['nname'] = $r[$bm[$i] . '_nname'];
                $r['pw'] = substr($r[$bm[$i] . '_token'], 1, 8);
                $r['mentor_anrede_de'] = $r[$bm[$i] . '_anrede'] ? 'Sehr geehrte' . ($r[$bm[$i] . '_anrede'] == 'Herr' ? 'r' : '') . ' ' . $r[$bm[$i] . '_anrede'] . ($r[$bm[$i] . '_titel'] ? ' ' . $r[$bm[$i] . '_titel'] : '') : 'Guten Tag';
                $r['mentor_anrede_en'] = $r[$bm[$i] . '_anrede'] ? 'Dear ' . $translations['en'][$r[$bm[$i] . '_anrede']] . ($r[$bm[$i] . '_titel'] ? ' ' . $r[$bm[$i] . '_titel'] : '') : 'Dear';
                $r['was_de'] = $bm_names_bilang['de'][$i];
                $r['was_en'] = $bm_names_bilang['en'][$i];
                $r['blink_de'] = "https://$_SERVER[HTTP_HOST]/ubt/de/intern/baydoc/?betr=confirm&id_obj=$id&who=$bm[$i]&token=" . $r[$bm[$i] . '_token'];
                $r['blink_en'] = "https://$_SERVER[HTTP_HOST]/ubt/en/intern/baydoc/?betr=confirm&id_obj=$id&who=$bm[$i]&token=" . $r[$bm[$i] . '_token'];
                $mail->sendMail(
                    $r['email'],
                    $mail->getMailText('mentor_neuer_antrag_betreff'),
                    $mail->getMailText('mentor_neuer_antrag'),
                    $r,
                    ids: [$r[$bm[$i] . '_id']]
                );
            }
        }
        $mail->sendMail(
            $mail->getAdmins(),
            "Neuer Antrag von $r[name], $r[vorname]",
            $mail->getMailText('admin_neuer_antrag'),
            $r
        );

        //INO
        $res = pg_query(
            $this->context->getRwDbConn(),
            'select id from lehrstuhl where link=\'ino\''
        );
        if (pg_num_rows($res)) {
            list($id_ino) = pg_fetch_row($res, 0);
            $res = pg_query_params(
                $this->context->getRwDbConn(),
                "select d.id,not (n.name='Deutschland') as ino1,
    not (a.name='Deutschland') as ino2, /*master*/
    not (s.name='Deutschland') as ino3, /*schule*/
    not (e.name='Deutschland') as ino4 /*ersteinschreibung*/
from baydoc d left outer join stat_laender n on d.land=n.name
left outer join stat_laender a on d.hstatg_ab_hs_land=a.id
left outer join stat_laender s on d.hstatg_hzb_land=s.id
left outer join stat_laender e on d.hstatg_erst_hs_land=e.id
where d.id=\$1",
                [$id]
            );
            $r_ino = pg_fetch_array($res, 0);
            if ($r_ino['ino1'] == 't' || $r_ino['ino2'] == 't' || $r_ino['ino3'] == 't' || $r_ino['ino4'] == 't') {
                //Zuordnung zu INO falls Land nicht DE oder Abschluss nicht in EU
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'select set_objekt_ls(d.id,$2,$2,o.id_art,0)
        from objekt o, baydoc d where o.id=d.id and o.id=$1',
                    [$id, $id_ino]
                );
                pg_execute(
                    $this->context->getRwDbConn(),
                    'zulassung',
                    [$id, $this->context->getUserId(), $id_ino, 1]
                );
                $mail->sendMail(
                    $mail->getAdmins($id_ino),
                    "Neuer Antrag von $r[name], $r[vorname] [BayDoc1/2b]",
                    $mail->getMailText('admin_neuer_antrag', $id_ino),
                    $r
                );

            }
        }


        echo $this->getJSRedirect("?tab=stamm");
    }

    public function print()
    {
        if (!$this->doc->getRow()['b_id']) {
            $GLOBALS['TE']->printMessage($this->t(
                'To finish the entry please give the name of supervisor and mentors',
                'Um den Registrierung abzuschließen , müssen Sie Betreuer und Mentoren eingeben'
            ), 'danger');
            return;
        }

        if (!$this->doc->getAntrag()) {
            $GLOBALS['TE']->printMessage($this->t(
                'Registration Process is finished',
                'Registrierung ist bereits abgeschlossen'
            ), 'danger');
            return;
        }
        if (($_GET['aktion'] ?? false) && !$this->editAllowed())
            unset($_GET['aktion']);
        if ($_GET['aktion'] ?? '') {
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }
            if ($_GET['aktion'] == 'save') {
                //Registration Staff!
                $this->finish();

                return;
            }
        }

        $GLOBALS['TE']->printMessage($this->getComment());
        echo $this->getForm($this->t('Finish Registration', 'Registrierung abzuschließen'));



    }

    public function editAllowed(): bool
    {
        return $this->doc->getRole() == 'selbst' && $this->doc->getAntrag();
    }


    public function getComment(): string
    {
        return $this->t(
            '<b>Remarks:</b> Click below to submit the entry. 
After finishing the application your entry will get visible to the administration of the university.
			Please check carefully!',
            '<b>Hinweise:</b> Klicken Sie unten, um den Registrierung abzuschließen.
			Nach dem Abschließen wird Ihr Eintrag für die Universitätsverwaltung sichtbar. Prüfen Sie ihre Angaben sorgfältig!'
        );
    }
}