<?php

namespace BayDOC\Tabs;

use Exception;

class DocStamm extends DocForm
{

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $admin = $doc->getRole() == 'admin';


        $lang = $context->lang;
        $lang2 = $context->lang2;
        if ($doc->getAntrag() || $admin) {
            $this->addField(new \BayDOC\Field\OrgSelect(
                $context,
                name: 'id_lehr',
                description: $this->t('Unit', 'Einheit'),
                non_empty: 1,
                null: 1,
                role: $doc->getRole(),
                table: $doc->getTable(),
                input_options: ($doc->getRole() == 'admin' ? " onChange=\"document.form1.set_objekt_ls.checked=1;\"" : '')
            ))->set(['left_join' => 'l12']);
            $this->addField(new \BayCMS\Field\Hidden(
                $context,
                "status",
                "Status",
                sql:'non_empty(k.de,k.en)',
                no_add_to_query: 1
            ))->set(['left_join'=>'add_to_query']);
        }
        if ($admin) {
            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'set_objekt_ls',
                no_add_to_query: 1,
                description: 'Zuordnung und Antrag bei Einheitswechsel neu setzen'
            ));
            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'keep_objekt_ls',
                no_add_to_query: 1,
                description: 'Alte Zuordnung zusätzlich beibehalten'
            ));
        }

        $this->addField(new \BayDOC\Field\Anrede(
            $context,
            'anrede',
            $this->t('Salutation', 'Anrede'),
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'hstatg_geschlecht',
            $this->t('Gender', 'Geschlecht'),
            values: [
                ['2', $this->t('Female', 'Weiblich')],
                ['1', $this->t('Male', 'Männlich')],
                ['3', $this->t('Gender diverse', 'Divers')],
                ['4', $this->t('Not stated (according to birth register)', 'Ohne Angabe (gemäß Eintragung im Geburtenregister)')]
            ],
            null: 1,
            non_empty: 1
        ));
        if($doc->getTable()=='postdoc')
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'titel',
            $this->t('Academic Title', 'Titel (z.B. Dr.)')
        ));

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'name',
            $this->t('Surname', 'Nachname'),
            non_empty: 1
        ))->set(['list_field' => 1]);

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'vorname',
            $this->t('Firstname', 'Vorname'),
            non_empty: 1
        ))->set(['list_field' => 1]);

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'gname',
            $this->t('Name of Birth', 'Geburtsname'),
            non_empty: 0
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            'gdatum',
            $this->t('Date of Birth', 'Geburtdatum'),
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'gort',
            $this->t('City of Birth', 'Geburtsort'),
            non_empty: !$admin
        ));

        $this->addField(new \BayDOC\Field\LandSelect(
            $context,
            'land',
            $this->t('Nationality', 'Nationalität'),
            non_empty: !$admin
        ))->set(['left_join' => 'laender', 'left_join_name' => 'nat1']);
        $this->addField(new \BayDOC\Field\LandSelect(
            $context,
            'land2',
            $this->t('2nd Nationality', '2. Nationalität'),
            non_empty: 0
        ))->set(['left_join' => 'laender', 'left_join_name' => 'nat2']);
        
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'str',
            $this->t('Street + Nr.', 'Straße + Hausnummer'),
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'ort',
            $this->t('Cip-Code + Town', 'PLZ + Ort'),
            non_empty: !$admin
        ));
        $this->addField(new \BayDOC\Field\LandSelect(
            $context,
            'land_wohnort',
            $this->t('Country of current habitation (only if not Germany)', 'Land Wohnort (nur falls nicht Deutschland)'),
            non_empty: 0
        ));
        $this->addField(new \BayCMS\Field\Email(
            $context,
            'email',
            $this->t('E-Mail Address', 'E-Mail Adresse'),
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'tel',
            $this->t('Phone Number', 'Telefonnummer'),
            non_empty: !$admin
        ));
        $this->addField(new \BayCMS\Field\URL(
            $context,
            'homepage',
            $this->t('Homepage (incl. https://)', 'Homepage (mit https://)'),
            non_empty: 0
        ));
        if ($this->doc->getTable() == 'baydoc') {
            $this->addField(new \BayCMS\Field\Number(
                $context,
                'mnr',
                $this->t('Student ID Number (Matrikelnummer)', 'Matrikelnummer'),
                non_empty: 0
            ));
        } else {
            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'habilabsicht',
                $this->t('Habilitation intended but not officially started', 'Habilitation geplant aber noch nicht angemeldet')
            ));
            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'newsletter',
                $this->t('Newsletter (about four each year)', 'Newsletter (ca. vier pro Jahr)')
            ));
        }

        $this->addField(new \BayCMS\Field\UploadImage(
            $context,
            'bild',
            $this->t('Image', 'Bild')
        ));
        if ($admin) {
            $this->addField(new \BayCMS\Field\Comment(
                $context,
                'admin_felder',
                '<h3>Nur sichtbar für Admins</h3>'
            ));
            $this->addField(new \BayCMS\Field\SelectJS(
                $context,
                'id_benutzer',
                description: $this->t('User account', 'Zugeordnete Nutzerkennung'),
                target: '../../intern/gru/user_select.php',
                db_query: "select id,login||' ('||kommentar||')' as description from benutzer where id=\$1"
            ))->set(['left_join' => 'user', 'left_join_name' => 'user1']);
            $this->addField(new \BayCMS\Field\SelectJS(
                $context,
                'id_benutzer2',
                description: $this->t('2nd user account', 'alternative Nutzerkennung (z.B. s-Kennung)'),
                target: '../../intern/gru/user_select.php',
                db_query: "select id,login||' ('||kommentar||')' as description from benutzer where id=\$1"
            ))->set(['left_join' => 'user', 'left_join_name' => 'user2']);

            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'set_zugriff',
                'Rechte setzen',
                no_add_to_query: 1
            ));
            $this->addField(new \BayCMS\Field\Comment(
                $context,
                'user_comment',
                'Hinweis: Falls Sie eine andere Nutzerkennung(en) hinterlegen,
					müssen Sie eventuell auch die Rechte anpassen!'
            ));
            if ($this->doc->getTable() == 'baydoc') {
                $this->addField(new \BayCMS\Field\TextInput(
                    $context,
                    'viva_nr',
                    'VIVA Personalnummer'
                ));
                $this->addField(new \BayCMS\Field\Checkbox(
                    $context,
                    'admineintrag',
                    'Eintrag durch Admin angelegt'
                ));
            } else {
                $this->addField(new \BayCMS\Field\Checkbox(
                    $context,
                    'aktiv',
                    'Aktiv',
                    help: 'Deaktivierte Postdocs sehen nur die Tabs Stammdaten und Promotionsabschluss'
                ));
                $this->addField(new \BayCMS\Field\Checkbox(
                    $context,
                    'no_tg',
                    'Nicht Research Stay Grant antragsberechtigt',
                    help: 'Der Tab Research Stay Grants bleibt sichtbar. Der Postdoc bekommt aber nur einen Hinweis angezeigt.'
                ));
                $this->addField(new \BayCMS\Field\Textarea(
                    $this->context,
                    'no_tg_bemerkung',
                    'Admin-Bemerkung zu Nicht Research Stay Grant antragsberechtigt'
                ));

            }

        } else
            $this->addField(new \BayCMS\Field\Hidden(
                $context,
                'id_benutzer',
                default_value: $context->getUserId(),
                type: 'int'
            ));

    }

    public function editAllowed(): bool
    {
        return ($this->doc->getRole() == 'admin' || $this->doc->getRole() == 'selbst') &&
            (!$this->doc->locked() || $this->doc->getAntrag());
    }

    private function prefillForm(){
        if($this->doc->getTable()=='postdoc' && 
            pg_num_rows($res=pg_query($this->context->getDbConn(),
            "select b.*,'t' as newsletter,b.id as id_doc,baydoc_getstatus(b.id,".$this->context->getOrgId().",'de')
				from baydoc b, lehrstuhl l where b.id_lehr=l.id and (b.id_benutzer=".$this->context->getUserId()." 
				  or b.id_benutzer2=".$this->context->getUserId().") and not b.antrag"))){
				  $GLOBALS['TE']->printMessage("Daten von Doktorandeneintrag werden übernommen");
				  $r=pg_fetch_array($res,0);
				  $this->setValues($r);
				  $this->addField(new \BayCMS\Field\Hidden(
                    $this->context,
                    'id_doc',
                    default_value:$r['id'],
                    type: 'integer'));
                    return;				  
		} 
        $res=pg_query($this->context->getDbConn(),
        "select * from benutzer where id=".$this->context->getUserId());
		$r_benutzer=pg_fetch_array($res,0);
		$r=[];
		$r['email']=$r_benutzer['email'];
		[$r['vorname'],$r['name']]=explode(' ',$r_benutzer['kommentar']);
		$r['id_benutzer']=$r_benutzer['id'];
		$r['newsletter']='t';
		if($this->context->get('row1','postdoc_profile')>0) $r['id_lehr']=$this->context->getUserId();
        $this->setValues($r);	
		
    }

    public function print()
    {
        if ($this->doc->getId()) {
            $this->load($this->doc->getId());
            if (($_GET['aktion'] ?? '') == 'del')
                $this->del();
        } elseif (!isset($_GET['aktion']))
            $_GET['aktion'] = 'edit';
        if ($_GET['aktion'] ?? '') {
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }
            if ($_GET['aktion'] == 'save') {
                if ($_POST['land2'] != "null" && $_POST['land2'] == 'Deutschland') {
                    $GLOBALS['TE']->printMessage($this->t('Please put Germany as first nationality.', 'Bitte setzen Sie Deutschland immer als erste Nationalität'), 'danger');
                    $_GET['aktion'] = "edit";
                    $this->getField('land')->setError(true);
                    $this->getField('land2')->setError(true);
                }
            }
            if ($_GET['aktion'] == 'save') {

                $this->save();

                $GLOBALS['TE']->printMessage($this->t('Saved entry', "Eintrag gespeichert"));
                if ($this->doc->getAntrag() && ($tab=$this->getNextTab()))
                    echo $this->getJSRedirect("?tab=$tab&id=" . $this->doc->getId() . "&aktion=edit");

                unset($_GET['aktion']);
            } else {
                if(! $this->doc->getId()) $this->prefillForm();
                echo $this->getForm($this->t('Edit Entry', 'Eintrag bearbeiten'));

            }
        }
        if (!isset($_GET['aktion']) && $this->doc->getId()) {
            $d_format = ($this->de() ? 'DD.MM.YYYY' : 'YYYY-MM-DD');
            $res = pg_query_params(
                $this->context->getDbConn(),
                "select b.name as bild,s.*,
		to_char(s.gdatum,'$d_format') as fgdatum
		from " . $this->doc->getTable() . " s left outer join bild b on b.id_obj=s.id, lehrstuhl l
		where l.id=s.id_lehr and s.id=\$1",
                [$this->doc->getId()]
            );


            $r = pg_fetch_array($res, 0);
            if ($r['bild'])
                echo "<img src=\"../../image/$r[bild]\" align=\"right\">";
            echo "<table>
	<tr><td>" . $this->getField('anrede')->getDisplayValue() . "<br/><b>$r[vorname] $r[name]<b>" . ($r['gname'] ? " (geb. $r[gname])" : '') . "</td></tr>
	<tr><td>$r[fgdatum], $r[gort]</td></tr>
	<tr><td>$r[str]</td></tr>
	<tr><td>$r[ort]" . ($r['land_wohnort'] ? "($r[land_wohnort])" : '') . "<td></tr>
	<tr><td>" . $this->t('Nationality', 'Nationalität') . ": $r[land]" . ($r['land2'] ? "/$r[land2]" : '') . "</td></tr>
	<tr><td>$r[tel]</td></tr>
	<tr><td>$r[email]</td></tr>
	<tr><td>$r[homepage]</td></tr>";
            if ($this->doc->getTable() == 'baydoc')
                echo "
	<tr><td>" . $this->t('Student ID Number', 'Matrikelnummer') . ": $r[mnr]</td></tr>" .
                    ($this->doc->getRole() == 'admin' ? "<tr><td>VIVA Personalnummer: $r[viva_nr]</td></tr>" : '');
            echo "</table>";



            if ($this->editAllowed())
                echo $GLOBALS['TE']->getActionLink("?tab=stamm&aktion=edit&id=" . $this->doc->getId(), $this->t('edit', "bearbeiten"), '', 'edit');
            if ($this->context->getPower() >= 1000)
                echo " -- " . $GLOBALS['TE']->getActionLink("../gru/objekt_detail.php?id_obj=" . $this->doc->getId(), $this->t('Object Properties', "Objekt Eigenschaften"), '','properties');

            if ($this->context->getPower() >= 1000)
                echo " -- " . $GLOBALS['TE']->getActionLink(
                    "?tab=stamm&aktion=del&id=" . $this->doc->getId(),
                    $this->t('delete', "löschen"),
                    " onClick=\"return confirm('" . $this->t('Do you really want to delete the entry?', 'Wirklich löschen?') . "')\"",
                    'del'
                );
        }
    }


    public function del()
    {
        if (($_GET['aktion'] ?? false) != 'del')
            return;
        if ($this->context->getPower() < 1000)
            return;

        if ($this->context->getPower() <= 1000 && isset($_GET['force']))
            unset($_GET['force']);

        if (!isset($_GET['force'])) {
            $res = pg_query(
                $this->context->getDbConn(),
                "select b.kommentar,v.*,to_char(v.wann,'DD.MM.YYYY') from 
baydoc_verfahren v, benutzer b where b.id=v.id_benutzer and v.id_stud=$_GET[id] and v.id_benutzer!=" . $this->context->getUserId()
            );

            if (pg_num_rows($res)) {
                $GLOBALS['TE']->printMessage('Es gibt noch Verfahrenseinträge von anderen Nutzern!', 'danger');
                echo "<table " . $GLOBALS['TE']->getCSSClass('table') . ">";
                for ($i = 0; $i < pg_num_rows($res); $i++) {
                    $r = pg_fetch_array($res, $i);
                    echo "<tr><td>$r[to_char]</td><td>$r[kommentar]</td><td>$r[bemerkung]</td></tr>";
                }
                echo "</table>";
                if ($this->context->getPower() > 1000)
                    echo $GLOBALS['TE']->getActionLink(
                        "?id=$_GET[id]&force=1&aktion=del",
                        "Trotzdem vollständig löschen (nur Superuser)",
                        " onClick=\"return confirm('Sind Sie sicher?')\"",
                        'del'
                    ) . "<br/><br/>";
                unset($_GET['aktion']);
                return;
            }
        }
        if (
            pg_num_rows(pg_query(
                $this->context->getDbConn(),
                "select * from baydoc_geld where id_stud=$_GET[id]"
            ))
        ) {
            unset($_GET['aktion']);
            $GLOBALS['TE']->printMessage('Es gibt noch Geldeinträge! Löschen nicht möglich', 'danger');
            return;
        }

        $obj = new \BayCMS\Base\BayCMSObject($this->context);
        $obj->load($_GET['id']);
        pg_query($this->context->getRwDbConn(), "begin");
        pg_query($this->context->getRwDbConn(), "delete from baydoc_verfahren where id_stud=$_GET[id] and 
                (id_benutzer=" . $this->context->getUserId() . " or " . $this->context->getPower() . ">1000)");

        try {
            $obj->erase(true);
            pg_query($this->context->getRwDbConn(), "commit");
            $GLOBALS['TE']->printMessage("Eintrag gelöscht!");
            echo $GLOBALS['TE']->getActionLink('/' . $this->context->getOrgLinkLang() . ($this->doc->getTable() == 'baydoc' ? '/admin/baydoc/baydoc.php' : '/admin/postdoc/admin.php'), 'zurück zur Übersicht', '', 'arrow-left');
            $this->context->printFooter();

        } catch (Exception $e) {
            $GLOBALS['TE']->printMessage("Konnte Objekt nicht löschen: " . $e->getMessage(), 'danger');
        }
        unset($_GET['aktion']);




    }

    public function save()
    {

        if (
            ($_POST['set_objekt_ls'] ?? false) &&
            $this->doc->getRole() == 'admin'
        ) {
            [$id_lehr_old] = pg_fetch_row(
                pg_query_params(
                    $this->context->getDbConn(),
                    "select id_lehr from " . $this->doc->getTable() . " where id=\$1",
                    [$this->doc->getId()]
                )
            );
        }
        $id = parent::save();
        if (
            $this->doc->getRole() == 'admin' && ($_POST['set_objekt_ls'] ?? false) && !pg_num_rows(pg_query_params(
                $this->context->getDbConn(),
                'select id_obj from objekt_ls where id_lehr=$1 and id_obj=$2',
                [$_POST['id_lehr'], $id]
            ))
        ) {
            echo "<h4>Setze Zuordnung</h4>";
            if ($this->doc->getTable() == 'baydoc')
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'insert into  baydoc_zulassung(id_stud,datum,id_kat,bemerkung,id_benutzer,id_lehr)
					values($1,now()::date,1,$2,$3,$4)',
                    [
                        $id,
                        'Einheit Autozuordnung',
                        $this->context->getUserId(),
                        $_POST['id_lehr']
                    ]
                );
            pg_query_params(
                $this->context->getRwDbConn(),
                'select set_objekt_ls(d.id,d.id_lehr,$2,o.id_art,0)
					from objekt o, ' . $this->doc->getTable() . ' d where o.id=d.id and o.id=$1',
                [$id, $_POST['id_lehr']]
            );
            if ($id_lehr_old != $_POST['id_lehr'] && !($_POST['keep_objekt_ls'] ?? false)) {
                echo "<h4>Lösche alte Zuordnung</h4>";
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'delete from objekt_ls where id_obj=$1 and (id_lehr=$2 or id_lehr in
						(select id_parent from gehoert_zu where id_lehr=$2 
						except select id_parent from gehoert_zu where id_lehr=$3))',
                    [$id, $id_lehr_old, $_POST['id_lehr']]
                );
                if ($this->doc->getTable() == 'baydoc')

                    pg_query_params(
                        $this->context->getRwDbConn(),
                        'delete from baydoc_zulassung where id_stud=$1 and id_lehr=$2 and id_kat=1',
                        [$id, $id_lehr_old]
                    );
            } else {
                echo "<h4>Alte Zuordnung bitte manuell löschen.</h4>";
            }
        }
        if ($this->doc->getRole() == 'admin' && ($_POST['set_zugriff'] ?? false)) {
            pg_prepare(
                $this->context->getRwDbConn(),
                'set_zugriff',
                'insert into zugriff(id_benutzer,id_obj)
					select $1,$2 except select id_benutzer,id_obj from zugriff where id_benutzer=$1 and id_obj=$2'
            );
            if (is_numeric($_POST['id_benutzer']))
                pg_execute(
                    $this->context->getRwDbConn(),
                    'set_zugriff',
                    [$_POST['id_benutzer'], $id]
                );
            if (is_numeric($_POST['id_benutzer2']))
                pg_execute(
                    $this->context->getRwDbConn(),
                    'set_zugriff',
                    [$_POST['id_benutzer2'], $id]
                );
        }
        return $id;

    }
}