<?php

namespace BayDOC\Tabs;

class DocStatus extends Doc
{

    private \BayCMS\Fieldset\Domain $domain;
    private array $org_ids;
    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $res = pg_query(
            $context->getDbConn(),
            "select l.id
		from lehrstuhl l, lehrstuhl l2, gehoert_zu g, objekt o, objekt o2, in_ls i
		where g.id_parent=l2.id and g.id_lehr=l.id and l.id=o.id and o.geloescht is null
		and l2.id=o2.id and o2.geloescht is null and l2.id=g.id_parent and
		(i.id_benutzer=" . $context->getUserId() . " and (i.power>1000 or (i.power=1000 and i.id_lehr=l2.id) or
		(i.power=1000 and i.id_lehr=l.id)) or (i.power=1000 and i.id_lehr in 
	(select id from lehrstuhl where de = 'Universität Bayreuth'))) and
		(l.baydoc_profile>0 or l.id=5001)"
        );
        $this->org_ids = [];
        for ($i = 0; $i < pg_num_rows($res); $i++) {
            [$this->org_ids[]] = pg_fetch_row($res, $i);
        }

        $this->domain = new \BayCMS\Fieldset\Domain(
            $context,
            'baydoc_zulassung',
            from: 'baydoc_zulassung t, benutzer b, lehrstuhl l, baydoc_zulassungskat k',
            where: 't.id_stud=' . $doc->getId() . " and t.id_kat=k.id and t.id_lehr=l.id and t.id_benutzer=b.id
            and t.id_lehr in (".implode(',',$this->org_ids).')',
            qs: 'tab=status&id=' . $doc->getId(),
            write_access_query: $doc->locked()?'false':'true',
            id_name:'id_st',
            copy: false,
            headline: false
        );
        $this->domain->setListProperties(
            export_buttons: false,
            new_button: !$doc->locked(),
            actions:$doc->locked()?[]:['edit']
        );
        $this->domain->addField(new \BayCMS\Field\Date(
            $context,
            'Datum',
            non_empty: 1,
            default_value: date('Y-m-d')
        ))->set(['list_field' => 1]);
        $this->domain->addField(new \BayCMS\Field\Hidden(
            $context,
            'id_benutzer',
            'Benutzer',
            type: 'int',
            default_value: $context->getUserId(),
            sql: 'b.kommentar'
        ))->set(['list_field' => 1]);
        $this->domain->addField(new \BayDOC\Field\OrgSelect(
            $context,
            'id_lehr',
            'Einheit',
            role: 'admin',
            org_ids: $this->org_ids,
            null: 1,
            non_empty: 1,
            sql: 'l.de',
            input_options: " onChange=\"document.form1.set_objekt_ls.checked=1;\""
        ))->set(['list_field' => 1]);
        $this->domain->addField(new \BayCMS\Field\Checkbox(
            $context,
            'set_objekt_ls',
            'Objekt-Zuordnung sicherstellen',
            no_add_to_query: 1,
            help: 'Falls gesetzt wird zusätzlich um Statuseintrag noch die Objekt-Zuordnung entsprechend geändert.'
        ))->set(['edit_field' => 1]);

        $this->domain->addField(new \BayDOC\Field\KatSelect(
            $context,
            'id_kat',
            'Art',
            null: 1,
            non_empty: 1,
            sql: 'k.de'
        ))->set(['list_field' => 1]);

        $this->domain->addField(new \BayCMS\Field\Hidden(
            $context,
            'id_stud',
            type: 'int',
            default_value: $doc->getId()
        ));
        $this->domain->addField(new \BayCMS\Field\Textarea(
            $context,
            'Bemerkung'
        ));

    }

    private function checkOrgId()
    {
        if (!isset($_GET['aktion']))
            return true;
        if (isset($_GET['id_st'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                'select * from baydoc_zulassung where id=$1',
                [$_GET['id_st']]
            );
            $r = pg_fetch_array($res, 0);
            if (!in_array($r['id_lehr'], $this->org_ids)) {
                $GLOBALS['TE']->printMessage('Ungültige OrgId detektiert!', 'danger');
                unset($_GET['aktion']);
                return false;
            }
        }
        if ($_POST['id_lehr'] ?? false) {
            if (!in_array($_POST['id_lehr'], $this->org_ids)) {
                $GLOBALS['TE']->printMessage('Ungültige OrgId detektiert!', 'danger');
                unset($_GET['aktion']);
                return false;
            }
        }
        return true;
    }

    public function print()
    {
        if ($this->checkOrgId()) {
            $_POST['id_benutzer'] = $this->context->getUserId(); //overwrite old user id
            $edit = $this->domain->getEdit();
            if ($edit['error'])
                $GLOBALS['TE']->printMessage($edit['error'], 'danger');
            if ($edit['message'])
                $GLOBALS['TE']->printMessage($edit['message']);
            echo $edit['html'];
            if (($_POST['aktion'] ?? '') == 'save' && !$edit['error'] && ($_POST['set_objekt_ls'] ?? '') == 't') {
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'select set_objekt_ls(d.id,$2,$2,o.id_art,0)
					from objekt o, baydoc d where o.id=d.id and o.id=$1',
                    [
                        $this->doc->getId(),
                        $_POST['id_lehr']
                    ]
                );
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'select set_objekt_ls(d.id,g.id_parent,$2,o.id_art,0)
					from objekt o, baydoc d, gehoert_zu g where 
				g.id_lehr=$2 and o.id=d.id and o.id=$1',
                    [
                        $this->doc->getId(),
                        $_POST['id_lehr']
                    ]
                );
            }
        }

        echo $this->domain->getList()['html'];

    }

    public function editAllowed(): bool
    {
        return $this->doc->getRole() == 'admin' && !$this->doc->locked();
    }


}