<?php

namespace BayDOC\Tabs;

use BayDOC\Field\AdminOK;

class DocUni extends DocAdministration
{
    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $admin = $doc->getRole() == 'admin';
        $footnote = ['*', $this->t('mandatory', 'Pflichtfeld')];
        $edit_hstatg_ok = ($this->context->org_folder == 'ubt' || $this->context->org_folder == 'ino' || $this->context->getPower() > 1000);

        $this->admin_actions = ['HZB', 'Bachelor', 'Master', 'CV', 'Zusatzupload'];
        if ($edit_hstatg_ok)
            $this->admin_actions[] = "Für Einschreibung: Ausbildung geprüft + gesperrt";
        if ($this->context->org_folder == 'ubt')
            $this->admin_actions[] = "HStatG-Abgleich";

        $this->addField(new AdminOK(
            context: $context,
            name: 'admin_hzb_zeugnis',
            no_add_to_query: true,
            description: '<h3>' . $this->t(
                'University Entrance Certificate (UEC)',
                'Hochschulzugangsberechtigung (HZB) - Meist Abitur'
            ) . '</h3>'
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'hstatg_hzb_jahr',
            description: $this->t('Year of UEC', 'Jahr des ersten Erwerbs einer HZB'),
            min: 1930,
            max: date('Y'),
            placeholder: $this->t('YYYY', 'JJJJ'),
            footnote: $footnote
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_art',
            target: 'stat_hr.php',
            db_query: "select id, schule as description from stat_hr where id=\$1",
            help: $this->t(
                'For non German a common choice is &quot;Erwerb der HZB im Ausland: Allgemeine Hochschulreife&quot;',
                'Meist &quot;Gymnasium (aHR)&quot;<br/> Wenn Abitur außerhalb Deutschlands dann meist &quot;Erwerb der HZB im Ausland: Allgemeine Hochschulreife&quot;'
            ),
            description: $this->t('Type of UEC', 'Art der ersten HZB'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_hr', 'left_join_name' => 'hzb_art']);
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_kreis',
            target: 'stat_kreise.php',
            db_query: 'select id,bundesland||\'/\'||kreis as description from stat_kreise where id=$1',
            help: $this->t(
                'Look for the town of your school. Leave blank, if the school is not in Germany',
                'Suchen Sie die Stadt Ihrer Schule. Lassen Sie das Feld leer, falls Sie Ihre HZB nicht in Deutschland erworben haben'
            ),
            description: $this->t('Location of school: City (onlyif in Germany)', 'Landkreis bzw. kreisfreie Stadt der Schule'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_kreise', 'left_join_name' => 'hzb_kreis']);

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_hzb_land',
            target: 'stat_laender.php',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            description: $this->t('Country of the school', 'Land der Schule'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_laender', 'left_join_name' => 'hzb_land']);

        $this->addField(new \BayCMS\Field\UploadFile(
            context: $context,
            name: 'hzg_zeugnis',
            uname: 'abi',
            help: $this->t(
                'Please upload here one single PDF with your school leaving certificate(s) incl. translation (e.g. A-Level, Baccalaureat, High-School-Diploma).',
                'Bitte laden Sie hier ein einziges PDF mit dem letzten Schulzeugnis hoch (Hochschulzugangsberechtigung, z.B. Abitur, A-Level, Baccalaureat, High-School-Diploma)'
            ) . ' (max. 2 MB)',
            description: $this->t('school leaving certificate(s) incl. translation', 'letztes Schulzeugnis'),
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
        ))->set(['left_join' => 'file', 'left_join_name' => 'hzb_file']);

        if ($admin)
            $this->addField(new AdminOK(
                context: $context,
                name: 'admin_hzb_zeugnis',
                description: 'Prüfung HZB'
            ));

        /* Bachelor */

        $this->addField(new AdminOK(
            context: $context,
            name: 'admin_bachelor_zeugnis',
            no_add_to_query: true,
            description: '<h3>' . $this->t(
                'First matriculation as student - typically your bachelor study',
                'Ersteinschreibung als Studierende(r) - Meist Bachelorstudium'
            ) . '</h3>'
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_erst_hs',
            target: 'stat_hs.php',
            db_query: 'select id,name as description from stat_hs where id=$1',
            help: $this->t(
                'Look for your university. If the university is not in Germany add &quot;Hochschule im Ausland&quot; here',
                'Suchen Sie hier Ihre Universität. Wenn die Universität nicht in Deutschland ist, wählen Sie &quot;Hochschule im Ausland&quot;'
            ),
            description: $this->t('University of first matriculation', 'Hochschule der Ersteinschreibung')
        ))->set(['left_join' => 'stat_hs', 'left_join_name' => 'bachelor_hs']);

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_erst_hs_land',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            target: 'stat_laender.php',
            description: $this->t('Country of first matriculation', 'Land der Ersteinschreibung'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_laender', 'left_join_name' => 'bachelor_land']);

        $semester_schluessel = [
            ['1', $this->t('summer term', 'Sommersemester')],
            ['2', $this->t('winter term', 'Wintersemester')]
        ];

        $this->addField(new \BayCMS\Field\Select(
            context: $context,
            name: 'hstatg_erst_semester',
            values: $semester_schluessel,
            description: $this->t('Term', 'Semester'),
            null: true,
            help: $this->t(
                'Please choose between &quot;winter term (October til March)&quot; and &quot;summer term&quot; (April til September) according to the month your initial matriculation took place',
                'Bitte wählen Sie entsprechend dem Monat ihrer Ersteinschreibung Winter- oder Sommersemester aus'
            ),
            footnote: $footnote
        ));

        $this->addField(new \BayCMS\Field\NumSelect(
            $context,
            name: 'hstatg_erst_monat',
            max: 12,
            null: true,
            description: $this->t('Month of first matriculation', 'Monat der Ersteinschreibung')
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'hstatg_erst_jahr',
            description: $this->t('Year of first matriculation', 'Jahr der Ersteinschreibung'),
            min: 1930,
            max: date('Y'),
            placeholder: $this->t('YYYY', 'JJJJ'),
            footnote: $footnote
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            name: 'hstatg_end_bachelor',
            description: $this->t('Date of certificate (Bachelor)', 'Datum des Zeugnisses (Bachelor)')
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            context: $context,
            name: 'bachelor_zeugnis',
            uname: 'bachelor',
            help: $this->t(
                'Please upload here one single PDF with your bachelor’s degree (incl. certificate, academic transcript of records with grading scale and a translation of both the certificate and the transcript of records)',
                'Bitte laden Sie hier ein einziges PDF mit dem Bachelorabschluss hoch (Zeugnis inkl. Urkunde, Übersetzung und vollständige Transcripts mit Grading-Scale)'
            ) . ' (max. 2 MB)',
            description: $this->t('Documents bachelor degree incl. translation', 'Nachweise Bachelorstudium'),
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
        ))->set(['left_join' => 'file', 'left_join_name' => 'bachelor_file']);
        if ($admin)
            $this->addField(new AdminOK(
                context: $context,
                name: 'admin_bachelor_zeugnis',
                description: 'Prüfung Bachelor'
            ));


        /* Master */

        $this->addField(new AdminOK(
            context: $context,
            name: 'admin_master_zeugnis',
            no_add_to_query: true,
            description: '<h3>' . $this->t(
                'Qualifying degree for the doctorate - typically your master degree',
                'Zur Promotion berechtigende, vorangegangene bestandene Abschlussprüfung - Meist Masterabschluss'
            ) . '</h3>'
        ));
        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_hs',
            target: 'stat_hs.php',
            db_query: 'select id,name as description from stat_hs where id=$1',
            help: $this->t(
                'Look for your university. If the university is not in Germany add &quot;Hochschule im Ausland&quot; here',
                'Suchen Sie hier Ihre Universität. Wenn die Universität nicht in Deutschland ist, wählen Sie &quot;Hochschule im Ausland&quot;'
            ),
            description: $this->t('University of the degree', 'Hochschule des Abschlusses'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_hs', 'left_join_name' => 'master_hs']);

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_hs_land',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from stat_laender where id=\$1",
            target: 'stat_laender.php',
            description: $this->t('Country of the degree', 'Land der Abschlusses'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_laender', 'left_join_name' => 'master_land']);

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_art',
            db_query: "select id,pruef||' - '||zusatz as description from stat_art where id=\$1",
            target: 'stat_art.php',
            help: $this->t(
                'For a degree outside Germany type &quot;Ausland&quot; and choose between options',
                'Oft &quot;Master an Universitäten (Abschlussprüfung vorausgesetzt) - Masterstudium&quot;<br/>Wenn Studium außerhalb Deutschlands, wählen Sie bitte eine Abschlussprüfung, die mit &quot;Ausland&quot; beginnt'
            ),
            description: $this->t('Type of the degree', 'Art der Prüfung'),
            footnote: $footnote
        ))->set(['left_join' => 'stat_art', 'left_join_name' => 'master_art']);

        $this->addField(new \BayCMS\Field\SelectJS(
            context: $context,
            name: 'hstatg_ab_fach',
            db_query: "select id, non_empty(name,en,'" . $this->context->lang . "') as description from baydoc_stgfach where id=\$1",
            target: 'stgfaecher.php',
            description: $this->t('Subject of the degree', '1. Studienfach'),
            footnote: $footnote
        ))->set(['left_join' => 'baydoc_stgfach', 'left_join_name' => 'master_fach']);

        $this->addField(new \BayCMS\Field\NumSelect(
            $context,
            name: 'hstatg_start_master_monat',
            max: 12,
            null: true,
            description: $this->t('Month of Starting Master/State Examination', 'Monat Beginn Master/Examen')
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'hstatg_start_master_jahr',
            description: $this->t('Year of Starting Master/State Examination', 'Jahr Beginn Master/Examen'),
            min: 1930,
            placeholder: $this->t('YYYY', 'JJJJ'),
            max: date('Y')
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            name: 'hstatg_ab_datum',
            description: $this->t('Date of the certificate (Master/State Examination)', 'Datum des Zeugnisses (Master/Examen')
        ));
        $noten_schluessel = [
            ['n0', 'Mit Auszeichnung'],
            ['n1', 'Sehr gut'],
            ['n2', 'Gut'],
            ['n7', 'Vollbefriedigend (Nur Staatsprüf./Magister)'],
            ['n3', 'Befriedigend'],
            ['n4', 'Ausreichend'],
            ['n8', 'Bestanden, Note nicht bekannt']
        ];
        $this->addField(new \BayCMS\Field\Select(
            context: $context,
            name: 'hstatg_ab_note',
            values: $noten_schluessel,
            description: $this->t('Grade', 'Gesamtnote'),
            null: true,
            footnote: $footnote
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'master_degree_grade',
            description: $this->t('Grade of Master\'s degree (numeric)', 'Masternote (Zahl)')
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'master_degree_min',
            description: $this->t(
                'Minimum grade to pass in your educational system (Min; e.g. 4 in Germany)',
                'Mindestnote in Ihrem Studiensystem, um den Abschluss zu bestehen (z.B. 4 in Deutschland)'
            )
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'master_degree_max',
            description: $this->t(
                'Best possible grade achievable in your educational system (Max; e.g. 1 in Germany)',
                'Beste mögliche Note in Ihrem Studiensystem (z.B. 1 in Deutschland)'
            )
        ));
        $this->addField(new \BayCMS\Field\Number(
            context: $context,
            name: 'master_degree_grade_equiv',
            input_options: ' readonly',
            post_input: "
    <script>
    $(document).ready(function(){
        $('#form1_master_degree_min, #form1_master_degree_max, #form1_master_degree_grade').keyup(function(){
            form1_calculate_degree(this);
        });
    });
        
    function form1_calculate_degree( src ) {
            var max=parseFloat($('#form1_master_degree_max').val().replace(',','.'));
            var min=parseFloat($('#form1_master_degree_min').val().replace(',','.'));
            var ist=parseFloat($('#form1_master_degree_grade').val().replace(',','.'));
            $('#form1_master_degree_grade_equiv').val(1+3*(max-ist)/(max-min));
    }
    </script>
    ",
            description: $this->t('Your calculated equivalent degree in Germany', 'Äquivalentnote in Deutschland')
        ));

        $this->addField(new \BayCMS\Field\UploadFile(
            context: $context,
            name: 'master_zeugnis',
            uname: 'diplom_master',
            help: $this->t(
                'Please upload here one single PDF with your master’s degree (incl. certificate, academic transcript of records with grading scale and a translation of both the certificate and the transcript of records)',
                'Bitte laden Sie hier ein einziges PDF mit dem Masterabschluss hoch (Zeugnis inkl. Urkunde, Übersetzung und vollständige Transcripts mit Grading-Scale)'
            ) . ' (max. 2 MB)',
            description: $this->t('Documents Master/State Examination', 'Nachweise Masterstudium/Examen'),
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
        ))->set(['left_join' => 'file', 'left_join_name' => 'master_file']);

        if ($admin)
            $this->addField(new AdminOK(
                context: $context,
                name: 'admin_master_zeugnis',
                description: 'Prüfung Master'
            ));

        $this->addField(new \BayCMS\Field\UploadFile(
            context: $context,
            name: 'cv_pdf',
            uname: 'cv',
            help: $this->t(
                'Please upload here your curriculum vitae in tabular form (incl. information with months and years regarding school and higher education)',
                'Bitte laden Sie hier einen tabellarischen Lebenslauf hoch (inkl. Schulzeit und Monatsangaben zu allen Ausbildungsabschnitten)'
            ) . ' (max. 2 MB)',
            description: $this->t('CV', 'Lebenslauf'),
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
        ))->set(['left_join' => 'file', 'left_join_name' => 'cv_file']);

        if ($admin)
            $this->addField(new AdminOK(
                context: $context,
                name: 'admin_cv',
                description: 'Prüfung CV'
            ));
        $this->addField(new \BayCMS\Field\UploadFile(
            context: $context,
            name: 'add_pdf',
            uname: 'add_pdf',
            help: $this->t(
                'Here you can upload additional documents in one single PDF on request, e.g. country-specific additional documents',
                'Hier können Sie auf Anforderung weitere Dokumente in einem einzigen PDF hochladen z.B. länderspezifische Zusatzdokumente'
            ) . ' (max. 2 MB)',
            description: $this->t('Additional documents', 'Zusatzdokumente'),
            accept: 'application/pdf',
            preg_match: '/\\.pdf$/i',
            self_edit: 1800,
            max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
        ))->set(['left_join' => 'file', 'left_join_name' => 'add_file']);

        if ($admin)
            $this->addField(new AdminOK(
                context: $context,
                name: 'admin_add',
                description: 'Prüfung Zusatzupload'
            ));

        if ($admin) {
            $this->addField(new \BayCMS\Field\Comment(
                $context,
                'admin_fields',
                '<h3>Administratorenfelder</h3>'
            ));
            $this->addField(new \BayCMS\Field\Checkbox(
                $context,
                'hstatg_ok',
                'Bestätigung für Einschreibung: Formale Prüfung durch Incoming Degree (mit Ausland), sonst HStatG-Plausibilitätsprüfung durch UBTGS',
                input_options: ($edit_hstatg_ok ? '' : ' disabled readonly')
            ));
            if ($edit_hstatg_ok)
                $this->addField(new \BayCMS\Field\Checkbox(
                    $context,
                    'hstatg_abgleich',
                    'HStagG-Abgleich',
                    input_options: ($this->context->org_folder == 'ubt' ? '' : ' disabled readonly')
                ));

            $this->addField(new \BayCMS\Field\Select(
                $context,
                'action',
                'Bearbeiter-Aktion',
                values: $this->admin_actions,
                null: true,
                non_empty: true,
                no_add_to_query: true,
                not_in_table: true
            ));
            $this->addField(new \BayCMS\Field\Textarea(
                $context,
                'action_comment',
                'Bearbeiter Kommenentar',
                no_add_to_query: true,
                not_in_table: true
            ));

        }

    }





    public function editAllowed(): bool
    {
        return ($this->doc->getRole() == 'admin' || ($this->doc->getRole() == 'selbst' && !$this->doc->hstatgOk()))
            && !$this->doc->locked();
    }

    public function print()
    {

        //CV Upload
        if ($_GET['cv'] ?? false) {
            $form = new \BayCMS\Fieldset\Form(
                $this->context,
                table: 'baydoc',
                qs: "tab=uni&cv=save",
                id_name: 'id',
                delete_button: false,
                cancel_button: false
            );
            $form->setId($this->doc->getId());
            $form->addField(new \BayCMS\Field\Hidden(
                $this->context,
                'gname'
            ));
            $form->addField(new \BayCMS\Field\UploadFile(
                context: $this->context,
                name: 'cv_pdf_upload',
                uname: 'cv',
                help: $this->t(
                    'Please upload here your curriculum vitae in tabular form (incl. information with months and years regarding school and higher education)',
                    'Bitte laden Sie hier einen tabellarischen Lebenslauf hoch (inkl. Schulzeit und Monatsangaben zu allen Ausbildungsabschnitten)'
                ) . ' (max. 2 MB)',
                description: $this->t('CV', 'Lebenslauf'),
                accept: 'application/pdf',
                preg_match: '/\\.pdf$/i',
                self_edit: 1800,
                max_size: ($this->doc->getRole() == 'admin' ? 0 : 2) * 1024 * 1024
            ));
            if ($_GET['aktion'] ?? false) {
                $form->setValues($_POST);
                $form->save();
                unset($_GET['aktion']);
            } else {
                $form->load($this->doc->getId());
                echo $form->getForm($this->t('Upload CV', 'Lebenslauf hochladen'));
            }

        }

        $this->load($this->doc->getId());


        if (($_GET['aktion'] ?? false) && !$this->editAllowed())
            unset($_GET['aktion']);
        if ($_GET['aktion'] ?? '') {
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }
            if ($_GET['aktion'] == 'save') {
                $this->save();
                $GLOBALS['TE']->printMessage($this->t('Saved entry', "Eintrag gespeichert"));
                unset($_GET['aktion']);
                if ($this->doc->getAntrag())
                    echo $this->getJSRedirect("?tab=betr&id=" . $this->doc->getId() . "&aktion=edit");

            } else {
                if ($this->doc->getAntrag())
                    $GLOBALS['TE']->printMessage($this->getComment());
                echo $this->getForm($this->t('Edit Entry', 'Eintrag bearbeiten'));
            }
        }
        if (!isset($_GET['aktion'])) {
            $GLOBALS['TE']->printMessage($this->getComment());
            if (!$this->editAllowed() && $this->doc->getRole() == 'selbst')
                echo $GLOBALS['TE']->getActionLink("?tab=uni&cv=1", $this->t('Upload CV', 'Lebenslauf hochladen'), 'upload');
            echo $this->getTable(delete_link: false, edit_link: $this->editAllowed(), object_link: false, pos: 'top');
            if ($this->doc->getRole() == 'admin')
                echo $this->getAdminHistory();
        }

    }

    public function getComment(): string
    {
        return $this->t(
            'In this section, we need information about your previous education. Mandatory fields according to the Higher Education Statistics Act (HStatG) are marked with an *.<br/><br/> 

        An <i>upload</i> of documents is only necessary if <i>at least one educational period was absolved abroad</i>. In this case, please upload evidence of your entire educational history. <br/><br/> 
        
        Please note that the check of foreign degrees cannot start before all documents are complete. It depends on the check whether you can enrol as a doctoral student.',
            'In diesem Abschnitt benötigen wir Informationen zu vorherigen Ausbildungsabschnitten. Alle verpflichtenden Felder nach dem Hochschulstatistikgesetz (HStatG) sind mit einem * markiert. 
    <br/><br/> 
    Ein <i>Upload</i> der Dokumente ist nur notwendig, wenn <i>mind. ein Ausbildungsabschnitt im Ausland</i> erfolgt ist. Bitte laden Sie in diesem Fall Nachweise über alle Abschnitte hoch. <br/><br/> 
    
    Bitte beachten Sie, dass die Prüfung ausländischer Abschlüsse erst erfolgen kann, wenn alle Unterlagen vollständig vorliegen. Von der Prüfung hängt ab, ob Sie sich einschreiben können. '
        );
    }

}