<?php

namespace BayDOC\Tabs;

use BayCMS\Field\Checkbox;
use \BayCMS\Field\Date;
use \BayCMS\Field\Select;
use \BayCMS\Field\Datetime;
use \BayCMS\Field\Comment;
use \BayCMS\Field\SelectJS;
use \BayCMS\Field\Textarea;
use \BayCMS\Field\Number;
use BayCMS\Field\TextInput;

class DocVerfahren extends DocAdministration
{

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $this->skip_empty=true;
        $this->admin_actions=[
            'Prüfung Zulassungsvoraussetzungen',
            'Prüfung Betreuungsvereinbarung',
            'Eintrag Prüfung',
            'Eintrag Uniwechsel',
            'Eintrag Rücktritt',
            'Sonstiges'
        ];
        $this->addAdminFields();

        $this->addField(new Comment(
            $context,
            'pruefung_annahme',
            '<h3>Prüfung Annahme zur Promotion</h3>',
            div_id: 'Annahme'
        ));
        $this->addField(new Datetime(
            $context,
            'reg_time',
            'Datum/Uhrzeit der ersten Registrierung',
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ))->set(['left_join'=>'add_to_query']);
        $this->addField(new Date(
            $context,
            'antrags_datum',
            'Datum des Antrags (== Status Antrag)',
            input_options: ' readonly disabled',
            no_add_to_query: 1
        ));

        $this->addField(new SelectJS(
            $context,
            'hstatg_fach',
            description: 'Promotionsfach (==EF11)',
            target: 'stgfaecher.php',
            db_query: 'select id,name||\' (\'||signatur||\')\' as description 
        from baydoc_stgfach where id=$1'
        ))->set(['left_join'=>'baydoc_stgfach','left_join_name'=>'prom_fach']);



        $this->addField(new Select(
            $context,
            'zulassung_prom_art',
            'Art der Promotion',
            null: 1,
            values: DocHstatg::$prom_art
        ));
        $this->addField(new Date(
            $context,
            'zulassung',
            'Datum Zulassungsvoraussetzungen geprüft'
        ));
        $this->addField(new Textarea(
            $context,
            'zulassung_text',
            'Auflagen/Anmerkungen'
        ));
        $this->addField(new Date(
            $context,
            'zulassung_antrag',
            'Datum Antrag auf Annahme zur Promotion'
        ));
        $this->addField(new Date(
            $context,
            'pstart2',
            'Promotionsstart an vorheriger Universität',
            footnote:['**','relevant für EF13 - siehe Hilfetext'],
            help: 'Die Meldung von EF13 berücksichtigt: (1) Promotionsbeginn an vorheriger Universität,  (2) Datum Annahme zur Promotion, (3) Datum Zulassungsveraussetzungen geprüft.'
        ));
        $this->addField(new Date(
            $context,
            'zulassung_zulassung',
            'Datum Annahme zur Promotion',
            footnote:['**','relevant für EF13 - siehe Hilfetext'],
            help: 'Die Meldung von EF13 berücksichtigt: (1) Promotionsbeginn an vorheriger Universität,  (2) Datum Annahme zur Promotion, (3) Datum Zulassungsveraussetzungen geprüft.'
        ));
        $this->addField(new Textarea(
            $context,
            'zulassung_promordnung',
            'Promotionsordnung',
            help: 'Promotion nach Promotionsordnung vom ...'
        ));
        $this->addField(new Textarea(
            $context,
            'zulassung_ueberpruefung',
            'Bemerkung Überprüfungsergebnis',
            help: 'In dieses Feld werden die Ergebnisse von Überprüfungen zum Status der Promotion geschrieben.'
        ));


        $this->addField(new Comment(
            $context,
            'pruefung_betreuungsvereinbarung',
            '<h3>Prüfung Betreuungsvereinbarung</h3>',
            div_id: 'Betreuungsvereinbarung'
        ));
        $this->addField(new Date(
            $context,
            'proverein',
            'Datum der Betreuungsvereinbarung'
        ));
        $this->addField(new Textarea(
            $context,
            'proverein_text',
            'Auflagen/Anmerkungen'
        ));

        $this->addField(new Comment(
            $context,
            'pruefung_comment',
            '<h3>Prüfung</h3>',
            div_id: 'Prüfung'
        ));
        $this->addField(new Date(
            $context,
            'prue_antrag',
            'Datum „Antrag auf Zulassung zum Promotionsprüfungsverfahren“'
        ));


        $this->addField(new Select(
            $context,
            'hstatg_diss_art',
            'Art der Dissertation (EF18)',
            values: DocHstatg::$diss_art,
            null: 1
        ));
        $this->addField(new Date(
            $context,
            'prue_abgabe',
            'Abgabe Dissertation und vollständige Unterlagen im Dekanat',
            footnote:['***','sichtbar für Promovierende']
        ));
        $this->addField(new Textarea(
            $context,
            'prue_titel',
            'Titel der Arbeit'
        ));
        $this->addField(new Date(
            $context,
            'prue_prom_komm',
            'Datum der Promotionskommission',
            footnote: ['***', 'sichtbar für Promovierende']
        ));
        $this->addField(new Date(
            $context,
            'prue_zulassung',
            'Zulassung zum Promotionsprüfungsverfahren',
            footnote:['***','sichtbar für Promovierende']
        ));


        $this->addField(new Comment(
            $context,
            'gutachter1_comment',
            '<h4>Gutachter*in 1 (alle Felder sichtbar für Promovierende)</h4>',
            div_id: 'Gutachter'
        ));
        $this->addField(new SelectJS(
            $context,
            'prue_gut1_id',
            description: 'Name',
            target: '../../intern/baydoc/prof.php',
            db_query: "select id, titel||' '||vname||' '||nname as description from bayprof where id=\$1"
        ));
        $this->addField(new Date(
            $context,
            'prue_best_gut1',
            description: 'Bestellung und Versand der Druckexemplare'
        ));
        $this->addField(new Date(
            $context,
            'prue_ein_gut1',
            description: 'Eingang Gutachten'
        ));



        $this->addField(new Comment(
            $context,
            'gutachter2_comment',
            '<h4>Gutachter*in 2 (alle Felder sichtbar für Promovierende)</h4>'
        ));
        $this->addField(new SelectJS(
            $context,
            'prue_gut2_id',
            description: 'Name',
            target: '../../intern/baydoc/prof.php',
            db_query: "select id, titel||' '||vname||' '||nname as description from bayprof where id=\$1"
        ));
        $this->addField(new Date(
            $context,
            'prue_best_gut2',
            description: 'Bestellung und Versand der Druckexemplare'
        ));
        $this->addField(new Date(
            $context,
            'prue_ein_gut2',
            description: 'Eingang Gutachten'
        ));


        $this->addField(new Comment(
            $context,
            'gutachter_commentw',
            '<h4>Weitere*r Gutachter*in(alle Felder sichtbar für Promovierende)</h4>'
        ));
        $this->addField(new SelectJS(
            $context,
            'prue_gutw_id',
            description: 'Name',
            target: '../../intern/baydoc/prof.php',
            db_query: "select id, titel||' '||vname||' '||nname as description from bayprof where id=\$1"
        ));
        $this->addField(new Date(
            $context,
            'prue_best_gutw',
            description: 'Bestellung und Versand der Druckexemplare'
        ));
        $this->addField(new Date(
            $context,
            'prue_ein_gutw',
            description: 'Eingang Gutachten'
        ));

        $this->addField(new Comment(
            $context,
            'prom_pruefung_comment',
            '<h4>Promotionsprüfung</h4>',
            div_id: 'Promotionsprüfung'
        ));

        $this->addField(new Date(
            $context,
            'prue_aus_start',
            'Beginn der Auslagefrist',
            footnote: ['***', 'sichtbar für Promovierende']
        ));
        $this->addField(new Date(
            $context,
            'prue_aus_end',
            'Ende der Auslagefrist',
            footnote: ['***', 'sichtbar für Promovierende']
        ));
        $this->addField(new Date(
            $context,
            'prue_mit_koll',
            'Mitteilung des Kolloquium-Termins',
            footnote: ['***', 'sichtbar für Promovierende']
        ));
        $this->addField(new Date(
            $context,
            'prue_pruef',
            'voraussichtliches Datum der mündliche Prüfung'
        ));
        $this->addField(new Select(
            $context,
            'prue_note',
            'Gesamtnote',
            null: 1,
            values: [0, 1, 2, 3, 4]
        ));
        $this->addField(new Number(
            $context,
            'prue_note_decimal',
            'Gesamtbewertung (numerisch)',
            help: 'Optional: Hier können Sie die genaue Note mit Nachkommastelle eintragen',
            step: 0.01
        ));
        $this->addField(new Date(
            $context,
            'prue_nichtbestanden',
            'Promotion endgültig nicht bestanden am (EF14)',
            help: 'sofern hier etwas steht, muss die Person in der nächsten Meldung mit Art der Registrierung 5 (Promotion abgeschlossen = Bestanden und Endgültig nicht bestanden) gemeldet werden.'
        ));
        $this->addField(new Date(
            $context,
            'prue_urkunde',
            'Datum der mündlichen Prüfung (EF14)'
        ));
        $this->addField(new Date(
            $context,
            'prue_pflicht',
            'Datum Abgabe Pflichtexemplare'
        ));
        $this->addField(new Date(
            $context,
            'prue_urkunde2',
            'Datum der Urkunde (wenn nicht Datum der mündlichen Prüfung)'
        ));
        $this->addField(new Date(
            $context,
            'prue_urkunde_aus',
            'Datum der Aushändigung der Urkunde'
        ));
        $this->addField(new Date(
            $context,
            'prue_erhebung_frei',
            'Datum Erhebungsbogen freigegeben'
        ));
        $this->addField(new Date(
            $context,
            'prue_erhebung_bearb',
            'Datum Erhebungsbogen bearbeitet',
            input_options: ($context->getPower() <= 1000 ? ' readonly disabled' : '')
        ));
        $this->addField(new TextInput(
            $context,
            'prue_eref',
            'e-pub Nummer/eRef Link'
        ));

        $this->addField(new Comment(
            $context,
            'wechsel_comment',
            '<h3>Wechsel der Universität</h3>',
            div_id: 'Uniwechsel'
        ));
        $this->addField(new Date(
            $context,
            'uniwechsel',
            'Datum des Wechsels'
        ));
        $this->addField(new Textarea(
            $context,
            'uniwechsel_text',
            'Zieluniversität/Anmerkungen'
        ));

        $this->addField(new Comment(
            $context,
            'ruecktritt_comment',
            '<h3>Rücktritt von der Promotion</h3>',
            div_id: 'Rücktritt'
        ));
        $this->addField(new Date(
            $context,
            'abbruch',
            'Datum des Rücktritts'
        ));
        $this->addField(new Textarea(
            $context,
            'abbruch_text',
            'Anmerkungen'
        ));
        $this->addField(new Date(
            $context,
            'abbruch_best',
            'Datum „Bestätigung Rücktritt von der Promotion“'
        ));

        $this->addField(new Comment(
            $context,
            'sonstiges_comment',
            '<h3>Sonstiges</h3>',
            div_id: 'Sonstiges'

        ));

        $this->addField(new Select(
            $context,
            'gs_anmeldung',
            'Anmeldung bei Graduateschool nach Ablauf der Einjahresfrist erlauben',
            null: 1,
            values: [['f', 'Nein'], ['t', 'Ja']]
        ));





    }

    

    public function load(int $id)
    {
        parent::load($id);
        $res = pg_query_params(
            $this->context->getDbConn(),
            'select z.datum from 
baydoc_zulassung z, baydoc d where d.id_lehr=z.id_lehr and z.id_kat=1 and d.id=$1 and d.id=z.id_stud',
            [$id]
        );
        if (pg_num_rows($res)) {
            [$antrags_datum] = pg_fetch_row($res, 0);
            $this->getField('antrags_datum')->setValue($antrags_datum);
        }

    }




}