<?php

namespace BayDOC\Tabs;

use Exception;

class PostdocTg extends \BayCMS\Fieldset\Form
{
    protected \BayDOC\Entry\Postdoc $doc;

    protected array $grant_row = [];
    protected string $grant_text;
    public function __construct(\BayCMS\Base\BayCMSContext $context, \BayDOC\Entry\Postdoc $doc)
    {
        $this->doc = $doc;
        parent::__construct(
            $context,
            table: 'postdoc_tg',
            id_name: 'id_tg',
            qs: 'tab=tg&id=' . $this->doc->getId(),
            uname: 'postdoc_tg',
            id_parent: $this->doc->getId(),
            object_button: false
        );
        $this->loadGrants();

        $this->addField(new \BayCMS\Field\Hidden(
            $this->context,
            'id_tg_deadline',
            default_value: $this->grant_row['id'],
            type: 'integer'
        ));

        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'kurztitel',
            $this->t('Research stay title', 'Kurztitel'),
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'ziel',
            $this->t('Destination (City/Country)', 'Reiseziel (Ort/Land)'),
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Date(
            $this->context,
            'von',
            $this->t('Start date', 'Start der Reise'),
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Date(
            $this->context,
            'bis',
            $this->t('End date', 'Ende der Reise'),
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Number(
            $this->context,
            'betrag',
            $this->t('Amount (will be filled - max: ' . $this->grant_row['max_antrag'] . ')', 'Beantragter Betrag (siehe Kostenschätzung - max: ' . $this->grant_row['max_antrag'] . ')'),
            non_empty: 1,
            input_options: ' readonly',
            post_input: "
    <script>
    $(document).ready(function(){           
        $( \"input[name*='kostenschaetzungc1']\" ).change(function(){
            var betrag =  parseFloat(\$( '#form1_kostenschaetzung_sum' ).text());
            if(betrag > " . $this->grant_row['max_antrag'] . ") betrag=" . $this->grant_row['max_antrag'] . ";
            $( '#form1_betrag' ).val(betrag);
            
        });
    });
    </script>"
        ));

        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'beschreibung',
            $this->t('Summary/Description (1200 characters)', 'Zusammenfassung/Beschreibung des Vorhabens (1200 Zeichen)'),
            max_length: 1800,
            non_empty: 1
        ));

        $this->addField(new \BayCMS\Field\Comment(
            $this->context,
            'moti',
            '<h4>Motivation</h4>'
        ));
        $qual_ziel['de'] = ['Habilitation', 'Nachwuchsgruppen Leitung', 'Junior Professur', 'Postdoc'];
        $qual_ziel['en'] = ['Habilitation', 'Junior group leader', 'Junior Professor', 'Postdoc'];
        $values = [];
        for ($i = 0; $i < count($qual_ziel['de']); $i++) {
            $values[] = [$qual_ziel['de'][$i], $qual_ziel[$this->context->lang][$i]];
        }
        $this->addField(new \BayCMS\Field\Select(
            $this->context,
            'qualiziel',
            $this->t('Qualification Objective', 'Qualifikationsziel'),
            null: 1,
            non_empty: 1,
            values: $values
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'motivation',
            $this->t('Expectations regarding networking (max. 1200 characters)', 'Erwartungen hins. Vernetzung (max. 1200 Zeichen)'),
            max_length: 1500,
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'annahmebestaetigung',
            $this->t('Expected benefit for own research (max. 1200 characters)', 'Erwarteter Nutzen für eigene Forschung (max. 1200 Zeichen)'),
            max_length: 1500
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $this->context,
            'annahmebestaetigung_file',
            $this->t('Invitation – if available (pdf)', 'Einladung – falls schon vorhanden (pdf)'),
            preg_match: '/\.pdf$/',
            accept: 'application/pdf'
        ));
        $this->addField(new \BayCMS\Field\UploadFile(
            $this->context,
            'sonstiges_file',
            $this->t('Other information (pdf)', 'Sonstige Angaben (pdf)'),
            preg_match: '/\.pdf$/',
            accept: 'application/pdf'
        ));
        $this->addField(new \BayCMS\Field\Textarea(
            $this->context,
            'sonstiges',
            $this->t('Description of other information (100 characters)', 'Beschreibung zu Sonstige Angaben (100 Zeichen)'),
            max_length: 150
        ));

        $this->addField(new \BayCMS\Field\Comment(
            $this->context,
            'kosten',
            '<h4>' . $this->t('Costs', 'Kosten') . '</h4>'
        ));
        $this->addField(new \BayCMS\Field\HtmlTable(
            $this->context,
            'kostenschaetzung',
            $this->de() ? ['Kategorie', 'Kosten in €'] : [
                'Category',
                'Costs in €'
            ],
            $this->t('cost calculation', 'Kostenschätzung'),
            col_input_options: [' size=30', ' size=6'],
            sum_col: 1,
            non_empty: 1,
            read_only_rows: 2,
            min_rows: 5,
            default_value: '<table><tr><th>Category</th><th>Costs in €</th></tr>
    <tr><td>Travel cost</td><td>0</td></tr>
    <tr><td>Accomodation cost</td><td>0</td></tr>
                    <tr><td colspan=1><i>Summe</i></td><td>0</td></tr></table>'
        ));
        $geld_geber['de'] = array('Keine', 'DAAD', 'DFG', 'Stipendiengeber', 'UBT Chancengleichheit');
        $geld_geber['en'] = array('None', 'DAAD', 'DFG', 'Scholarship donor', 'UBT Gender equality');
        $values = [];
        for ($i = 0; $i < count($geld_geber['de']); $i++) {
            $values[] = [$geld_geber['de'][$i], $geld_geber[$this->context->lang][$i]];
        }
        $this->addField(new \BayCMS\Field\SelectCheckbox(
            $this->context,
            'geldgeber',
            $this->t('Funding', 'Geldgeber'),
            values: $values,
            non_empty: 1,
            free_input: $this->t('Other fundings', 'Andere Geldgeber')
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $this->context,
            'keine_mittel',
            $this->t('I do NOT have my own universitarian budget for travelling', 'Ich verfüge nicht über eigene	Haushaltsmittel für Reisezwecke')
        ));


        $this->addField(new \BayCMS\Field\Comment(
            $this->context,
            'super',
            '<h4>' . $this->t('The supervisor agrees to the research stay', 'Zustimmung der Lehr-/Forschungseinheit') . '</h4>'
        ));
        $this->addField(new \BayCMS\Field\Checkbox(
            $this->context,
            'abgesprochen',
            $this->t('The supervisor agrees to the research stay', 'Die Teilnahme an dem VORHABEN ist mit der/dem Vorgesetzten abgesprochen, die Zustimmung liegt vor')
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'abgesprochen_name',
            $this->t('Supervisor name', 'Name des/der Vorgesetzten')
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'abgesprochen_einheit',
            $this->t('Department/Chair', 'Einheit des/der Vorgesetzten')
        ));


        if ($this->doc->getRole() == 'admin') {
            $this->addField(new \BayCMS\Field\Comment(
                $this->context,
                'admin',
                '<h4>Admin-Felder</h4>'
            ));
            $this->addField(new \BayCMS\Field\Select(
                $this->context,
                'Status',
                non_empty: 1,
                values: ['Antrag', 'Bewilligt', 'Nicht bewilligt', 'Nicht antragsberechtigt']
            ));

            $this->addField(new \BayCMS\Field\Textarea(
                $this->context,
                'status_bemerkung',
                'Status Bemerkung'
            ));
            $this->addField(new \BayCMS\Field\Select(
                $this->context,
                'Annahme',
                values: [
                    'Ja',
                    'Nein (Vorhaben nicht mehr relevant)',
                    'Nein (Andere Finanzierung)'
                ],
                non_empty: 1
            ));
            $this->addField(new \BayCMS\Field\UploadFile(
                $this->context,
                'bericht',
                'Abschlussbericht (pdf)',
                preg_match: '/\.pdf$/',
                accept: 'application/pdf'
            ));
        }
    }

    protected function loadGrants()
    {
        $this->grant_text = '';

        //Abfrage nach aktiven Grants
        $res = pg_query($this->context->getDbConn(), "select non_empty(" . $this->context->getLangLang2('tg.') . "),
                to_char(tg.von,'DD.MM.YYYY HH24:MI') as fvon,
                to_char(tg.bis,'DD.MM.YYYY HH24:MI') as fbis,
                tg.* from 
                postdoc_tg_deadline tg, objekt" . $this->context->getOrgId() . " o where tg.id=o.id and
                tg.von<=now() and tg.bis>=now()");
        if (!pg_num_rows($res) && $this->doc->getRole() != 'admin') {
            $this->grant_text .= '<h3>' . $this->t(
                'Currently no active call for travel grant applications',
                'Aktuell keine Anträge möglich'
            ) . '<h3>';
            $res = pg_query($this->context->getDbConn(), "select non_empty(" . $this->context->getLangLang2('tg.') . "),
                    to_char(tg.von,'DD.MM.YYYY HH24:MI') as fvon,
                    to_char(tg.bis,'DD.MM.YYYY HH24:MI') as fbis,
                    tg.* from
                    postdoc_tg_deadline tg, objekt" . $this->context->getOrgId() . " o where tg.id=o.id and
                    tg.von>now() order by tg.von limit 1");
            if (pg_num_rows($res)) {
                $r = pg_fetch_array($res, 0);
                $this->grant_text .= '<h4>' . $this->t('Next call', 'Nächste Ausschreibung') . ": $r[fvon] - $r[fbis]</h4>";
            }
            //Keine Ausschreibung und Rolle nicht Admin -> Keine Bearbeitung!
            if (isset($_GET['aktion']))
                unset($_GET['aktion']);
        }
        //Abfrage der Aussschreibung für Admins (damit JS im Formular funktioniert)
        if (!pg_num_rows($res) && $this->doc->getRole() == "admin" && isset($_GET['id_tg'])) {
            $res = pg_query_params(
                $this->context->getDbConn(),
                "select non_empty(" . $this->context->getLangLang2('tg.') . "),
                    to_char(tg.von,'DD.MM.YYYY HH24:MI') as fvon,
                    to_char(tg.bis,'DD.MM.YYYY HH24:MI') as fbis,
                    tg.* from
                    postdoc_tg g, postdoc_tg_deadline tg, objekt" . $this->context->getOrgId() . " o where tg.id=o.id and 
                    tg.id=g.id_tg_deadline and g.id=\$1
                     order by tg.von limit 1",
                [$_GET['id_tg']]
            );

        }


        if (pg_num_rows($res)) {
            $this->grant_row = pg_fetch_array($res, 0);
            $this->grant_text .= "<h3>" . $this->grant_row['non_empty'] . "</h3>
            <p>" . $this->grant_row['fvon'] . " - " . $this->grant_row['fbis'] . "</p>";
        } else
            $this->grant_row = ['max_antrag' => 0, 'id' => 0];

    }

    public function print()
    {
        if ($this->doc->getRow()['no_tg'] == 't' && $this->doc->getRole() == 'admin') {
            $GLOBALS['TE']->printMessage('Hinweis: Research Stay Grant Tab ist für diesen Postdoc deaktiviert!', 'danger');
        }

        if (!$this->doc->getRow()['prom_abschluss_datum'] && $this->doc->getRole() != 'admin') {
            $GLOBALS['TE']->printMessage($this->t(
                'Before applying for travel grants you have to complete your profile concerning your <a href="?tab=prom&id=' . $this->doc->getId() . '">PhD</a> ',
                'Für die Antragsstellung müssen Sie zunächst Ihre Angaben zur 
                    <a href="?tab=prom&id=' . $this->doc->getId() . '">Promotion</a> vervollständigen'
            ), 'danger');
            return;
        }

        echo $this->grant_text;

        if ($this->doc->getRow()['no_tg'] == 't' && $this->doc->getRole() == 'selbst') {
            $GLOBALS['TE']->printMessage('Sie sind für die aktuelle Ausschreibung als „nicht antragsberechtigt“ eingetragen.', 'danger');
            echo '
        Antragsberechtigt sind:
        <ul>
        <li>Postdocs mit Promotion in den letzten 6 Jahren auf Qualifikationsstellen oder mit Stipendium</li>
        <li>Habilitierende</li>
        <li>LeiterInnen von Nachwuchsgruppen</li>
        </ul>
        Nicht antragsberechtigt sind Sie auch, wenn Sie in den letzten 2 Jahren bereits eine Bewilligung aus dieser Fördermaßnahme erhielten.';
            return;
        }


        if (($_GET['aktion'] ?? '') == 'del') {

            $obj = new \BayCMS\Base\BayCMSObject($this->context);
            try {
                $obj->load($_GET['id_tg']);
                $obj->erase(true);
                $GLOBALS['TE']->printMessage($this->t('Entry deleted', 'Eintrag gelöscht'));

            } catch (Exception $e) {
                $GLOBALS['TE']->printMessage('Fehler beim Löschen: ' . $e->getMessage(), 'danger');
            }
            unset($_GET['aktion']);
        }
        if (isset($_GET['aktion'])) {



            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error) {
                    $_GET['aktion'] = 'edit';
                }
            }
            if ($_GET['aktion'] == 'save') {
                $this->setId($_GET['id_tg'] ?? null);
                $this->save();
                echo $this->getTable(object_link: false);

            } else {
                if ($_GET['id_tg'] ?? false) {
                    $this->load($_GET['id_tg']);
                }
                echo $this->getForm($this->t('Application for research stay grant', "Antrag auf Research Stay Grant"));
                return;
            }
        }

        // Abfrage auf vorliegenden Antrag:
        if (count($this->grant_row)) {
            $res = pg_query($this->context->getDbConn(), "select tg.*,o.* from postdoc_tg tg, objekt o 
                    where tg.id=o.id and tg.id_tg_deadline=" . $this->grant_row['id'] . " and o.id_obj=" . $this->doc->getId());
            if (!pg_num_rows($res)) {
                echo $GLOBALS['TE']->getActionLink("?tab=tg&aktion=edit&id=" . $this->doc->getId(), $this->t('New application for a research stay grant', 'Neuer Antrag'), '', "new") . "<br/>";
            }
        }

        $list = new \BayCMS\Fieldset\BayCMSList(
            $this->context,
            "postdoc_tg tg, objekt o, postdoc_tg_deadline tgd",
            "tg.id=o.id and o.id_obj=" . $this->doc->getId() . " and tg.id_tg_deadline=tgd.id",
            id_query: 'tg.id',
            prefix: 'tg.',
            id_name: 'id_tg',
            actions: ['edit', 'del'],
            qs: 'tab=tg&id=' . $this->doc->getId(),
            write_access_query: "(check_objekt(o.id," . $this->context->getUserId() . ") and " . ($this->doc->getRole() == 'admin' ? "true" : " tgd.von<=now() and tgd.bis>=now()") . ')'
        );

        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'ausschreibung',
            $this->t('Call', 'Ausschreibung'),
            sql: 'non_empty(' . $this->context->getLangLang2('tgd.') . ')'
        ));
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'kurztitel',
            $this->t('Application', 'Antrag')
        ));
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'betrag',
            $this->t('Amount', 'Betrag')
        ));
        $list->addField(new \BayCMS\Field\TextInput(
            $this->context,
            'status',
            $this->t('Status')
        ));
        echo $list->getTable();
    }
}
