<?php

namespace BayDOC\Tabs;

class PostdocUni extends DocForm
{
    protected string $tab = 'uni';

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        parent::__construct($context, $doc);
        $non_empty = $doc->getRole() != 'admin';
        $abschluss = ' '.$this->t(
            $this->tab == 'uni' ? 'of the university degree' : 'of the PhD degree',
            $this->tab == 'uni' ? 'des Abschlusses' : 'der Promotion'
        );
        $this->addField(new \BayDOC\Field\LandSelect(
            $context,
            $this->tab . '_land',
            $this->t('Country', 'Land').$abschluss,
            non_empty: $non_empty
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            $this->tab . '_ort',
            $this->t('City', 'Stadt').$abschluss,
            non_empty: $non_empty
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            $this->tab . '_name',
            $this->t('Name of the institution', 'Name der Einrichtung'),
            non_empty: $non_empty
        ));
        $uni_art_value = ['Universität', 'Fachhochschule', 'Sonst'];
        $uni_art_desc = ($context->lang == 'de' ? ['Universität', 'Fachhochschule', 'Sonst'] : ['University', 'Fachhochschule', 'Something else']);
        $values = [];
        for ($i = 0; $i < count($uni_art_value); $i++) {
            $values[] = [$uni_art_value[$i], $uni_art_desc[$i]];
        }
        $this->addField(new \BayCMS\Field\Select(
            $context,
            $this->tab . '_typ',
            $this->t('Type of the institution', 'Art der Einrichtung'),
            null: 1,
            non_empty: $non_empty,
            values: $values
        ));
        if ($this->tab == 'uni') {
            $uni_abschluss_value = ['Bachelor', 'Diplom', 'Master', 'Magister', 'Staatsexamen', 'Sonstiger Abschluss'];
            $uni_abschluss_desc = ($context->lang == 'de' ?
                ['Bachelor', 'Diplom', 'Master', 'Magister', 'Staatsexamen', 'Sonstiger Abschluss'] :
                ['Bachelor', 'Diploma', 'Master', 'Magister', 'Staatsexamen', 'other degree']);
            $values = [];
            for ($i = 0; $i < count($uni_abschluss_value); $i++) {
                $values[] = [$uni_abschluss_value[$i], $uni_abschluss_desc[$i]];
            }
            $this->addField(new \BayCMS\Field\Select(
                $context,
                $this->tab . '_abschluss',
                $this->t('Type of the degree', 'Art des Abschlusses'),
                null: 1,
                non_empty: $non_empty,
                values: $values
            ));
        }

        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            $this->tab . '_abschluss_name',
            $this->t('Name', 'Name').$abschluss,
            non_empty: $non_empty
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            $this->tab . '_abschluss_datum',
            $this->t('Date', 'Datum').$abschluss,
            non_empty: $non_empty
        ));
    }
}