<?php

namespace BayDOC\Tabs;

use BayDOC\Util\Mail;

class TabEvent extends Tab
{

    private array $eventlock = [];
    private static string $event_email = 'event.graduateschool@uni-bayreuth.de';

    private static string $mail_text_de = 'Liebe Teilnehmerinnen und Teilnehmer,
 
Sie haben sich verbindlich für den Workshop „$e.titel“ angemeldet.
 
Der Workshop beginnt am $e.datum_de um vorrausichtlich $e.von Uhr. Bitte beachten Sie, dass gegebenenfalls nachträgliche Änderungen per E-Mail mitgeteilt werden.
 
Auf unserer Webseite finden Sie die Kursbeschreibung noch einmal zu Ihrer Information:
$e.url
 
Unentschuldigtes Fehlen ist für den/die TrainerIn, die TeilnehmerInnen, und besonders für Personen, die keinen Platz erhalten konnten, frustrierend. Sollten Sie daher verhindert sein, melden Sie sich bitte selbstständig bis 7 Tage vor Beginn des Workshops ab (Promovierende über https://baydoc.uni-bayreuth.de/gs/de/top/gru/login.php und PostDocs+ über https://baydoc.uni-bayreuth.de/ubt/de/intern/postdoc/). Danach ist eine Abmeldung nur noch per E-Mail an event.graduateschool@uni-bayreuth.de in begründeten Fällen möglich.
 
Sollten Sie am Tag des Workshops dennoch unentschuldigt fehlen, so führt dies zu einer sechsmonatigen Sperre. Eine Entschuldigung kann nur in begründeten Ausnahmefällen nachträglich erfolgen.
 
Mit freundlichen Grüßen,
das Team der Servicestelle WiN und der UBT Graduate School
';

    private static string $mail_text_en = 'Dear participants,
 
You have bindingly registered for the workshop "$e.titel".
 
The workshop will start on $e.datum_en at presumably $e.von o‘clock. Please note that any subsequent changes will be communicated by E-Mail.
 
On our website you will find the course description for your information:
$e.url
 
Unexcused absences are frustrating for the instructor, the participants, and especially for people on the waiting list. Therefore, if you are unable to attend, please cancel on your own up to 7 days before the workshop starts (Doctoral candidates via https://baydoc.uni-bayreuth.de/gs/en/top/gru/login.php and PostDocs+ via https://baydoc.uni-bayreuth.de/ubt/de/intern/postdoc/). After that, cancellation is only possible by E-Mail to event.graduateschool@uni-bayreuth.de in justified cases.
 
If you are absent without excuse, you will be blocked from registering for any other workshops for the next six months. Only in exceptional justified cases, an excuse given after the Workshop will be accepted.
 
Yours sincerely,
Junior Scholar Office (WiN-UBT) - WiN Academy and University of 
Bayreuth Graduate School
';
    private static string $mail_text_wait_de = 'Guten Tag,
 
Sie haben sich für die Warteliste zum Workshop  „$e.titel“ angemeldet. Bitte beachten Sie, dass Sie per E-Mail benachrichtigt werden, falls/sobald ein Platz frei wird.
 
Mit freundlichen Grüßen,
das Team der Servicestelle WiN und der UBT Graduate School';
    private static string $mail_text_wait_en = 'Dear all,
 
You are on the waiting list for the workshop "$e.titel". Please note that you will be notified by e-mail if/as soon as a spot becomes available.
 
Yours sincerely,
Junior Scholar Office (WiN-UBT) - WiN Academy and University of 
Bayreuth Graduate School
';

    private static string $mail_text_moved = 'Guten Tag, 
Sie sind nachgerückt für Kurs „$e.titel“. Der Workshop beginnt am $e.datum_de um vorrausichtlich $e.von Uhr. Auf unserer Webseite finden Sie die Kursbeschreibung noch einmal zu Ihrer Information:
$e.url

Bitte teilen Sie uns unter event.graduateschool@uni-bayreuth.de mit, ob Sie den Platz wahrnehmen.

Hello, 
you have moved up from the waiting list and have a spot for course "$e.titel". The workshop will start on $e.datum_en at presumably $e.von o‘clock. On our website you will find the course description for your information:
$e.url

Please send us an e-mail to event.graduateschool@uni-bayreuth.de if you will participate.

Mit freundlichen Grüßen / Kind regards WiN / University of Bayreuth 
Graduate School';

    public function __construct(\BayCMS\Base\BayCMSContext $context, \BayDOC\Entry\Doc $doc)
    {
        parent::__construct($context, $doc);
        $this->readEventLock();
    }

    public static function help(\BayCMS\Base\BayCMSContext $context)
    {
        $out = '<h2>Automatische E-Mails</h2><p>
    Im Source-Code sind automatische E-Mails konfiguriert. Absender ist 
    event.graduateschool@uni-bayreuth.de. Es werden automatische E-Mails bei der Anmeldung zu einer Veranstaltung und beim Nachrücken aus der Warteliste verschickt.
    </p>
    <h2>Datenbank</h2><p>
    Veranstaltungsanmedlungen werden über die Tabelle "verweis" in der Datenbank abgelegt. Dadurch ist möglich
    dass sich sowohl Postdocs als auch Promovierende anmelden. Eine reguläre Anmeldung erhält die Ordnung 100. 
    Wartelistenanmeldungen Ordnung>100. Die Wartelistenposition ergibt sich aus Ordnung-100;<br/>
    Falls die Veranstaltung kostenpflichtig ist, wird zusätzlich noch ein Eintrag in der Tabelle "baydoc_geld" vorgenommen.
    <br/>
    In der Tabelle baydoc_eventlock können Postdocs/Promovierende zeitweise von der Anmeldung für 
    Veranstaltungen ausgeschlossen werden.<br/>
    Selbstabmeldung ist bis zum in "abmeldung_bis" in Tabelle "baydoc_events" festgelegten Zeitpunkt erlaubt.<br/>
    
    </p>
    <h3>Datenbankfunktionen</h3>';

        $funktionen = array(
            'baydoc_checkevent' => 'Prüft eine Veranstaltung für einen Teilnehmer. Rückgabewerte:<br/>
      2+: Warteliste (Platz = Wert -1)<br/>
  1: angemeldet<br/>
  0: Anmeldung möglich<br/>
  -1: Nicht aktiv<br/>
  -2: Ausgebucht<br/>
  -3: Guthaben nicht ausreichend ',
            'baydoc_eventcount' => 'Liefert die Anzahl der regulär angemeldeten Teilnehmer',
            'baydoc_eventwait' => 'Liefert die Anzahl der Teilnehmer auf der Warteliste'
        );
        foreach ($funktionen as $f => $des) {
            $out .= "<h4>$f</h4><p>$des</p><pre>";
            list($def) = pg_fetch_row(pg_query_params(
                $context->getDbConn(),
                'select pg_get_functiondef(oid) from pg_proc where proname = $1',
                [$f]
            ));
            $out .= htmlspecialchars($def) . "</pre>";
        }
        return $out;
    }

    private function readEventLock()
    {
        $res = pg_query_params(
            $this->context->getRwDbConn(),
            'select to_char(bis,\'' . $this->t('yyyy-mm-dd', 'dd.mm.yyyy') . '\') as fbis,
            bis, bis>now()::date as locked from
baydoc_eventlock where id_obj=$1 and id_lehr=$2',
            [$this->entry->getId(), $this->context->getOrgId()]
        );
        if (pg_num_rows($res)) {
            $this->eventlock = pg_fetch_array($res, 0);
        } else {
            $this->eventlock = ['locked' => 'f', 'bis' => ''];
        }
    }

    public function editAllowed(): bool
    {
        if ($this->entry->getRole() == 'admin')
            return true;
        if ($this->eventlock['locked'] == 't')
            return false;
        return !$this->entry->locked();
    }

    private function save()
    {
        if (!$this->editAllowed())
            return;
        $mailer = new Mail($this->context);

        pg_prepare(
            $this->context->getDbConn(),
            "event",
            "select non_empty(" . $this->context->getLangLang2('') . ") as titel,to_char(datum,'DD.MM.YYYY') as datum_de, 
        to_char(datum,'YYYY-MM-DD') as datum_en, to_char(von,'HH24:MI') as von,
        non_empty(url,'https://www.win-ubt.uni-bayreuth.de/de/termine/index.html') as url
        from baydoc_events where id=\$1"
        );
        if (isset($_GET['aktion']) && (is_array($_POST['id_event'] ?? '') || is_array($_POST['id_event_wait'] ?? ''))) {
            pg_query($this->context->getRwDbConn(), 'begin');
            pg_prepare(
                $this->context->getRwDbConn(),
                'insert_verweis',
                'insert into verweis(id_von,id_auf,ordnung)
                    select $1,$2,100 where baydoc_checkevent($1,$2)=0 or $3=\'admin\''
            );
            pg_prepare(
                $this->context->getRwDbConn(),
                'insert_verweis_wait',
                'insert into verweis(id_von,id_auf,ordnung)
                    select $1,$2,101+baydoc_eventwait(id) from baydoc_events where waitlist and id=$2 and 
                    (baydoc_checkevent($1,$2)=-2 or $3=\'admin\')'
            );
            pg_prepare(
                $this->context->getRwDbConn(),
                'insert_geld',
                'insert into baydoc_geld(id_stud,datum,was,kat,betrag,id_benutzer,id_gkat,id_event)
                    select $1,now()::date,non_empty(e.de,e.en)||\' \'||to_char(e.datum,\'DD.MM.YYYY\'),0,e.min_geld,$3,e.id_gkat,e.id
                    from baydoc_events e, verweis v
                    where e.id=$2 and v.id_auf=e.id and v.id_von=$1 and v.ordnung=100 and e.min_geld>0
                    '
            );
            if (is_array($_POST['id_event'] ?? '')) {
                for ($i = 0; $i < count($_POST['id_event']); $i++) {
                    $res = pg_execute(
                        $this->context->getRwDbConn(),
                        'insert_verweis',
                        [$this->entry->getId(), $_POST['id_event'][$i], $this->entry->getRole()]
                    );
                    if (pg_affected_rows($res))
                        pg_execute(
                            $this->context->getRwDbConn(),
                            'insert_geld',
                            [$this->entry->getId(), $_POST['id_event'][$i], $this->context->getUserId()]
                        );
                    if ($this->entry->getRole() == 'selbst' && pg_affected_rows($res)) {
                        $r_e = pg_fetch_row(pg_execute($this->context->getDbConn(), 'event', [$_POST['id_event'][$i]]));
                        $message = str_replace(
                            ['$e.titel', '$e.datum_de', '$e.datum_en', '$e.von', '$e.url'],
                            $r_e,
                            $this->de() ? self::$mail_text_de : self::$mail_text_en
                        );
                        $subject = "Workshop „$r_e[0]“";
                        $mailer->sendMail(
                            $this->entry->getRow()['email'],
                            $subject,
                            $message,
                            [],
                            self::$event_email,
                            $this->entry->getId()
                        );

                    }
                }
            }
            if (is_array($_POST['id_event_wait'] ?? '')) {
                for ($i = 0; $i < count($_POST['id_event_wait']); $i++) {
                    $res = pg_execute(
                        $this->context->getRwDbConn(),
                        'insert_verweis_wait',
                        [$this->entry->getId(), $_POST['id_event_wait'][$i], $this->entry->getRole()]
                    );
                    if ($this->entry->getRole() == 'selbst' && pg_affected_rows($res)) {
                        $r_e = pg_fetch_row(pg_execute($this->context->getDbConn(), 'event', [$_POST['id_event'][$i]]));
                        $message = str_replace(
                            ['$e.titel', '$e.datum_de', '$e.datum_en', '$e.von', '$e.url'],
                            $r_e,
                            $this->de() ? self::$mail_text_wait_de : self::$mail_text_wait_en
                        );
                        $subject = ($this->de() ? "Warteliste für Workshop" : "Waiting List for Workshop") . "„$r_e[0]“";
                        $mailer->sendMail(
                            $this->entry->getRow()['email'],
                            $subject,
                            $message,
                            [],
                            self::$event_email,
                            $this->entry->getId()
                        );

                    }

                }
            }
            pg_query($this->context->getRwDbConn(), 'commit');
        }

        if (isset($_GET['aktion']) && isset($_POST['id_event_del'])) {
            pg_query($this->context->getRwDbConn(), 'begin');
            pg_prepare(
                $this->context->getRwDbConn(),
                'delete',
                'select baydoc_deleteevent($1,$2)'
            );
            if ($this->entry->getRole() != 'admin')
                pg_prepare(
                    $this->context->getRwDbConn(),
                    'check_delete',
                    'select id from baydoc_events where id=$1 and abmeldung_bis>=now()'
                );
            for ($i = 0; $i < count($_POST['id_event_del']); $i++) {
                if ($this->entry->getRole() != 'admin') {
                    $res = pg_execute($this->context->getRwDbConn(), 'check_delete', [$_POST['id_event_del'][$i]]);
                    if (!pg_num_rows($res)) {
                        $GLOBALS['TE']->printMessage("Anmeldung kann nur durch Admin gelöscht werden.", 'warning');
                        continue;
                    }
                }
                $res = pg_execute($this->context->getRwDbConn(), 'delete', [$this->entry->getId(), $_POST['id_event_del'][$i]]);
                list($id) = pg_fetch_row($res, 0);
                if ($id) {
                    pg_query_params($this->context->getRwDbConn(), 'insert into baydoc_geld(id_stud,datum,was,kat,betrag,id_benutzer,id_gkat,id_event)
                    select $1,now()::date,non_empty(e.de,e.en)||\' \'||to_char(e.datum,\'DD.MM.YYYY\'),0,e.min_geld,$3,e.id_gkat,e.id
                    from baydoc_events e, verweis v
                    where e.id=$2 and v.id_auf=e.id and v.id_von=$1 and v.ordnung=100 and e.min_geld>0
                    ', [$id, $_POST['id_event_del'][$i], $this->context->getUserId()]);
                    $r_e = pg_fetch_row(pg_execute($this->context->getDbConn(), 'event', [$_POST['id_event_del'][$i]]));
                    $message = str_replace(
                        ['$e.titel', '$e.datum_de', '$e.datum_en', '$e.von', '$e.url'],
                        $r_e,
                        self::$mail_text_moved
                    );
                    $subject = "UBTGS Workshop: Platz frei geworden / Spot Available „$r_e[0]“";
                    [$name, $art, $email] = pg_fetch_row(pg_query(
                        $this->context->getDbConn(),
                        "select o.de,ao.uname,case when ao.uname='postdoc' then p.email else d.email end as email
                    from art_objekt ao, objekt o left outer join baydoc d on d.id=o.id 
                    left outer join postdoc p on p.id=o.id 
                   where o.id=$id and o.id_art=ao.id"
                    ), 0);

                    $mailer->sendMail(
                        $email,
                        $subject,
                        $message,
                        [],
                        self::$event_email,
                        $this->entry->getId()
                    );
                    if ($this->entry->getRole() == 'admin')
                        $GLOBALS['TE']->printMessage(
                            "Achtung!!",
                            'warning',
                            'Durch das Löschen ist <a href="../' . ($art == 'postdoc' ? 'postdoc' : 'baydoc') . '/?id=' . $id . '&tab=event">' . $name . '</a> 
                         von der Warteliste auf die Teilnehmerliste gerutscht.'
                        );
                }
            }
            pg_query($this->context->getRwDbConn(), 'commit');
            if ($this->entry->getRole() == 'admin')
                $GLOBALS['TE']->printMessage(
                    "Anmeldung gelöscht.",
                    'warning',
                    'Bitte beachten Sie, dass Sie die eine <a href="?id=' . $this->entry->getId() . '&tab=geld">Buchung</a> 
             gegenenfalls manuell löschen müssen.'
                );
        }


    }
    private function setEventlock()
    {
        if (($_GET['aktion'] ?? '') != 'lock')
            return;
        if ($this->entry->getRole() != 'admin')
            return;
        pg_query($this->context->getRwDbConn(), 'begin');
        pg_query_params(
            $this->context->getRwDbConn(),
            'delete from baydoc_eventlock where id_obj=$1 and id_lehr=$2',
            [$this->entry->getId(), $this->context->getOrgId()]
        );


        if (($_POST['locked'] ?? ''))
            pg_query_params(
                $this->context->getRwDbConn(),
                'insert into baydoc_eventlock(id_obj,id_lehr,bis) values ($1,$2,$3)',
                [$this->entry->getId(), $this->context->getOrgId(), $_POST['locked']]
            );
        pg_query($this->context->getRwDbConn(), 'commit');
        $GLOBALS['TE']->printMessage("Sperre gespeichert");
        $this->readEventLock();
        unset($_GET['aktion']);
    }

    public function print()
    {
        $this->setEventlock();
        $this->save();

        if ($this->eventlock['locked'] == 't')
            $GLOBALS['TE']->printMessage($this->t("You have been locked until " . $this->eventlock['fbis'], "Sie wurden bis zum " . $this->eventlock['fbis'] . " von der Veranstaltungsbuchung gesperrt"), 'danger');

        //Veranstaltungen mit Anmeldung
//Filter siehe SQL
        $res = pg_query($this->context->getRwDbConn(), "select e.id,non_empty(" . $this->context->getLangLang2('e.') . "),
to_char(e.datum,'DD.MM.YYYY') as fdatum,
		to_char(e.datum_bis,'DD.MM.YYYY') as fdatum_bis,e.url,e.max_anzahl,e.waitlist,
        e.abmeldung_bis>=now() as abmeldung,
		non_empty(" . $this->context->getLangLang2('e.text_') . ") as beschreibung,
to_char(e.anmeldung_bis,'DD.MM.YYYY HH24:MI') as fanmeldung_bis,
to_char(e.abmeldung_bis,'DD.MM.YYYY HH24:MI') as fabmeldung_bis,

baydoc_checkevent(" . $this->entry->getId() . ",e.id),
		baydoc_eventcount(e.id), baydoc_eventwait(e.id)
		from baydoc_events e, objekt" . $this->context->getOrgId() . " o
		where e.id=o.id 
        and (e.anmeldung_von<=now() or e.anzeigen_vor_anmeldung or e.anmeldung_von is null 
        or '" . $this->entry->getRole() . "'='admin')
        and e.anmeldung_bis is not null and " . (strstr($_SERVER['PHP_SELF'], '/postdoc/') ? 'e.postdoc' : 'e.baydoc') . " 
		and (e.datum>=now()::date or (e.datum>=now()-interval  '2 months' and '" . $this->entry->getRole() . "'='admin')) 
		 order by e.datum");
        $event_status = ($this->de() ?
            [-3 => 'Guthaben nicht ausreichend', -2 => 'Ausgebucht', -1 => 'Anmeldezeitraum nicht aktiv', 0 => 'Anmeldung möglich', 1 => '<b>Angemeldet</b>'] :
            [-3 => 'Credit not sufficient', -2 => 'Fully booked', -1 => 'Registration period not active', 0 => 'Booking possible', 1 => '<b>Booked</b>']);


        $GLOBALS['TE']->printMessage($this->t('In this section, you can register for workshops and events. In case of unexcused absence at the day of the workshop, you will be blocked from registering for any other workshops for the next six months. You will see the lock date in this section.
After the workshop is fully processed (up to four weeks), you can download the certificate of participation at the bottom of this page.',
            'Hier können Sie sich für Veranstaltungen anmelden. Sollten Sie am Tag des Workshops unentschuldigt fehlen, so führt dies zu einer sechsmonatigen Sperre der Workshop-Anmeldung.
Nach vollständiger Abwicklung der Veranstaltung (bis zu vier Wochen), können Sie hier Ihr Teilnahmezertifikat im unteren Teil dieser Seite herunterladen.'
        ));

        if ($this->editAllowed())
            echo "<form action=\"index.php?tab=event&aktion=save&id=" . $this->entry->getId() . "\" method=\"post\">";
        echo '<table ' . $GLOBALS['TE']->getCSSClass('table') . '>
<tr><th>' . $this->t('Title', 'Titel') . '</th><th>' . $this->t('Date', 'Termin') . '</th>
<th>' . $this->t('Places/<br/>Booked/<br/>on waitlist', 'Plätze/<br/>Gebucht/<br/>Warteliste') . '</th>
<th>' . $this->t('Registration<br/>open until', 'Anmeldung<br/>möglich bis') . '</th>
<th>' . $this->t('Free cancelation<br/>open until', 'Abmeldung<br/>möglich bis') . '</th>
<th></th>' . ($this->entry->getRole() == 'admin' ? '<th>Admin</th>' : '') . '</tr>';
        $count = 0;
        $ids = 0;
        for ($i = 0; $i < pg_num_rows($res); $i++) {
            $r = pg_fetch_array($res, $i);
            if ($r['beschreibung'])
                $r['url'] = "../../intern/baydoc/event.php?id=$r[id]";
            echo "<tr><td>$r[non_empty]" . ($r['url'] ? ' <a href="' . $r['url'] . '">' . $this->t('more', 'mehr') . '</a>' : '') . "</td>
	<td>$r[fdatum]" . ($r['fdatum_bis'] ? " - $r[fdatum_bis]" : '') . "</td>
	<td>" . ($r['max_anzahl'] ? $r['max_anzahl'] : '&infin;') . "/$r[baydoc_eventcount]/$r[baydoc_eventwait]</td>
	<td><b>$r[fanmeldung_bis]</b></td><td><b>" .
                ($r['fabmeldung_bis'] ? $r['fabmeldung_bis'] : $this->t('not allowed', 'nicht erlaubt')) . "</b></td><td>";
            if ($r['baydoc_checkevent'] == 0 && $this->editAllowed()) {
                echo "<input type=\"checkbox\" name=\"id_event[]\" value=\"$r[id]\"> " . $this->t('book', 'anmelden');
                $count++;
            } else if ($r['baydoc_checkevent'] == -2 && $this->editAllowed() && $r['waitlist'] == 't') {
                echo "
		<input type=\"checkbox\" name=\"id_event_wait[]\" value=\"$r[id]\"> " . $this->t('on wait list', 'auf Warteliste');

                $count++;
            } else {
                if (isset($event_status[$r['baydoc_checkevent']]))
                    echo $event_status[$r['baydoc_checkevent']];
                else
                    echo '<b>' . $this->t('on wait list position', 'auf Warteliste Platz') . ' ' . ($r['baydoc_checkevent'] - 1) . '</b>';
                if ($r['abmeldung'] == 't' && $this->entry->getRole() != 'admin') {
                    echo "</td><td><input type=\"checkbox\" name=\"id_event_del[]\" value=\"$r[id]\"> abmelden";
                    $count++;
                }
            }
            if ($this->entry->getRole() == 'admin')
                echo '</td><td>';
            if ($this->entry->getRole() == 'admin') {
                if ($r['baydoc_checkevent'] >= 1) {
                    echo "<input type=\"checkbox\" name=\"id_event_del[]\" value=\"$r[id]\"> löschen";
                    $count++;
                } elseif ($r['baydoc_checkevent'] < 0) {
                    echo "<input type=\"checkbox\" name=\"id_event[]\" value=\"$r[id]\"> anmelden";
                    $count++;
                    if ($r['waitlist'] == 't')
                        echo "<input type=\"checkbox\" name=\"id_event_wait[]\" value=\"$r[id]\"> auf Warteliste";

                }
            }
            $ids .= ",$r[id]";
            echo '</td></tr>' . "\n";
        }

        //alte Anmeldugen
        $res = pg_query(
            $this->context->getDbConn(),
            "select e.id,non_empty(" . $this->context->getLangLang2('e.') . "),
to_char(e.datum,'DD.MM.YYYY') as fdatum,
        g.ctime,f.name
		from baydoc_events e
left outer join baydoc_geld g on g.id_event=e.id and g.id_stud=" . $this->entry->getId() . " and g.kat=1, 
objekt o , verweis v
left outer join objekt of on v.id_auf=of.id_obj 
left outer join file f on f.id=of.id and f.de='zert_" . ($this->context->modul == 'postdoc' ? 'p' : 'd') . "'
 
		where v.id_von=" . $this->entry->getId() . " and v.id_auf=e.id and v.ordnung=100 and e.id=o.id and e.datum<now()::date 
		and e.id not in ($ids) order by e.datum desc"
        );
        if (pg_num_rows($res)) {
            echo '<tr><th colspan="6">' . $this->t('Events attended', "Teilgenommen an") . ($this->entry->getRole() == 'admin' ? '</th><th>' : '') . '</th></tr>';
            for ($i = 0; $i < pg_num_rows($res); $i++) {
                $r = pg_fetch_array($res, $i);
                echo "<tr><td>$r[non_empty]</td><td>$r[fdatum]</td><td colspan=3>" .
                    ($r['name'] ? $GLOBALS['TE']->getActionLink(
                        "../../intern/baydoc/event_pdf.php?id=" . $this->entry->getId() . "&id_event=$r[id]",
                        $this->t('download certificate', 'Zertifikat herunterladen'),
                        ''
                    ) : '')
                    . "</td>" . ($this->entry->getRole() == 'admin' ? '<td></td>' : '') . "</tr>";
            }
        }
        echo '</table>';
        if ($this->editAllowed() && $count)
            echo '<input type="submit" value="' . $this->t('submit', 'abschicken') . '">';
        if ($this->editAllowed())
            echo '</form>';



        if ($this->context->getOrgId() != 5001 && $this->context->modul == 'baydoc')
            echo '<p>' .
                $this->t('Only for members of the UBT Graduate School: <br/>For events of the UBT Graduate School
 please switch to the <a href="/gs/en/intern/baydoc/?tab=event">member portal</a>',
                    'Nur für Mitglieder der UBT Graduate School:<br/>Für Veranstaltungen der UBT Graduate School 
wechseln Sie bitte in das  <a href="/gs/en/intern/baydoc/?tab=event">Mitgliederportal</a>'
                ) . '</p>';

        if ($this->entry->getRole() == 'admin') {
            $form = new \BayCMS\Fieldset\Form(
                $this->context,
                table: 'baydoc_event_lock',
                action: "?aktion=lock",
                qs: "tab=event&id=" . $this->entry->getId()
            );
            $form->addField(new \BayCMS\Field\Date(
                $this->context,
                'locked',
                'Gesperrt bis',
                default_value: $this->eventlock['bis']
            ));

            echo '<br/><br/><hr/>';
            echo $form->getForm("Person sperren (nur Admin)");

        }


    }


}