<?php

namespace BayDOC\Tabs;

class TabGeld extends DocForm
{
    private array $gkat_access;

    public function __construct(
        \BayCMS\Base\BayCMSContext $context,
        \BayDOC\Entry\Doc $doc
    ) {
        $this->context=$context;
        $this->doc=$doc;
        $res = pg_query(
            $context->getDbConn(),
            "select a.id_gkat from baydoc_gkat_access a, in_ls il 
where il.id_lehr=a.id_lehr and il.id_benutzer=" . $context->getUserId() . " and il.power>=1000"
        );
        $this->gkat_access = [];
        for ($i = 0; $i < pg_num_rows($res); $i++) {
            [$this->gkat_access[$i]] = pg_fetch_row($res, $i);
        }
        \BayCMS\Fieldset\Form::__construct(
            $context,
            table: 'baydoc_geld',
            id_name:'id_g',
            qs: 'tab=geld&id=' . $doc->getId()
        );
        $this->addField(new \BayCMS\Field\Hidden(
            $context,
            'id_stud',
            default_value: $doc->getId()
        ));
        $this->addField(new \BayCMS\Field\Date(
            $context,
            'datum',
            'Von',
            default_value: date('Y-m-d'),
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'kat',
            'Art',
            values: [[-1, 'Gutschrift'], [0, 'Festlegung'], [1, 'Ausgabe']],
            null: 1,
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Select(
            $context,
            'id_gkat',
            'Kategorie',
            db_query: 'select id, de as description from baydoc_gkat 
        where id in (' . implode(',', $this->gkat_access) . ') order by 2',
            null: 1,
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\TextInput(
            $context,
            'was',
            'Beschreibung',
            non_empty: 1
        ));
        $this->addField(new \BayCMS\Field\Number(
            $context,
            'Betrag',
            non_empty: 1,
            step: 0.01
        ));
        $this->addField(new \BayCMS\Field\Hidden(
            $context,
            'id_benutzer',
            default_value: $context->getUserId()
        ));
    }

    public static function help(\BayCMS\Base\BayCMSContext $context) {
        $out='<h3>Schreib-Zugriff</h3>
        <p>Schreibzugriff haben nur Admins, die in der Tabelle baydoc_gkat_access für mindestens eine Kategorie freigeschaltet sind.</p>';
        return $out;
    }

    public function editAllowed(): bool
    {
        return count($this->gkat_access) && !$this->doc->locked() && $this->doc->getRole() == 'admin';
    }

    public function getComment(): string
    {
        return $this->t(
            'In this section, you see an overview of your current UBTGS credit. Please note that workshops are listed after they have been fully processed (up to four weeks).',
            'Hier sehen Sie eine Übersicht Ihres Guthabens. Bitte beachten Sie, dass Workshops erst nach der vollständigen Abwicklung (bis zu vier Wochen) aufgeführt werden.'
        );

    }


    public function print()
    {
        if(! $this->editAllowed() && isset($_GET['aktion']))
            unset($_GET['aktion']);
        
        if (($_GET['aktion'] ?? false) && $_GET['aktion'] == 'del') {
            pg_query_params(
                $this->context->getRwDbConn(),
                'delete from baydoc_geld where id=$1 and check_objekt(id_stud,$2)',
                [$_GET['id_g'], $this->context->getUserId()]
            );
            $GLOBALS['TE']->printMessage('Eintrag gelöscht');
            unset($_GET['aktion']);
        }

        if ($_GET['aktion'] ?? false) {
            if($_GET['id_g']??false)
                $this->load($_GET['id_g']);
            if ($_GET['aktion'] == 'save') {
                $error = $this->setValues($_POST);
                if ($error)
                    $_GET['aktion'] = "edit";
            }

            if ($_GET['aktion'] == 'save') {
                $this->save();
                $GLOBALS['TE']->printMessage($this->t('Saved entry', "Eintrag gespeichert"));
                unset($_GET['aktion']);
            } else {
                echo $this->getForm($this->t('Edit Entry', 'Eintrag bearbeiten'));
            }

        }

        if (!isset($_GET['aktion'])) {
            $comment = $this->getComment();
            if ($comment)
                $GLOBALS['TE']->printMessage($comment);
            if ($this->editAllowed())
                echo $GLOBALS['TE']->getActionLink(
                    '?tab=geld&aktion=edit&id=' . $this->doc->getId(),
                    'Neuer Eintrag','',
                    'new'
                );

            $kats = array(-1, 0, 1);
            $kats_beschr = ($this->de() ? ['Gutschriften', 'Festlegungen', 'Ausgaben'] :
                ['Credit', 'Planned expenses', 'Expenses']);
            $betrag = [];
            $ausgaben = [];
            $sum_ausgaben = 0;
            echo '<table ' . $GLOBALS['TE']->getCSSClass('table') . '>';
            $lang = $this->context->lang;
            $lang2 = $this->context->lang2;
            pg_prepare(
                $this->context->getDbConn(),
                'baydoc_geld',
                "select to_char(g.datum,'DD.MM.YYYY'),g.*,non_empty(k.$lang,k.$lang2),k.dp_sum
                        from baydoc_geld g, baydoc_gkat k where 
                        g.id_gkat=k.id and g.id_stud=" . $this->doc->getId() . " and g.kat=\$1 order by datum"
            );
            for ($i = 0; $i < count($kats); $i++) {
                $bg_color = ($kats[$i] < 0 ? '#00cc00' : '#ff0000');
                echo '<tr><th colspan=4 style="font-weight:bold;">' . $kats_beschr[$i] . '</th></tr>';
                $res = pg_execute(
                    $this->context->getDbConn(),
                    'baydoc_geld',
                    [$kats[$i]]
                );
                for ($j = 0; $j < pg_num_rows($res); $j++) {
                    $r = pg_fetch_array($res, $j);
                    if ($r['dp_sum'] == 't'){
                        if(! isset($betrag[$r['non_empty']])) $betrag[$r['non_empty']]=0;
                        $betrag[$r['non_empty']] += $r['betrag'] * ($r['kat'] < 0 ? 1 : -1);
                    }
                    if ($r['kat'] >= 0) {
                        $sum_ausgaben += $r['betrag'];
                        if(! isset($ausgaben[$r['non_empty']]))$ausgaben[$r['non_empty']]=0;
                        $ausgaben[$r['non_empty']] += $r['betrag'];
                    }

                    echo "<tr><td>$r[to_char]</td><td>$r[non_empty]</td>
                        <td>$r[was]</td><td style=\"align:right;\">$r[betrag]</td>" .
                        ($this->doc->getRole() == 'admin' && $this->editAllowed() && 
                        in_array($r['id_gkat'], $this->gkat_access) ?
                            "<td>".$GLOBALS['TE']->getActionLink("?id=" . $this->doc->getId() .
                            "&tab=geld&aktion=edit&id_g=$r[id]","bearbeiten",'',"edit")."</td>" : '') . "</tr>\n";
                }
                if (pg_num_rows($res) == 0)
                    echo "<tr><td colspan=4>" . ($lang == 'de' ? 'Keine Eintragungen' : 'No entry') . "</td></tr>\n";

            }
            echo "<tr><td colspan=4>&nbsp;</td></tr>\n";

            foreach ($betrag as $key => $value) {
                $value = round($value, 2);
                $bg_color = ($value >= 0 ? '#00cc00' : '#ff0000');
                echo "
                    <tr style=\"background-color:$bg_color;color:#fff;\"><td colspan=3><b>" . ($lang == 'de' ? 'Restbetrag' : 'Amount remaining') . " $key</b>
                    </td><td style=\"align:right;\">$value</td></tr>";
            }
            if ($sum_ausgaben) {
                echo '<tr><th colspan=4><b>' . ($lang == 'de' ? 'Ausgaben nach Kategorie' : 'Expenses grouped by category') . '</b></th></tr>';
                foreach ($ausgaben as $key => $value) {
                    $value = round($value, 2);
                    echo "<tr><td colspan=3>$key</td><td style=\"align:right;\">$value</td></tr>";
                }
                echo '<tr><td colspan=4></td></tr><tr><td colspan=3><b>' . ($lang == 'de' ? 'Gesamt' : 'Total') . '</b></td>
                    <td style="align:right;"><b>' . round($sum_ausgaben, 2) . '</b></td></tr>';

            }
            echo "</table>";

            echo ($lang == 'de' ? '<b>Hinweis:</b> Das Budget wird freigegeben nach 
                <br/>(1) Teilnahme am Auftaktseminar, 
                <br/>(2) Nachweis des Online-Kurses zur Guten Wissenschaftlichen Praxis (Upload unter Promotion -&gt; Bearbeiten), 
                <br/>(3) Teilnahme an einem Qualifizierungskurs (*Workshop).' :
                '<b>Please note:</b> The individual budget will be blocked until 
                    <br/>(1) participation in the kick-off seminar, 
                    <br/>(2) Upload of your certificate from the e-learning course on Good Scientific Practice (in Section PhD -&gt; Edit), 
                    <br/>(3) Participation in a qualification course (marked with an *).');

            if ($this->editAllowed())
                $GLOBALS['TE']->printMessage('Hinweis: Sie können hier Eintragungen vornehmen, da Sie Administrator einer Einheit sind,
                die für die Geldverwaltung freigeschalten ist. Normale Administratoren haben hier nur Leserechte!');

        }
    }
}