<?php

namespace BayDOC\Util;

class Mail
{
    private \BayCMS\Base\BayCMSContext $context;
    private \BayCMS\Util\Sendmail $mailer;

    public function __construct(\BayCMS\Base\BayCMSContext $context)
    {
        $this->context = $context;
    }


    public function getEmailForm(string $qs = '')
    {
        $form = new \BayCMS\Fieldset\Form(
            $this->context,
            submit: 'E-Mail senden',
            qs: $qs
        );

        $form->addField(new \BayCMS\Field\TextInput(
            $this->context,
            name: 'subject',
            description: $this->context->t('Subject', 'Betreff'),
            non_empty: 1
        ));
        $form->addField(new \BayCMS\Field\Textarea(
            $this->context,
            name: 'message',
            description: $this->context->t('Message', 'Nachrichtentext'),
            non_empty: 1
        ));
        $form->addField(new \BayCMS\Field\Select(
            $this->context,
            name: 'email_type',
            description: $this->context->t('E-Mail Type', 'E-Mail Typ'),
            values: ['text', 'html'],
            post_input: '
            <script language="javascript" type="text/javascript" src="/baycms-tinymce4/tinymce.min.js"></script>
            <script>
            function set_editor(){
               if($("#form1_email_type").val()=="html"){
                   tinyMCE.init({
                     selector : "#form1_message",
                     relative_urls : false,
                     remove_script_host : false,
                     plugins : "fullscreen,link,paste",
                         paste_auto_cleanup_on_paste : true,
                         toolbar: " bold italic subscript superscript link | bullist numlist | fullscreen", 
                         menubar:false,
                         statusbar: false,
                         language : "' . $this->context->lang . '",	    
                         debug : false,
                         valid_elements : "p,strong/b.italic/i,ul,ol,li,sub,sup,a[href|target],br,table,tr,th,td,h1,h2,h3,h4,h5,h6,span"	    
                    });
                 
               } else {
                   tinymce.remove("#form1_message");
                   v=$("#form1_message").val();
                   $("#form1_message").val($(v).text());
             
               }
            }
            function set_editor_on_change(){
               if($("#form1_email_type").val()=="html"){
                   v=$("#form1_message").val().replace(/([^>\r\n]?)(\r\n|\n\r|\r|\n)/g, \'$1\'+ \'<br>\' +\'$2\');
                   $("#form1_message").val(v);
               }
               set_editor();	
            }
            $("#form1_email_type").change(set_editor);
            $(document).ready(set_editor);
          </script>           
            
            '
        ));
        $form->addField(new \BayCMS\Field\Select(
            $this->context,
            name: 'Sender',
            no_add_to_query: true,
            values: [
                $this->context->get('row1', 'email'),
                $this->context->get('row1', 'user_email')
            ]
        ));
        return $form;

    }

    public function sendMail(
        mixed $to,
        string $subject_template,
        string $message_template,
        array $values,
        string $from = '',
        mixed $ids = [],
        string $email_type = 'text'
    ) {
        $subject = $this->replaceTokens($subject_template, $values, true);
        $message = $this->replaceTokens($message_template, $values);
        if (!is_array($to))
            $to = [$to];
        if (!is_array($ids))
            $ids = [$ids];
        if (!$from)
            $from = $this->context->get('row1', 'email');
        if (!isset(($this->mailer)))
            $this->mailer = new \BayCMS\Util\Sendmail($this->context);
        for ($i = 0; $i < count($to); $i++) {
            $this->mailer->send($subject, $message, ['to' => $to[$i], 'from' => $from, 'html' => $email_type == 'html']);
            if ($ids[$i])
                pg_query_params(
                    $this->context->getRwDbConn(),
                    'insert into qb2_emails(id_obj,id_row,sendtime,to_address,subject, message,email_type) 
            values ($1,$2,now(),$3,$4,$5,$6)',
                    [$ids[$i], $ids[$i], $to[$i], $subject, $message, $email_type]
                );

        }

    }

    public function getMailText(string $which, int $id_lehr = null, string $modul = 'baydoc')
    {
        if ($id_lehr === null)
            $id_lehr = $this->context->getOrgId();

        $res = pg_query_params(
            $this->context->getDbConn(),
            "select value,id from modul_default_config where mod=\$2 
 and uname=\$1",
            [$which, $modul]
        );
        if (!pg_num_rows($res))
            return '';
        $r = pg_fetch_array($res, 0);
        $res = pg_query_params(
            $this->context->getDbConn(),
            "select value from modul_ls_config where id_lehr=\$1 and id_modconfig=\$2",
            [$id_lehr, $r['id']]
        );
        if (!pg_num_rows($res))
            return $r['value'];
        $r = pg_fetch_array($res, 0);
        return $r['value'];
    }

    public function getAdmins(int $id_lehr = null)
    {
        if ($id_lehr === null)
            $id_lehr = $this->context->getOrgId();
        $emails = [];
        $res = pg_query(
            $this->context->getDbConn(),
            "select distinct b.email from benutzer b, in_ls il
where il.power>=1000 and il.id_benutzer=b.id and 
il.id_lehr=" . $id_lehr . " and b.email>'' and b.email ilike '%@%'"
        );
        for ($i = 0; $i < pg_num_rows($res); $i++)
            [$emails[$i]] = pg_fetch_row($res, $i);

        return $emails;
    }

    public function replaceTokens($template, $r, $no_wordwrap = false)
    {
        $search = [];
        $replace = [];
        foreach ($r as $key => $value) {
            $search[] = '$' . $key . '$';
            $replace[] = $value;
        }
        if ($no_wordwrap)
            return str_replace($search, $replace, $template);
        else
            return wordwrap(str_replace($search, $replace, $template));
    }

}